/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_M3NGLR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_M3NGLR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_M3NGLR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_M3NGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_M3NGLR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_M3NGLR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_M3NGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_M3NGLR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_M3NGLR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_M3NGLR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_M3NGLR::Heavy_WSTD_M3NGLR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_xzE6dU5K);
  numBytes += sLine_init(&sLine_QNmgPlwp);
  numBytes += sLine_init(&sLine_wM5aKWYy);
  numBytes += sLine_init(&sLine_dkMLcHqE);
  numBytes += sLine_init(&sLine_EkIBwZmn);
  numBytes += sBiquad_init(&sBiquad_s_fxMBqzVz);
  numBytes += sLine_init(&sLine_mawsVzU3);
  numBytes += sLine_init(&sLine_NVxjQnl8);
  numBytes += sLine_init(&sLine_SDGkcoaF);
  numBytes += sLine_init(&sLine_ALKocCTi);
  numBytes += sLine_init(&sLine_XPo78D2W);
  numBytes += sBiquad_init(&sBiquad_s_V7PZlozW);
  numBytes += sLine_init(&sLine_OwL1sSW8);
  numBytes += sLine_init(&sLine_yexUL0vG);
  numBytes += sLine_init(&sLine_FVCZeWQg);
  numBytes += sLine_init(&sLine_tLlV6mpz);
  numBytes += sLine_init(&sLine_TBAKZDFl);
  numBytes += sLine_init(&sLine_eXBMm8go);
  numBytes += sBiquad_init(&sBiquad_s_rs9E4TT7);
  numBytes += sLine_init(&sLine_wa75jf5a);
  numBytes += sLine_init(&sLine_UxYunt9Z);
  numBytes += sLine_init(&sLine_WxGO5sky);
  numBytes += sLine_init(&sLine_2cyd2HI4);
  numBytes += sLine_init(&sLine_NGkbo151);
  numBytes += sLine_init(&sLine_KmrYJsfz);
  numBytes += sBiquad_init(&sBiquad_s_9j8aNkGk);
  numBytes += sLine_init(&sLine_SToXVaC3);
  numBytes += sLine_init(&sLine_q0M14IhK);
  numBytes += sLine_init(&sLine_Ep96rZYL);
  numBytes += sLine_init(&sLine_slHWrL6L);
  numBytes += sLine_init(&sLine_8m9lBJHp);
  numBytes += sBiquad_init(&sBiquad_s_wjVxPtDR);
  numBytes += sLine_init(&sLine_NVP5gANv);
  numBytes += sLine_init(&sLine_FA8cnVyE);
  numBytes += sLine_init(&sLine_KdNFiuFT);
  numBytes += sLine_init(&sLine_jwfWwdB7);
  numBytes += sLine_init(&sLine_luAPr5kk);
  numBytes += sLine_init(&sLine_EIWIIEoV);
  numBytes += sBiquad_init(&sBiquad_s_SxDnELtD);
  numBytes += sLine_init(&sLine_ytDMHiuZ);
  numBytes += sLine_init(&sLine_KCVjVWAO);
  numBytes += sLine_init(&sLine_RFeTYkdi);
  numBytes += sLine_init(&sLine_8a6MMoqJ);
  numBytes += sLine_init(&sLine_RIykccS3);
  numBytes += sLine_init(&sLine_7aXjVofq);
  numBytes += sLine_init(&sLine_Y8nZLxwb);
  numBytes += sLine_init(&sLine_HQ6Xu0B9);
  numBytes += sLine_init(&sLine_clx4w716);
  numBytes += sLine_init(&sLine_1cgHQtsR);
  numBytes += sLine_init(&sLine_NsFpXWm1);
  numBytes += sLine_init(&sLine_IADvtpRx);
  numBytes += sLine_init(&sLine_n294RCd6);
  numBytes += sLine_init(&sLine_gJc8PNeP);
  numBytes += sLine_init(&sLine_EFn9NHaU);
  numBytes += sEnv_init(&sEnv_0vLXw4DE, 512, 256);
  numBytes += sEnv_init(&sEnv_X6VhQUUt, 512, 256);
  numBytes += sLine_init(&sLine_LJyZoAzY);
  numBytes += sLine_init(&sLine_wCiqSjlu);
  numBytes += sLine_init(&sLine_Ze0mF9sT);
  numBytes += sLine_init(&sLine_8dzZnWs7);
  numBytes += sLine_init(&sLine_TcKZZxAD);
  numBytes += sLine_init(&sLine_GuuVTCeA);
  numBytes += sLine_init(&sLine_ebeZcP8o);
  numBytes += sLine_init(&sLine_tI4Q5Y6d);
  numBytes += sLine_init(&sLine_3sJV3a89);
  numBytes += sLine_init(&sLine_iYkY0hHB);
  numBytes += sLine_init(&sLine_wg2wgXps);
  numBytes += sLine_init(&sLine_rJYNLifm);
  numBytes += sLine_init(&sLine_R9Dmo8Lf);
  numBytes += sLine_init(&sLine_S3kLqp0Y);
  numBytes += sLine_init(&sLine_APcNkI4j);
  numBytes += sLine_init(&sLine_91mblq9h);
  numBytes += sLine_init(&sLine_nMqFbXeQ);
  numBytes += sLine_init(&sLine_IdA1qZPZ);
  numBytes += sEnv_init(&sEnv_lXJoZoFl, 512, 256);
  numBytes += sEnv_init(&sEnv_bvphXsZx, 512, 256);
  numBytes += sLine_init(&sLine_t3bi42mH);
  numBytes += sLine_init(&sLine_JYfbQUby);
  numBytes += sLine_init(&sLine_l4FU55Kl);
  numBytes += sLine_init(&sLine_LVqPhta4);
  numBytes += sLine_init(&sLine_Arn3lTzT);
  numBytes += sLine_init(&sLine_SClschGm);
  numBytes += sLine_init(&sLine_elVf9Vnz);
  numBytes += sLine_init(&sLine_Ewj5byRN);
  numBytes += sLine_init(&sLine_mAK40YQY);
  numBytes += sLine_init(&sLine_YfoEZAEN);
  numBytes += sLine_init(&sLine_lAR1Xg2G);
  numBytes += sLine_init(&sLine_XKdUOyXt);
  numBytes += sLine_init(&sLine_j5oT2Mgm);
  numBytes += sLine_init(&sLine_72MT8g6v);
  numBytes += sLine_init(&sLine_JOpHP5TD);
  numBytes += sLine_init(&sLine_x8SUfxUU);
  numBytes += sLine_init(&sLine_ZDX8w7Jk);
  numBytes += sLine_init(&sLine_i4Gtz4ZS);
  numBytes += sLine_init(&sLine_EW4g4xpW);
  numBytes += sLine_init(&sLine_mjr4eL4w);
  numBytes += sEnv_init(&sEnv_Vab8C2Nk, 512, 256);
  numBytes += sEnv_init(&sEnv_7LSo0ycF, 512, 256);
  numBytes += sLine_init(&sLine_Yag7Sdav);
  numBytes += sLine_init(&sLine_1zitPqRt);
  numBytes += sLine_init(&sLine_DGWtYZyf);
  numBytes += sLine_init(&sLine_5tIOs5Qy);
  numBytes += sLine_init(&sLine_8qUFWHDl);
  numBytes += sLine_init(&sLine_gLlNlnA8);
  numBytes += sLine_init(&sLine_ECvhcurD);
  numBytes += sLine_init(&sLine_lawUtHkC);
  numBytes += sLine_init(&sLine_0Y5Sf33o);
  numBytes += sLine_init(&sLine_VDwP6j68);
  numBytes += sLine_init(&sLine_f6BOh6kk);
  numBytes += sLine_init(&sLine_C6tFtCZA);
  numBytes += sLine_init(&sLine_XX44TUy7);
  numBytes += sLine_init(&sLine_n3yD6RiJ);
  numBytes += sLine_init(&sLine_1v52Lauc);
  numBytes += sLine_init(&sLine_w6aXpICg);
  numBytes += sLine_init(&sLine_plRZ9nUu);
  numBytes += sLine_init(&sLine_dojQ6Ax2);
  numBytes += sEnv_init(&sEnv_SebcApkC, 512, 256);
  numBytes += sEnv_init(&sEnv_NVpinrgk, 512, 256);
  numBytes += sLine_init(&sLine_bI2EUWQ6);
  numBytes += sLine_init(&sLine_hCh9b5xs);
  numBytes += sLine_init(&sLine_jp0p0uDd);
  numBytes += sLine_init(&sLine_tsPkPeLQ);
  numBytes += sLine_init(&sLine_g6gD2mH3);
  numBytes += sLine_init(&sLine_7eWR2twk);
  numBytes += sLine_init(&sLine_wt4CEhaf);
  numBytes += sLine_init(&sLine_zskjx6sR);
  numBytes += sLine_init(&sLine_FAGprRyj);
  numBytes += sLine_init(&sLine_dObJ04sd);
  numBytes += sLine_init(&sLine_V0EU16uj);
  numBytes += sLine_init(&sLine_4evbcxnu);
  numBytes += sLine_init(&sLine_nupK7uV8);
  numBytes += sLine_init(&sLine_yCcYTrOX);
  numBytes += sLine_init(&sLine_IRwnmGeo);
  numBytes += sLine_init(&sLine_HWilLpMo);
  numBytes += sLine_init(&sLine_PanNwXSZ);
  numBytes += sLine_init(&sLine_tJmxRwCr);
  numBytes += sLine_init(&sLine_WbCaSSpp);
  numBytes += sLine_init(&sLine_hDomaCGc);
  numBytes += sEnv_init(&sEnv_SXUIox5T, 512, 256);
  numBytes += sEnv_init(&sEnv_bgmQ18zr, 512, 256);
  numBytes += sLine_init(&sLine_Jh39WsDN);
  numBytes += sLine_init(&sLine_4COV11Cx);
  numBytes += sLine_init(&sLine_5JoV6qyc);
  numBytes += sLine_init(&sLine_6xI3KZ7e);
  numBytes += sLine_init(&sLine_rg70aCQ4);
  numBytes += sLine_init(&sLine_Jq7zY0aX);
  numBytes += sLine_init(&sLine_QnjqZWyq);
  numBytes += sLine_init(&sLine_kOSS03Ry);
  numBytes += sLine_init(&sLine_jLuLpq0c);
  numBytes += sLine_init(&sLine_SDxmP6OQ);
  numBytes += sLine_init(&sLine_bU5ybW5d);
  numBytes += sLine_init(&sLine_3f7SoeF2);
  numBytes += sLine_init(&sLine_00Le1ti8);
  numBytes += sLine_init(&sLine_k05MI0kE);
  numBytes += sLine_init(&sLine_b0oYX8rM);
  numBytes += sLine_init(&sLine_u3olOA84);
  numBytes += sLine_init(&sLine_s4XeWf9J);
  numBytes += sLine_init(&sLine_TQ0BTggM);
  numBytes += sEnv_init(&sEnv_eTwj183W, 512, 256);
  numBytes += sEnv_init(&sEnv_QADo3dvR, 512, 256);
  numBytes += sLine_init(&sLine_cKRaaX4s);
  numBytes += sLine_init(&sLine_9hihgmkH);
  numBytes += sLine_init(&sLine_Avrt8f19);
  numBytes += sLine_init(&sLine_YqdGmMqn);
  numBytes += sLine_init(&sLine_cILf1MKD);
  numBytes += sLine_init(&sLine_6uApRBZ9);
  numBytes += cVar_init_f(&cVar_1rtcpRBW, 0.0f);
  numBytes += cVar_init_f(&cVar_n0ak0z9R, 0.0f);
  numBytes += cVar_init_f(&cVar_Y3zEhTQN, 0.0f);
  numBytes += cVar_init_f(&cVar_TD2GC48h, 0.0f);
  numBytes += cVar_init_f(&cVar_tapR9NCA, 0.0f);
  numBytes += cVar_init_f(&cVar_OOav8DVl, 1.0f);
  numBytes += cVar_init_f(&cVar_rpqtljlv, 0.0f);
  numBytes += cVar_init_f(&cVar_GYD81vSg, 0.0f);
  numBytes += cVar_init_f(&cVar_5kaiuu8J, 0.0f);
  numBytes += cVar_init_f(&cVar_cSacIwHE, 0.0f);
  numBytes += cSlice_init(&cSlice_VsKsucYJ, 1, -1);
  numBytes += cVar_init_f(&cVar_CbuIeV5P, 1337.0f);
  numBytes += cVar_init_f(&cVar_uiep2mdK, 0.0f);
  numBytes += cIf_init(&cIf_OBcyzbkr, false);
  numBytes += cIf_init(&cIf_u49rLg3E, false);
  numBytes += cBinop_init(&cBinop_spUeg2ix, 0.0f); // __pow
  numBytes += cIf_init(&cIf_9VxfmE58, false);
  numBytes += cBinop_init(&cBinop_XmRMtDuO, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_hhDnQfvf, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_RFsjrol7, 0.0f);
  numBytes += cIf_init(&cIf_P5b79Q7O, false);
  numBytes += cIf_init(&cIf_JwZnzNpc, false);
  numBytes += cBinop_init(&cBinop_qQdJoMcM, 0.0f); // __pow
  numBytes += cIf_init(&cIf_O64ICI4e, false);
  numBytes += cBinop_init(&cBinop_WdX2MICZ, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_fyGq5jCF, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_KWbrqTsv, 0.0f);
  numBytes += cIf_init(&cIf_GF0ZdhOM, false);
  numBytes += cIf_init(&cIf_aOaijEle, false);
  numBytes += cBinop_init(&cBinop_V7IlGTkF, 0.0f); // __pow
  numBytes += cIf_init(&cIf_cl8h2eqV, false);
  numBytes += cBinop_init(&cBinop_pqgOFibR, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_QK6hce9U, -15.0f); // __eq
  numBytes += cIf_init(&cIf_dvmyzcMt, false);
  numBytes += cSlice_init(&cSlice_3ezCgU5w, 1, -1);
  numBytes += cVar_init_f(&cVar_OGnTEunt, 0.0f);
  numBytes += cSlice_init(&cSlice_KJhk5QmV, 1, -1);
  numBytes += cVar_init_f(&cVar_nBjOB8a2, 0.0f);
  numBytes += cSlice_init(&cSlice_OqQnfPoq, 1, -1);
  numBytes += cVar_init_f(&cVar_3tdKC5o6, 0.0f);
  numBytes += cSlice_init(&cSlice_2knPGjg0, 1, -1);
  numBytes += cVar_init_f(&cVar_cNaiL7V1, 0.313f);
  numBytes += cBinop_init(&cBinop_8UX6ymW9, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_d1NobOPN, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_4CjgcEX8, 0.0f);
  numBytes += cVar_init_f(&cVar_aoWBsKC4, 1337.0f);
  numBytes += cVar_init_f(&cVar_FWGDmW9G, 0.3f);
  numBytes += cBinop_init(&cBinop_KdyltgR0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4pMoxTtf, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_0wJhe5pk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gS2r8i8G, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8g6c1Z1J, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JnT7wEbc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xKJSNxMQ, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_1XDpaiOa, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_UiCHDLdn, 0.0f);
  numBytes += cVar_init_f(&cVar_7j6EFgvQ, 1337.0f);
  numBytes += cVar_init_f(&cVar_VUCCKkx4, 0.313f);
  numBytes += cBinop_init(&cBinop_5VuBizdq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_eEnNoL6u, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Wck7DKCk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_K1IgWour, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MzRn2Tn1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_02shqL1f, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_9NkCPwy8, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_uCQZRaxr, 0.0f);
  numBytes += cVar_init_f(&cVar_cf0irE00, 1037.0f);
  numBytes += cVar_init_f(&cVar_59LfuHYj, 0.4f);
  numBytes += cBinop_init(&cBinop_ECHVyQqx, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_eOyDaL6Y, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_iKf29xYd, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ksG9oyzO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_URkCFUBs, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_0WnE5PCI, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_zMIewIzW, 1, -1);
  numBytes += cVar_init_f(&cVar_olQPGbyn, 1337.0f);
  numBytes += cVar_init_f(&cVar_fGCSvT8A, 0.0f);
  numBytes += cIf_init(&cIf_p3vWFAKt, false);
  numBytes += cIf_init(&cIf_OrJfAzr7, false);
  numBytes += cBinop_init(&cBinop_MWXKiS7t, 0.0f); // __pow
  numBytes += cIf_init(&cIf_6HagrQdh, false);
  numBytes += cBinop_init(&cBinop_B7gWrSjc, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_PcF6ycMs, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_fPQRrE0s, 0.0f);
  numBytes += cIf_init(&cIf_qT9GbkrX, false);
  numBytes += cIf_init(&cIf_wvozEkPR, false);
  numBytes += cBinop_init(&cBinop_xlxrp2SF, 0.0f); // __pow
  numBytes += cIf_init(&cIf_G8IbKafE, false);
  numBytes += cBinop_init(&cBinop_dEHjxB7u, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_FNvePRw6, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_ZJeQA4mh, 0.0f);
  numBytes += cIf_init(&cIf_dgxbQy7Y, false);
  numBytes += cIf_init(&cIf_U02Q0B62, false);
  numBytes += cBinop_init(&cBinop_ZEkZjAay, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Zx3Cxwga, false);
  numBytes += cBinop_init(&cBinop_nlUtfb2D, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_Nv1kKZXI, -15.0f); // __eq
  numBytes += cIf_init(&cIf_zPcsPl6M, false);
  numBytes += cSlice_init(&cSlice_GCpHv0Fc, 1, -1);
  numBytes += cVar_init_f(&cVar_9aMUZ4LS, 0.0f);
  numBytes += cSlice_init(&cSlice_KKKhRgIw, 1, -1);
  numBytes += cVar_init_f(&cVar_xyjqi6fw, 0.0f);
  numBytes += cSlice_init(&cSlice_9J9WVdkr, 1, -1);
  numBytes += cVar_init_f(&cVar_MXLzkZzs, 0.0f);
  numBytes += cSlice_init(&cSlice_BhVRqS9s, 1, -1);
  numBytes += cVar_init_f(&cVar_SDVg9zrD, 0.313f);
  numBytes += cBinop_init(&cBinop_F7vI2hDI, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_WAbj6MZo, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_69pASwxu, 0.0f);
  numBytes += cVar_init_f(&cVar_2eYvfeT1, 1337.0f);
  numBytes += cVar_init_f(&cVar_A3s9Cj0J, 0.3f);
  numBytes += cBinop_init(&cBinop_Qfl4goeV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NKG49AxJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WjtsJ35C, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zfW3QBJu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FwCWtARW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_sTdd8YeT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_awJpMbkI, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_ZgCmRGiX, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_xCGQrGGP, 0.0f);
  numBytes += cVar_init_f(&cVar_vViOuSws, 1337.0f);
  numBytes += cVar_init_f(&cVar_7CP3BMfI, 0.313f);
  numBytes += cBinop_init(&cBinop_b8WCUmAD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JflyvtUp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_k3qgQYCf, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UO7eZAqF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_89mF8LDw, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_E542eAUk, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_GWrE8OaU, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_9QFznsvg, 0.0f);
  numBytes += cVar_init_f(&cVar_IFkzGaee, 1037.0f);
  numBytes += cVar_init_f(&cVar_FWF0CzRG, 0.4f);
  numBytes += cBinop_init(&cBinop_7ALrXqSG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5zwROeys, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yXyxKM0I, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7pAycBPi, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ClXT6Vmk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LVYmrQeS, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_TPBrwfmc, 5705.6f);
  numBytes += cVar_init_f(&cVar_9v982nhZ, 313.3f);
  numBytes += cBinop_init(&cBinop_7qTTTcZw, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_rViMwwBz, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_qGEhFU1l, 0.0f); // __div
  numBytes += cSlice_init(&cSlice_i65wIapF, 1, -1);
  numBytes += cVar_init_f(&cVar_0x7J47mD, 0.5f);
  numBytes += cVar_init_f(&cVar_IBcdgxWQ, 0.0f);
  numBytes += cVar_init_f(&cVar_r8wfZLqX, 0.0f);
  numBytes += cIf_init(&cIf_LytZMXta, false);
  numBytes += cIf_init(&cIf_Yq9qYhrr, false);
  numBytes += cDelay_init(this, &cDelay_scty9HDL, 10.0f);
  numBytes += cIf_init(&cIf_oom8aqMi, false);
  numBytes += cIf_init(&cIf_wkR0KBAe, false);
  numBytes += cDelay_init(this, &cDelay_aAK4xb0b, 10.0f);
  numBytes += cIf_init(&cIf_RSmn0pkq, false);
  numBytes += cIf_init(&cIf_5hacUM1Y, false);
  numBytes += cDelay_init(this, &cDelay_LLrPLOd8, 10.0f);
  numBytes += cIf_init(&cIf_Dxs02FeK, false);
  numBytes += cIf_init(&cIf_kze2KA10, false);
  numBytes += cDelay_init(this, &cDelay_waqHaLjN, 10.0f);
  numBytes += cIf_init(&cIf_V4FH86Jf, false);
  numBytes += cIf_init(&cIf_P0RgNRja, false);
  numBytes += cDelay_init(this, &cDelay_WDhmTAOO, 10.0f);
  numBytes += cIf_init(&cIf_VaSGk8hN, false);
  numBytes += cIf_init(&cIf_kEkRTH7x, false);
  numBytes += cDelay_init(this, &cDelay_BHG69H8v, 10.0f);
  numBytes += cIf_init(&cIf_y7bhcqfe, false);
  numBytes += cIf_init(&cIf_IRXWTNsy, false);
  numBytes += cDelay_init(this, &cDelay_5wijxg8L, 10.0f);
  numBytes += cIf_init(&cIf_Hkwua7Y1, false);
  numBytes += cIf_init(&cIf_3YJVNkYT, false);
  numBytes += cDelay_init(this, &cDelay_ORjxiAFh, 10.0f);
  numBytes += cIf_init(&cIf_KZdIjpDe, false);
  numBytes += cIf_init(&cIf_8aYRA4T1, false);
  numBytes += cDelay_init(this, &cDelay_m1TTw6Pa, 10.0f);
  numBytes += cIf_init(&cIf_uyPS3YvW, false);
  numBytes += cIf_init(&cIf_7l69yQ9n, false);
  numBytes += cDelay_init(this, &cDelay_zlP0HDtv, 10.0f);
  numBytes += cIf_init(&cIf_dmoOvVW7, false);
  numBytes += cIf_init(&cIf_4VNiifGi, false);
  numBytes += cDelay_init(this, &cDelay_p7h0bdAC, 10.0f);
  numBytes += cIf_init(&cIf_fmsNEt2c, false);
  numBytes += cIf_init(&cIf_NAtROjtR, false);
  numBytes += cDelay_init(this, &cDelay_4E698XfB, 10.0f);
  numBytes += sVarf_init(&sVarf_slvEwhv4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7VIpL6fX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_atHXUUe1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SjFUDRSj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PHlImIjo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_G7gf7Wyu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_01j254MX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hzcpSn2d, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_25Sz3RI5, 0.0f);
  numBytes += cSlice_init(&cSlice_2NIN2hP4, 1, -1);
  numBytes += cVar_init_f(&cVar_JDkpE6oY, 1.0f);
  numBytes += cSlice_init(&cSlice_inutEfIb, 1, -1);
  numBytes += cVar_init_f(&cVar_IRcBMK7t, 0.0f);
  numBytes += cSlice_init(&cSlice_WEsRWAMu, 1, -1);
  numBytes += cVar_init_f(&cVar_nK0U0mbg, 512.0f);
  numBytes += cSlice_init(&cSlice_R9h09YLP, 1, -1);
  numBytes += cVar_init_f(&cVar_Kp1w2zBA, 1.0f);
  numBytes += cSlice_init(&cSlice_KwNFuGHY, 1, -1);
  numBytes += cVar_init_f(&cVar_fMZiRdWS, 1.0f);
  numBytes += cDelay_init(this, &cDelay_0kKeT0jm, 20.0f);
  numBytes += cVar_init_f(&cVar_rNrQfe51, 0.0f);
  numBytes += cIf_init(&cIf_VjIVSelq, false);
  numBytes += cIf_init(&cIf_DXyfkSni, false);
  numBytes += cBinop_init(&cBinop_k3wCxZS7, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_r9DeRBgf, 1, -1);
  numBytes += cVar_init_f(&cVar_gPTj32a2, 0.0f);
  numBytes += sVarf_init(&sVarf_9KKacHes, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1CQ7aROH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_yDlutCQ4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EP5RRXSZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mIa4NwQH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ofaqyxcc, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_DEFMfnuu, 0.0f);
  numBytes += cVar_init_f(&cVar_P1zW5wg7, 0.0f);
  numBytes += cIf_init(&cIf_rGr0MlCr, false);
  numBytes += cIf_init(&cIf_rvU8u9tP, false);
  numBytes += cDelay_init(this, &cDelay_IxR6Bq9w, 10.0f);
  numBytes += cIf_init(&cIf_p9IGal1Y, false);
  numBytes += cIf_init(&cIf_ZiLcuVTo, false);
  numBytes += cDelay_init(this, &cDelay_qfZsRQLu, 10.0f);
  numBytes += cIf_init(&cIf_Jwwqfwac, false);
  numBytes += cIf_init(&cIf_Zr6SGiaz, false);
  numBytes += cDelay_init(this, &cDelay_fTFlDa7A, 10.0f);
  numBytes += cIf_init(&cIf_90PLhf6v, false);
  numBytes += cIf_init(&cIf_Y9li8S14, false);
  numBytes += cDelay_init(this, &cDelay_YGMpW5aD, 10.0f);
  numBytes += cIf_init(&cIf_GdGygfhL, false);
  numBytes += cIf_init(&cIf_4qzNz1yB, false);
  numBytes += cDelay_init(this, &cDelay_tOWBaq8W, 10.0f);
  numBytes += cIf_init(&cIf_ETamw3B8, false);
  numBytes += cIf_init(&cIf_T1NI7VeP, false);
  numBytes += cDelay_init(this, &cDelay_Oizm8CD6, 10.0f);
  numBytes += cIf_init(&cIf_ZjZfVCMJ, false);
  numBytes += cIf_init(&cIf_uaDI5Udv, false);
  numBytes += cDelay_init(this, &cDelay_HOHmF4Zp, 10.0f);
  numBytes += cIf_init(&cIf_LyTXZySr, false);
  numBytes += cIf_init(&cIf_IbHlbaCA, false);
  numBytes += cDelay_init(this, &cDelay_wrkDIHcG, 10.0f);
  numBytes += cIf_init(&cIf_SMNfGEp3, false);
  numBytes += cIf_init(&cIf_G6rcEvPU, false);
  numBytes += cDelay_init(this, &cDelay_p6inJrBi, 10.0f);
  numBytes += cIf_init(&cIf_iN4Oe7jQ, false);
  numBytes += cIf_init(&cIf_kUWeCwb0, false);
  numBytes += cDelay_init(this, &cDelay_mpuyrbHN, 10.0f);
  numBytes += cIf_init(&cIf_7GeC5Sm1, false);
  numBytes += cIf_init(&cIf_DX7SXTxc, false);
  numBytes += cDelay_init(this, &cDelay_CoWP2Qoj, 10.0f);
  numBytes += cIf_init(&cIf_K12HQNuE, false);
  numBytes += cIf_init(&cIf_Ix8e2RYF, false);
  numBytes += cDelay_init(this, &cDelay_IMgf7nsx, 10.0f);
  numBytes += sVarf_init(&sVarf_jXoGPIG6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kkAFQqqv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_e3TMYEtE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uvmL77g5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4oQd7mB3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DORhvzVY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_f8keSKbS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ttFZguO7, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_7QzWHacc, 0.0f);
  numBytes += cSlice_init(&cSlice_b3QzQuAd, 1, -1);
  numBytes += cVar_init_f(&cVar_N6nVAae4, 1.0f);
  numBytes += cSlice_init(&cSlice_YdzSMMPD, 1, -1);
  numBytes += cVar_init_f(&cVar_2us1DNKp, 0.0f);
  numBytes += cSlice_init(&cSlice_APL5IOJg, 1, -1);
  numBytes += cVar_init_f(&cVar_jQKDssvQ, 512.0f);
  numBytes += cSlice_init(&cSlice_OAZdHQdF, 1, -1);
  numBytes += cVar_init_f(&cVar_JBbVVxFv, 1.0f);
  numBytes += cSlice_init(&cSlice_RNyvD4Bz, 1, -1);
  numBytes += cVar_init_f(&cVar_7Hm77VZB, 1.0f);
  numBytes += cDelay_init(this, &cDelay_Hpggc0Ki, 20.0f);
  numBytes += cVar_init_f(&cVar_k6KKjbyY, 0.0f);
  numBytes += cIf_init(&cIf_IU8kLC3Y, false);
  numBytes += cIf_init(&cIf_DvF4eO03, false);
  numBytes += cBinop_init(&cBinop_e0TUzQC5, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_cD6nTWWV, 1, -1);
  numBytes += cVar_init_f(&cVar_gZYRfL5T, 0.0f);
  numBytes += sVarf_init(&sVarf_EmVzxbGG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mTdxbi2K, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LDV3oreP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VdogrI20, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cikgi5eF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4EJIT8hm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jSB595L7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EJVJGCRJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eF0IUtLc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dKmh1QMQ, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_dfiMQfTV, 0.0f);
  numBytes += cVar_init_f(&cVar_wqjDDt7J, 0.0f);
  numBytes += cVar_init_f(&cVar_hb37dN8I, 0.0f);
  numBytes += cVar_init_f(&cVar_9toWFASb, 0.0f);
  numBytes += cVar_init_f(&cVar_26fwkrrn, 0.0f);
  numBytes += cVar_init_f(&cVar_cxvdBAaq, 1.0f);
  numBytes += cSlice_init(&cSlice_YqlLV05q, 1, -1);
  numBytes += cVar_init_f(&cVar_lFqd7G7a, 0.5f);
  numBytes += cVar_init_f(&cVar_jU53TK8N, 0.0f);
  numBytes += cVar_init_f(&cVar_Dk67hGaW, 0.0f);
  numBytes += cIf_init(&cIf_bpW84bqp, false);
  numBytes += cIf_init(&cIf_ZXnygVJr, false);
  numBytes += cDelay_init(this, &cDelay_Cmf6q2Ns, 10.0f);
  numBytes += cIf_init(&cIf_YhtssPr8, false);
  numBytes += cIf_init(&cIf_CeZGIPhc, false);
  numBytes += cDelay_init(this, &cDelay_zo9u949S, 10.0f);
  numBytes += cIf_init(&cIf_Kul25jGu, false);
  numBytes += cIf_init(&cIf_15kgzMnW, false);
  numBytes += cDelay_init(this, &cDelay_ASuR2k4A, 10.0f);
  numBytes += cIf_init(&cIf_lY7g8PUG, false);
  numBytes += cIf_init(&cIf_bt9gPPgf, false);
  numBytes += cDelay_init(this, &cDelay_L93L98vn, 10.0f);
  numBytes += cIf_init(&cIf_JGt23hR0, false);
  numBytes += cIf_init(&cIf_UEduO0Q7, false);
  numBytes += cDelay_init(this, &cDelay_Y9fSbdz5, 10.0f);
  numBytes += cIf_init(&cIf_iZW7lNkt, false);
  numBytes += cIf_init(&cIf_Fw0SBQeX, false);
  numBytes += cDelay_init(this, &cDelay_EboaYano, 10.0f);
  numBytes += cIf_init(&cIf_Kwb0vueD, false);
  numBytes += cIf_init(&cIf_EEHb5mn5, false);
  numBytes += cDelay_init(this, &cDelay_AhmtaJy7, 10.0f);
  numBytes += cIf_init(&cIf_uC2kacbS, false);
  numBytes += cIf_init(&cIf_mRS5rkXL, false);
  numBytes += cDelay_init(this, &cDelay_XaCEPKKl, 10.0f);
  numBytes += cIf_init(&cIf_vux7M62K, false);
  numBytes += cIf_init(&cIf_d7zjIZPm, false);
  numBytes += cDelay_init(this, &cDelay_g9puk30z, 10.0f);
  numBytes += cIf_init(&cIf_rWaqLkWe, false);
  numBytes += cIf_init(&cIf_dZhCbWKI, false);
  numBytes += cDelay_init(this, &cDelay_blcQPNle, 10.0f);
  numBytes += cIf_init(&cIf_lEq2HdXC, false);
  numBytes += cIf_init(&cIf_prVRm4Df, false);
  numBytes += cDelay_init(this, &cDelay_UafJabio, 10.0f);
  numBytes += cIf_init(&cIf_hnIKZfmI, false);
  numBytes += cIf_init(&cIf_5CqYb335, false);
  numBytes += cDelay_init(this, &cDelay_cPDobivr, 10.0f);
  numBytes += sVarf_init(&sVarf_CKWvYOMy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9ZZaYkSw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rDyQb5CD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eRzs33w6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dkiKWwRw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rQXuCUwb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qhKxAhAT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eNKp5g8C, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_f7NPBKnN, 0.0f);
  numBytes += cSlice_init(&cSlice_9REUbK9j, 1, -1);
  numBytes += cVar_init_f(&cVar_9VWgHGMD, 1.0f);
  numBytes += cSlice_init(&cSlice_ChMssFQh, 1, -1);
  numBytes += cVar_init_f(&cVar_qhcjrmBy, 0.0f);
  numBytes += cSlice_init(&cSlice_1uVkBWAR, 1, -1);
  numBytes += cVar_init_f(&cVar_YZUWV0hv, 512.0f);
  numBytes += cSlice_init(&cSlice_GiTmA7Cm, 1, -1);
  numBytes += cVar_init_f(&cVar_XeQ9T5Wg, 1.0f);
  numBytes += cSlice_init(&cSlice_rpIgJiot, 1, -1);
  numBytes += cVar_init_f(&cVar_hqDqKmQm, 1.0f);
  numBytes += cDelay_init(this, &cDelay_uRaDSgzC, 20.0f);
  numBytes += cVar_init_f(&cVar_96yXdXUg, 0.0f);
  numBytes += cIf_init(&cIf_tnlxBOlI, false);
  numBytes += cIf_init(&cIf_yeIX9NKZ, false);
  numBytes += cBinop_init(&cBinop_79BwAJDu, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_gt0zZab3, 1, -1);
  numBytes += cVar_init_f(&cVar_YvGhDbvH, 0.0f);
  numBytes += sVarf_init(&sVarf_aN4Ff5uW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LVkKPiFV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KeaflkBF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_f74U6UoW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RlqNPGZL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Rmkgfx91, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_th0exKwl, 0.0f);
  numBytes += cVar_init_f(&cVar_b7nTVroj, 0.0f);
  numBytes += cIf_init(&cIf_kyrWk2Dg, false);
  numBytes += cIf_init(&cIf_g26FUaQq, false);
  numBytes += cDelay_init(this, &cDelay_Ji2QncZv, 10.0f);
  numBytes += cIf_init(&cIf_ZJhpIUH3, false);
  numBytes += cIf_init(&cIf_9TukPgLz, false);
  numBytes += cDelay_init(this, &cDelay_Hhmx3ZNK, 10.0f);
  numBytes += cIf_init(&cIf_9IDvH2KG, false);
  numBytes += cIf_init(&cIf_5fZxIEVj, false);
  numBytes += cDelay_init(this, &cDelay_cwVmen6I, 10.0f);
  numBytes += cIf_init(&cIf_xKGnNvsR, false);
  numBytes += cIf_init(&cIf_UzP9jYoc, false);
  numBytes += cDelay_init(this, &cDelay_Mz7KzGko, 10.0f);
  numBytes += cIf_init(&cIf_in4CBi4o, false);
  numBytes += cIf_init(&cIf_RwoeIumg, false);
  numBytes += cDelay_init(this, &cDelay_S3cy4mvl, 10.0f);
  numBytes += cIf_init(&cIf_LrvUoj6o, false);
  numBytes += cIf_init(&cIf_rb16PU4e, false);
  numBytes += cDelay_init(this, &cDelay_yKFHDoOf, 10.0f);
  numBytes += cIf_init(&cIf_HEVrgmuN, false);
  numBytes += cIf_init(&cIf_v24aE7JG, false);
  numBytes += cDelay_init(this, &cDelay_y40DZmnM, 10.0f);
  numBytes += cIf_init(&cIf_1RRXLW96, false);
  numBytes += cIf_init(&cIf_FRW54VVT, false);
  numBytes += cDelay_init(this, &cDelay_D6deAFAV, 10.0f);
  numBytes += cIf_init(&cIf_0ei1eoC0, false);
  numBytes += cIf_init(&cIf_jG267RVs, false);
  numBytes += cDelay_init(this, &cDelay_HfaKCh2Z, 10.0f);
  numBytes += cIf_init(&cIf_f4aINsLO, false);
  numBytes += cIf_init(&cIf_DHb277t7, false);
  numBytes += cDelay_init(this, &cDelay_kmWVIcbA, 10.0f);
  numBytes += cIf_init(&cIf_uTlSzZXw, false);
  numBytes += cIf_init(&cIf_T5ffRsf8, false);
  numBytes += cDelay_init(this, &cDelay_zuUBfjme, 10.0f);
  numBytes += cIf_init(&cIf_2dsI1VOR, false);
  numBytes += cIf_init(&cIf_Ta8aL6Ay, false);
  numBytes += cDelay_init(this, &cDelay_PwbEgWNT, 10.0f);
  numBytes += sVarf_init(&sVarf_xr6JOdum, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_X9Ox9MuR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EjGaUOJc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_E06bcTW9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eGo6mWCB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Dl2Ren66, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_JVwDpWW2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_B885LOj5, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_TU32IZjr, 0.0f);
  numBytes += cSlice_init(&cSlice_GNjHZZGt, 1, -1);
  numBytes += cVar_init_f(&cVar_Qj11yOFv, 1.0f);
  numBytes += cSlice_init(&cSlice_QumeeFHZ, 1, -1);
  numBytes += cVar_init_f(&cVar_jZY58dxA, 0.0f);
  numBytes += cSlice_init(&cSlice_theEZZ1b, 1, -1);
  numBytes += cVar_init_f(&cVar_L4J08TWe, 512.0f);
  numBytes += cSlice_init(&cSlice_ugHx8vNO, 1, -1);
  numBytes += cVar_init_f(&cVar_jK8qyWDU, 1.0f);
  numBytes += cSlice_init(&cSlice_QP7GvFLq, 1, -1);
  numBytes += cVar_init_f(&cVar_o2Du3tv6, 1.0f);
  numBytes += cDelay_init(this, &cDelay_Zeh1RHCo, 20.0f);
  numBytes += cVar_init_f(&cVar_QFSsiNEW, 0.0f);
  numBytes += cIf_init(&cIf_i08fDHsz, false);
  numBytes += cIf_init(&cIf_2hFZZBY6, false);
  numBytes += cBinop_init(&cBinop_pUs7x8Zf, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_sRqHn11F, 1, -1);
  numBytes += cVar_init_f(&cVar_wJODObdJ, 0.0f);
  numBytes += sVarf_init(&sVarf_Ty4fTfwE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TK4TYESy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IJ22BkAO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rocW0gck, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iD5L6E3O, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gL4FmsV0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OdTrvi1h, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OJIWjBm0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_J5PLq9hm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mbjq7YNJ, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_EE0A2WvJ, 0.0f);
  numBytes += cVar_init_f(&cVar_KAyw8LI3, 0.0f);
  numBytes += cVar_init_f(&cVar_np0c0xQX, 0.0f);
  numBytes += cVar_init_f(&cVar_oQKRtR1c, 0.0f);
  numBytes += cVar_init_f(&cVar_lYcpsNve, 0.0f);
  numBytes += cVar_init_f(&cVar_vqRoXdF3, 1.0f);
  numBytes += cSlice_init(&cSlice_ZAoUbb99, 1, -1);
  numBytes += cVar_init_f(&cVar_jUi3BycM, 0.5f);
  numBytes += cVar_init_f(&cVar_EnFXUabm, 0.0f);
  numBytes += cVar_init_f(&cVar_5NFce6E5, 0.0f);
  numBytes += cIf_init(&cIf_MYHhnbOQ, false);
  numBytes += cIf_init(&cIf_lniVhoWu, false);
  numBytes += cDelay_init(this, &cDelay_IuQ3D3kU, 10.0f);
  numBytes += cIf_init(&cIf_xDEVbR2M, false);
  numBytes += cIf_init(&cIf_dnNqqgNO, false);
  numBytes += cDelay_init(this, &cDelay_qejbIzqe, 10.0f);
  numBytes += cIf_init(&cIf_VC1Tgacs, false);
  numBytes += cIf_init(&cIf_JXnJg9Uy, false);
  numBytes += cDelay_init(this, &cDelay_7R8qJMFE, 10.0f);
  numBytes += cIf_init(&cIf_jlQydz7B, false);
  numBytes += cIf_init(&cIf_wQR9ekG4, false);
  numBytes += cDelay_init(this, &cDelay_s4FsoRTD, 10.0f);
  numBytes += cIf_init(&cIf_5M069YIm, false);
  numBytes += cIf_init(&cIf_oMw3lWJA, false);
  numBytes += cDelay_init(this, &cDelay_USMc2VVU, 10.0f);
  numBytes += cIf_init(&cIf_lja8VwLt, false);
  numBytes += cIf_init(&cIf_KPY4DVhJ, false);
  numBytes += cDelay_init(this, &cDelay_nSv1mN0d, 10.0f);
  numBytes += cIf_init(&cIf_KAGxFEjH, false);
  numBytes += cIf_init(&cIf_kmBK6ihI, false);
  numBytes += cDelay_init(this, &cDelay_CdTmPXTk, 10.0f);
  numBytes += cIf_init(&cIf_tJ3mKSK7, false);
  numBytes += cIf_init(&cIf_RWsvjuBI, false);
  numBytes += cDelay_init(this, &cDelay_I1Jx9ZGj, 10.0f);
  numBytes += cIf_init(&cIf_CoIkMARe, false);
  numBytes += cIf_init(&cIf_BrZbN1do, false);
  numBytes += cDelay_init(this, &cDelay_hKUsDoQW, 10.0f);
  numBytes += cIf_init(&cIf_AHDFaYnb, false);
  numBytes += cIf_init(&cIf_L35Yx1Bn, false);
  numBytes += cDelay_init(this, &cDelay_bkuYv2md, 10.0f);
  numBytes += cIf_init(&cIf_xmUUaMaN, false);
  numBytes += cIf_init(&cIf_tXY0Tzn7, false);
  numBytes += cDelay_init(this, &cDelay_PNjF28iu, 10.0f);
  numBytes += cIf_init(&cIf_Wgp8A5No, false);
  numBytes += cIf_init(&cIf_eIjvkspR, false);
  numBytes += cDelay_init(this, &cDelay_BbMPROBi, 10.0f);
  numBytes += sVarf_init(&sVarf_bHTllCpE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_w20YXUEA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FUHaXlpV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DZSBaz24, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3cw3hUVR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5GRNsmGi, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_y1K2B105, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_18tAKPat, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_9xYvZgsu, 0.0f);
  numBytes += cSlice_init(&cSlice_Z1A3EXvq, 1, -1);
  numBytes += cVar_init_f(&cVar_6iPb83CS, 1.0f);
  numBytes += cSlice_init(&cSlice_0GEby73d, 1, -1);
  numBytes += cVar_init_f(&cVar_AiwS0bSa, 0.0f);
  numBytes += cSlice_init(&cSlice_hxAlRUfP, 1, -1);
  numBytes += cVar_init_f(&cVar_Ifi40YJu, 512.0f);
  numBytes += cSlice_init(&cSlice_tUYoT2dQ, 1, -1);
  numBytes += cVar_init_f(&cVar_YKjOtGOQ, 1.0f);
  numBytes += cSlice_init(&cSlice_AEwLAJkM, 1, -1);
  numBytes += cVar_init_f(&cVar_hf2w8GAX, 1.0f);
  numBytes += cDelay_init(this, &cDelay_QZQXE8jo, 20.0f);
  numBytes += cVar_init_f(&cVar_vSCVUS06, 0.0f);
  numBytes += cIf_init(&cIf_fRaeeWfk, false);
  numBytes += cIf_init(&cIf_eyRLdUVc, false);
  numBytes += cBinop_init(&cBinop_q3WQBCMs, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_FzNh9wyP, 1, -1);
  numBytes += cVar_init_f(&cVar_D7mlBY4n, 0.0f);
  numBytes += sVarf_init(&sVarf_ZdmopDW5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_K48ilF92, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AHpmQabp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VeNFz0yL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TUHsI1O3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DZIPtg72, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_NGMJuspW, 0.0f);
  numBytes += cVar_init_f(&cVar_F1uObOX4, 0.0f);
  numBytes += cIf_init(&cIf_y2NvahtZ, false);
  numBytes += cIf_init(&cIf_9tpdwyXt, false);
  numBytes += cDelay_init(this, &cDelay_q9eAbtrq, 10.0f);
  numBytes += cIf_init(&cIf_iVXau2MM, false);
  numBytes += cIf_init(&cIf_No05eEbO, false);
  numBytes += cDelay_init(this, &cDelay_frSkqEvY, 10.0f);
  numBytes += cIf_init(&cIf_SmWSLipi, false);
  numBytes += cIf_init(&cIf_7q7eFMOH, false);
  numBytes += cDelay_init(this, &cDelay_Sj01fPsE, 10.0f);
  numBytes += cIf_init(&cIf_gwXE9gQL, false);
  numBytes += cIf_init(&cIf_wEYirBpv, false);
  numBytes += cDelay_init(this, &cDelay_WSGjX3yF, 10.0f);
  numBytes += cIf_init(&cIf_mQ8NyF0Q, false);
  numBytes += cIf_init(&cIf_o382U2ti, false);
  numBytes += cDelay_init(this, &cDelay_oNBomTWM, 10.0f);
  numBytes += cIf_init(&cIf_9KNGnSyU, false);
  numBytes += cIf_init(&cIf_PxTkTccI, false);
  numBytes += cDelay_init(this, &cDelay_wwzuJnNI, 10.0f);
  numBytes += cIf_init(&cIf_jfVls1EK, false);
  numBytes += cIf_init(&cIf_DqSaNpOV, false);
  numBytes += cDelay_init(this, &cDelay_WVkyCjM1, 10.0f);
  numBytes += cIf_init(&cIf_Ik2EUFoc, false);
  numBytes += cIf_init(&cIf_UgRGJXOd, false);
  numBytes += cDelay_init(this, &cDelay_7KqFIZPt, 10.0f);
  numBytes += cIf_init(&cIf_t4dtMxQT, false);
  numBytes += cIf_init(&cIf_R2yxEciV, false);
  numBytes += cDelay_init(this, &cDelay_I9f2fzku, 10.0f);
  numBytes += cIf_init(&cIf_wRpurb9g, false);
  numBytes += cIf_init(&cIf_jwB3MuHX, false);
  numBytes += cDelay_init(this, &cDelay_18peB7fy, 10.0f);
  numBytes += cIf_init(&cIf_EoVvuyCB, false);
  numBytes += cIf_init(&cIf_ACo2yRxk, false);
  numBytes += cDelay_init(this, &cDelay_T3OfSqt5, 10.0f);
  numBytes += cIf_init(&cIf_PSWU4JCd, false);
  numBytes += cIf_init(&cIf_NaIsAJRU, false);
  numBytes += cDelay_init(this, &cDelay_METmT7OF, 10.0f);
  numBytes += sVarf_init(&sVarf_n4ydhRnt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sXKCcAMk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9yqDVKeT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eQoPPMJC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_r0bWoJem, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZGCY2BTb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MM070WZK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Os3fD1ui, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_nn23TImq, 0.0f);
  numBytes += cSlice_init(&cSlice_PQgvcMOy, 1, -1);
  numBytes += cVar_init_f(&cVar_tGEJlMjS, 1.0f);
  numBytes += cSlice_init(&cSlice_nwsqT3ii, 1, -1);
  numBytes += cVar_init_f(&cVar_h1FCjR5T, 0.0f);
  numBytes += cSlice_init(&cSlice_PqXHPy0m, 1, -1);
  numBytes += cVar_init_f(&cVar_UwEseuhe, 512.0f);
  numBytes += cSlice_init(&cSlice_tq7sX6I1, 1, -1);
  numBytes += cVar_init_f(&cVar_PxjGTUWL, 1.0f);
  numBytes += cSlice_init(&cSlice_scTq4fKW, 1, -1);
  numBytes += cVar_init_f(&cVar_9bTWvr0K, 1.0f);
  numBytes += cDelay_init(this, &cDelay_Ryp61Ovu, 20.0f);
  numBytes += cVar_init_f(&cVar_8sxcQIZQ, 0.0f);
  numBytes += cIf_init(&cIf_n9FG4I6f, false);
  numBytes += cIf_init(&cIf_GladYGQm, false);
  numBytes += cBinop_init(&cBinop_9tV9FsoE, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_1sohhQYG, 1, -1);
  numBytes += cVar_init_f(&cVar_LUsX6vvk, 0.0f);
  numBytes += sVarf_init(&sVarf_V34kDXjc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Kqd2OWvr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8nb9sm9G, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GrvutEiq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lCsD17he, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vuXuffCV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vWN3FD41, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9VVJSSb0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GIsMgmBC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qKPhfqwc, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_p1IzKpDN, 0.0f);
  numBytes += cVar_init_f(&cVar_4dIxWo09, 0.0f);
  numBytes += cVar_init_f(&cVar_F2jub07f, 0.0f);
  numBytes += sVarf_init(&sVarf_ROk7WGZC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1dvUqAI2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VYUhJHSW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eOe5XbOk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_G0Ud2ayX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ek9mkeHO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NCKczyfp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_97oBvnPd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9dA9dDxu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kXFktIX5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WRJwFO7C, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fexw9QZ3, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_M3NGLR::~Heavy_WSTD_M3NGLR() {
  sEnv_free(&sEnv_0vLXw4DE);
  sEnv_free(&sEnv_X6VhQUUt);
  sEnv_free(&sEnv_lXJoZoFl);
  sEnv_free(&sEnv_bvphXsZx);
  sEnv_free(&sEnv_Vab8C2Nk);
  sEnv_free(&sEnv_7LSo0ycF);
  sEnv_free(&sEnv_SebcApkC);
  sEnv_free(&sEnv_NVpinrgk);
  sEnv_free(&sEnv_SXUIox5T);
  sEnv_free(&sEnv_bgmQ18zr);
  sEnv_free(&sEnv_eTwj183W);
  sEnv_free(&sEnv_QADo3dvR);
}

HvTable *Heavy_WSTD_M3NGLR::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_M3NGLR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5847RBWb_sendMessage);
      break;
    }
    case 0xCFF7A234: { // High_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QQusSzLe_sendMessage);
      break;
    }
    case 0x12EF45B9: { // High_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_96rjqZ93_sendMessage);
      break;
    }
    case 0xC05E9A15: { // High_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9knGDMcO_sendMessage);
      break;
    }
    case 0x8E596A67: { // High_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NQ2Akip6_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bucS69DY_sendMessage);
      break;
    }
    case 0x585E4A54: { // High_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sRAeSG3v_sendMessage);
      break;
    }
    case 0x14A9747F: { // High_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_msPtdApp_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UfsuGQCW_sendMessage);
      break;
    }
    case 0xEBDB0C5E: { // Low_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_scxxDwgb_sendMessage);
      break;
    }
    case 0xF974E926: { // Low_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_K09SX2AQ_sendMessage);
      break;
    }
    case 0xBB56D13C: { // Low_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6Xh3ae9P_sendMessage);
      break;
    }
    case 0xB4EFBAC1: { // Low_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QyGGfnjG_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aYE3Vb39_sendMessage);
      break;
    }
    case 0x1665AEE9: { // Low_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vJowEYXr_sendMessage);
      break;
    }
    case 0x860CA1D9: { // Low_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TP8W4Qdk_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GKJBFzNX_sendMessage);
      break;
    }
    case 0xEA9DEF12: { // Mid_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Jdnj97h5_sendMessage);
      break;
    }
    case 0xDBF6FE0A: { // Mid_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JlelTBC8_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_inFmYPzF_sendMessage);
      break;
    }
    case 0x23F5E910: { // Mid_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fPm9mOV9_sendMessage);
      break;
    }
    case 0x33C126B6: { // Mid_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_88IudA8X_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_70DWelDu_sendMessage);
      break;
    }
    case 0x64B1268F: { // Mid_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yi0hhW6r_sendMessage);
      break;
    }
    case 0xA91022F8: { // Mid_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5GtL5g4p_sendMessage);
      break;
    }
    case 0x1AFCE6EB: { // 1025-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TSibBAEv_sendMessage);
      break;
    }
    case 0xD8B5B1DB: { // 1025-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QlgPs0Pn_sendMessage);
      break;
    }
    case 0x3794F656: { // 1025-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lawmpvUD_sendMessage);
      break;
    }
    case 0x94AE0ED9: { // 1025-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UwLIShtH_sendMessage);
      break;
    }
    case 0xCC4DB41E: { // 1025-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yCLL88G0_sendMessage);
      break;
    }
    case 0xAFE114F6: { // 1084-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_T8AOSnTh_sendMessage);
      break;
    }
    case 0x98647BAD: { // 1084-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PYXVUWc1_sendMessage);
      break;
    }
    case 0xA4661944: { // 1084-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2HxPtPC7_sendMessage);
      break;
    }
    case 0x505CED7B: { // 1125-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rJVRUZJH_sendMessage);
      break;
    }
    case 0x82611A6: { // 1125-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_I8Jbvq9G_sendMessage);
      break;
    }
    case 0x1B990984: { // 1125-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_75R5CVgs_sendMessage);
      break;
    }
    case 0x5F0AFAC5: { // 1166-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rcaGEspo_sendMessage);
      break;
    }
    case 0x25349984: { // 1166-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_14W1NNmd_sendMessage);
      break;
    }
    case 0x8258EF5C: { // 1166-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_553Iso7K_sendMessage);
      break;
    }
    case 0xBC1DF870: { // 1181-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9w9DgtJK_sendMessage);
      break;
    }
    case 0x9A5A2ED: { // 1181-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hgK6cwIU_sendMessage);
      break;
    }
    case 0x6714DCEB: { // 1181-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fafaDxZn_sendMessage);
      break;
    }
    case 0xE583CFFE: { // 1181-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1dSNCbAi_sendMessage);
      break;
    }
    case 0xA6D36AFA: { // 1181-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZUdG1JSt_sendMessage);
      break;
    }
    case 0x2AD225: { // 1240-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HOVjzIAH_sendMessage);
      break;
    }
    case 0x7DD55B03: { // 1240-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5pl9RoFh_sendMessage);
      break;
    }
    case 0xCF4D157B: { // 1240-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vCySTAWn_sendMessage);
      break;
    }
    case 0x4DF9D195: { // 1281-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7CUWnQnI_sendMessage);
      break;
    }
    case 0x58CB5D1B: { // 1281-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fTJ8jQhJ_sendMessage);
      break;
    }
    case 0xE926ADAA: { // 1281-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8R13FmlE_sendMessage);
      break;
    }
    case 0x839669AF: { // 1322-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ul7mgnHj_sendMessage);
      break;
    }
    case 0x89AA8991: { // 1322-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cnKnw0gR_sendMessage);
      break;
    }
    case 0xC43C6A92: { // 1322-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xZ9FaN6I_sendMessage);
      break;
    }
    case 0x44C46A9A: { // 1345-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sDMRjJdm_sendMessage);
      break;
    }
    case 0x5B005CAA: { // 1352-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zY3h3ABA_sendMessage);
      break;
    }
    case 0xBBD23460: { // 1352-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fII2LWuP_sendMessage);
      break;
    }
    case 0x23884B06: { // 1352-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YX0SDn3T_sendMessage);
      break;
    }
    case 0x91BE5650: { // 1352-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QB1zvJpk_sendMessage);
      break;
    }
    case 0x51E8B18D: { // 1352-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iOylIHin_sendMessage);
      break;
    }
    case 0x2CAD1402: { // 1352-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CK9IXeBC_sendMessage);
      break;
    }
    case 0x8CE949DD: { // 1470-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_if0Uz0pL_sendMessage);
      break;
    }
    case 0x1A98A8C5: { // 1470-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OWNASTZ7_sendMessage);
      break;
    }
    case 0x4211FC92: { // 1470-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3ANAxUma_sendMessage);
      break;
    }
    case 0x86F6710B: { // 1470-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HZxBjXjZ_sendMessage);
      break;
    }
    case 0x102FAA7E: { // 1470-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JAHT2qDU_sendMessage);
      break;
    }
    case 0x1A325FAC: { // 1470-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eJq5xGfp_sendMessage);
      break;
    }
    case 0x5FF45DD7: { // 1602-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aIQqFWDI_sendMessage);
      break;
    }
    case 0xA63D49D8: { // 1609-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PR82eDCm_sendMessage);
      break;
    }
    case 0xFB1C4FF4: { // 1609-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ObEk1ixs_sendMessage);
      break;
    }
    case 0x2D7D2212: { // 1609-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MI2TqDNN_sendMessage);
      break;
    }
    case 0xB4610071: { // 1609-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nZUl1MxT_sendMessage);
      break;
    }
    case 0x47BBE59E: { // 1609-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sN5VzAK0_sendMessage);
      break;
    }
    case 0xD51403EB: { // 1609-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uC1OmnhV_sendMessage);
      break;
    }
    case 0x559ECA90: { // 1727-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dRx3HTzB_sendMessage);
      break;
    }
    case 0xB4F19FB9: { // 1727-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9jom1PUg_sendMessage);
      break;
    }
    case 0x7CE4DF88: { // 1727-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9enWemSC_sendMessage);
      break;
    }
    case 0x9FD7A64D: { // 1727-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OcsAmQRr_sendMessage);
      break;
    }
    case 0x52C25AFE: { // 1727-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dl3aLlne_sendMessage);
      break;
    }
    case 0x801C27A5: { // 1727-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JzQj7yWu_sendMessage);
      break;
    }
    case 0xE5875B65: { // 1859-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pQNOJMat_sendMessage);
      break;
    }
    case 0x40898D28: { // 1866-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_afLXrcJ9_sendMessage);
      break;
    }
    case 0x9D616407: { // 1866-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aG8VYCE0_sendMessage);
      break;
    }
    case 0xE8DBDB0: { // 1866-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1txFQGsz_sendMessage);
      break;
    }
    case 0xD770731A: { // 1866-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WVZeA7tg_sendMessage);
      break;
    }
    case 0x124CD18B: { // 1866-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yi5F4Zzf_sendMessage);
      break;
    }
    case 0x4017FCCD: { // 1866-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CUIvw89q_sendMessage);
      break;
    }
    case 0x1B1DD5FB: { // 1984-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bcRmYSrI_sendMessage);
      break;
    }
    case 0xA478FA4C: { // 1984-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TZ0gvdYN_sendMessage);
      break;
    }
    case 0x97EB3671: { // 1984-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_g6OG94uD_sendMessage);
      break;
    }
    case 0xF3FECDEE: { // 1984-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WpO7MRbC_sendMessage);
      break;
    }
    case 0x9558C335: { // 1984-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CrstBReX_sendMessage);
      break;
    }
    case 0x4131288C: { // 1984-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sRosxn5n_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xhrxL7jx_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_M3NGLR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Crshr";
        info->hash = 0xCFF7A234;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 2: {
        info->name = "High_Fldr";
        info->hash = 0x12EF45B9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 3: {
        info->name = "High_Gain";
        info->hash = 0xC05E9A15;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "High_Lmtr";
        info->hash = 0x8E596A67;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 5: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 6: {
        info->name = "High_Smthr";
        info->hash = 0x585E4A54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "High_Sqnc";
        info->hash = 0x14A9747F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 9: {
        info->name = "Low_Crshr";
        info->hash = 0xEBDB0C5E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 10: {
        info->name = "Low_Fldr";
        info->hash = 0xF974E926;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 11: {
        info->name = "Low_Gain";
        info->hash = 0xBB56D13C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Lmtr";
        info->hash = 0xB4EFBAC1;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 13: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 14: {
        info->name = "Low_Smthr";
        info->hash = 0x1665AEE9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 15: {
        info->name = "Low_Sqnc";
        info->hash = 0x860CA1D9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Crshr";
        info->hash = 0xEA9DEF12;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Fldr";
        info->hash = 0xDBF6FE0A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Gain";
        info->hash = 0x23F5E910;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 21: {
        info->name = "Mid_Lmtr";
        info->hash = 0x33C126B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 22: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 23: {
        info->name = "Mid_Smthr";
        info->hash = 0x64B1268F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 24: {
        info->name = "Mid_Sqnc";
        info->hash = 0xA91022F8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 25;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_M3NGLR::cVar_1rtcpRBW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_axngQP3x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_n0ak0z9R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R6MNyP7h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Y3zEhTQN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ek1f3pew_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_TD2GC48h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kkNBwRjp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_tapR9NCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ppy2vkvn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_OOav8DVl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LVax3AYo_sendMessage);
  cMsg_rKZGOZIb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_LVax3AYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OOav8DVl, 1, m, &cVar_OOav8DVl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_X8iHme26_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_msPD10S0_sendMessage(_c, 0, m);
  cMsg_lreVn81k_sendMessage(_c, 0, m);
  cMsg_uXHEUkbx_sendMessage(_c, 0, m);
  cMsg_EjVHrUdy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_rpqtljlv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bien8tI8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_GYD81vSg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HMcZMhxS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_5kaiuu8J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6cS0IWAu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_cSacIwHE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eBLLjJ1P_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tsZEk5og_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yASzfH3N_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vrFcI7Rs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4CEsFJq2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_VsKsucYJ, 0, m, &cSlice_VsKsucYJ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_yiOKtVqU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_VsKsucYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_CcTteCRu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_CcTteCRu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_CbuIeV5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CcTteCRu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_CcTteCRu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lawmpvUD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_uiep2mdK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_HnSqpyW8_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_OBcyzbkr, 0, m, &cIf_OBcyzbkr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_OBcyzbkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_lEVcBw1H_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_u49rLg3E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_qy6Fdo2w_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_zV6jpEeq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_bGEm4oVF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_spUeg2ix, HV_BINOP_POW, 0, m, &cBinop_spUeg2ix_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_spUeg2ix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9VxfmE58, 0, m, &cIf_9VxfmE58_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6UEmyrHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_AVejoCrG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0XIfuBBJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_zYgWiBlb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6cl1rhIx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_u49rLg3E, 0, m, &cIf_u49rLg3E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zYgWiBlb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_u49rLg3E, 1, m, &cIf_u49rLg3E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zV6jpEeq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_6UEmyrHX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qy6Fdo2w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_9VxfmE58, 0, m, &cIf_9VxfmE58_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AVejoCrG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_spUeg2ix, HV_BINOP_POW, 1, m, &cBinop_spUeg2ix_sendMessage);
  cMsg_bGEm4oVF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_9VxfmE58_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qHRECAJ5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_HnSqpyW8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OBcyzbkr, 1, m, &cIf_OBcyzbkr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lEVcBw1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Oo2I4Ecu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vw9IcGYR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Mm0sEJid_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0XIfuBBJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6cl1rhIx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XmRMtDuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9VxfmE58, 1, m, &cIf_9VxfmE58_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hhDnQfvf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zb9tDgMv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_zb9tDgMv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_qHRECAJ5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_y1EaIfGG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_Mm0sEJid_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vw9IcGYR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XmRMtDuO, HV_BINOP_GREATER_THAN, 1, m, &cBinop_XmRMtDuO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Oo2I4Ecu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hhDnQfvf, HV_BINOP_EQ, 1, m, &cBinop_hhDnQfvf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MASlewrO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uiep2mdK, 0, m, &cVar_uiep2mdK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tvztPqZ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XmRMtDuO, HV_BINOP_GREATER_THAN, 0, m, &cBinop_XmRMtDuO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_a50D5rhE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hhDnQfvf, HV_BINOP_EQ, 0, m, &cBinop_hhDnQfvf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Rex6lipK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y1EaIfGG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_RFsjrol7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Xb1AMoDy_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_P5b79Q7O, 0, m, &cIf_P5b79Q7O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_P5b79Q7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_UsnpJ5dB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_JwZnzNpc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_2tX6vAV0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_OSMjR20W_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_6e9Zo8U7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qQdJoMcM, HV_BINOP_POW, 0, m, &cBinop_qQdJoMcM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qQdJoMcM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_O64ICI4e, 0, m, &cIf_O64ICI4e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_c57UKnO7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_zQR352gg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0sWjVtxo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_OZf2xWv8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VvrnS6Es_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JwZnzNpc, 0, m, &cIf_JwZnzNpc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OZf2xWv8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JwZnzNpc, 1, m, &cIf_JwZnzNpc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OSMjR20W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_c57UKnO7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2tX6vAV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_O64ICI4e, 0, m, &cIf_O64ICI4e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zQR352gg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qQdJoMcM, HV_BINOP_POW, 1, m, &cBinop_qQdJoMcM_sendMessage);
  cMsg_6e9Zo8U7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_O64ICI4e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_f7IJAAPt_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Wq8IK9BC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_Xb1AMoDy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_P5b79Q7O, 1, m, &cIf_P5b79Q7O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UsnpJ5dB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V9CpVmHJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tOxcnHPZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UcpVQcif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0sWjVtxo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VvrnS6Es_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WdX2MICZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_O64ICI4e, 1, m, &cIf_O64ICI4e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fyGq5jCF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sKz442qe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_sKz442qe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_f7IJAAPt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Wq8IK9BC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_z95XQP2K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_UcpVQcif_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_V9CpVmHJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fyGq5jCF, HV_BINOP_EQ, 1, m, &cBinop_fyGq5jCF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tOxcnHPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WdX2MICZ, HV_BINOP_GREATER_THAN, 1, m, &cBinop_WdX2MICZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qBvcTdUH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fyGq5jCF, HV_BINOP_EQ, 0, m, &cBinop_fyGq5jCF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pSDXz4dP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_z95XQP2K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_o2o3FR9c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RFsjrol7, 0, m, &cVar_RFsjrol7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FLF1MO9f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WdX2MICZ, HV_BINOP_GREATER_THAN, 0, m, &cBinop_WdX2MICZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_KWbrqTsv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Ko0kNDly_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_GF0ZdhOM, 0, m, &cIf_GF0ZdhOM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_GF0ZdhOM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_2H1qdJHR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_aOaijEle_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Qt4mZVEN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_IvxTCdBv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_YWGXP4Yr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_V7IlGTkF, HV_BINOP_POW, 0, m, &cBinop_V7IlGTkF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_V7IlGTkF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cl8h2eqV, 0, m, &cIf_cl8h2eqV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_O4aE1bjV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_CiF4Wrvc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wjjMUEB6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aOaijEle, 0, m, &cIf_aOaijEle_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7GmrI4M2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_dmRly5Xg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dmRly5Xg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aOaijEle, 1, m, &cIf_aOaijEle_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IvxTCdBv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_O4aE1bjV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Qt4mZVEN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_cl8h2eqV, 0, m, &cIf_cl8h2eqV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CiF4Wrvc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V7IlGTkF, HV_BINOP_POW, 1, m, &cBinop_V7IlGTkF_sendMessage);
  cMsg_YWGXP4Yr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_cl8h2eqV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sS3GSWhy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_Ko0kNDly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GF0ZdhOM, 1, m, &cIf_GF0ZdhOM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2H1qdJHR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4P6LpG6N_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_i5afyCTB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ov8aoc0V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7GmrI4M2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wjjMUEB6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pqgOFibR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cl8h2eqV, 1, m, &cIf_cl8h2eqV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QK6hce9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5N9vszrq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5N9vszrq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_sS3GSWhy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ICNIfWrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_Ov8aoc0V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4P6LpG6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QK6hce9U, HV_BINOP_EQ, 1, m, &cBinop_QK6hce9U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_i5afyCTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pqgOFibR, HV_BINOP_GREATER_THAN, 1, m, &cBinop_pqgOFibR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_S1txKMzg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QK6hce9U, HV_BINOP_EQ, 0, m, &cBinop_QK6hce9U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ik8IFCfk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ICNIfWrJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_dv6w5WUp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KWbrqTsv, 0, m, &cVar_KWbrqTsv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TseyEptK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pqgOFibR, HV_BINOP_GREATER_THAN, 0, m, &cBinop_pqgOFibR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_dvmyzcMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UdgW0mGU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ePyxTWTH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3ezCgU5w, 0, m, &cSlice_3ezCgU5w_sendMessage);
      break;
    }
    default: {
      cSwitchcase_AlETQ4zc_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_3ezCgU5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_N3lrCjz8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_N3lrCjz8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_OGnTEunt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_N3lrCjz8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_N3lrCjz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TSibBAEv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_AlETQ4zc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_KJhk5QmV, 0, m, &cSlice_KJhk5QmV_sendMessage);
      break;
    }
    default: {
      cSwitchcase_4CEsFJq2_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_KJhk5QmV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_fbLLM3Vu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_fbLLM3Vu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_nBjOB8a2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fbLLM3Vu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_fbLLM3Vu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yCLL88G0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_yiOKtVqU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_OqQnfPoq, 0, m, &cSlice_OqQnfPoq_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Qhwt67OQ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_OqQnfPoq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_QceAGrhX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_QceAGrhX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_3tdKC5o6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QceAGrhX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_QceAGrhX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QlgPs0Pn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Qhwt67OQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_2knPGjg0, 0, m, &cSlice_2knPGjg0_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_2knPGjg0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qGFopzJB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qGFopzJB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_cNaiL7V1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qGFopzJB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_qGFopzJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UwLIShtH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6OduBRvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xzE6dU5K, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FGg1S3SO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QNmgPlwp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_SCrdmjeb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wM5aKWYy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ksjif8CM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dkMLcHqE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_AAqszRZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EkIBwZmn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Zzw7iewQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_slnuEOGH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_slnuEOGH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8UX6ymW9, HV_BINOP_DIVIDE, 1, m, &cBinop_8UX6ymW9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nNCRQa68_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_N90BRSKI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_OlkymsAR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kCCFDsfh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_N90BRSKI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OlkymsAR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8UX6ymW9, HV_BINOP_DIVIDE, 0, m, &cBinop_8UX6ymW9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nNCRQa68_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kCCFDsfh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_8UX6ymW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_d1NobOPN, HV_BINOP_MULTIPLY, 1, m, &cBinop_d1NobOPN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_d1NobOPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ys3AfGc8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1bnaKHoW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_8Byksiwf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lAWoq0rn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_H9TMuHke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1vE5WKzH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_SSWR2RfW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_xsEnHPUg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xsEnHPUg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_d1NobOPN, HV_BINOP_MULTIPLY, 0, m, &cBinop_d1NobOPN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3S0BXf4k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_xI56WBoN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xI56WBoN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qjycYjoL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ewKYvSkB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4CjgcEX8, 1, m, &cVar_4CjgcEX8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_4CjgcEX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KuWjCK7p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_CcuWOcKW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4pMoxTtf, HV_BINOP_MULTIPLY, 1, m, &cBinop_4pMoxTtf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sRHJXbL6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_CcuWOcKW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fiGlxxr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_y2AxZFti_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_y2AxZFti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0wJhe5pk, HV_BINOP_MULTIPLY, 1, m, &cBinop_0wJhe5pk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qFNonyEB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gS2r8i8G, HV_BINOP_MULTIPLY, 1, m, &cBinop_gS2r8i8G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mgzbWJJs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_qFNonyEB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5nwnxuCr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8g6c1Z1J, HV_BINOP_MULTIPLY, 1, m, &cBinop_8g6c1Z1J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_33OPi7DH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_awT7TPu2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_awT7TPu2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JnT7wEbc, HV_BINOP_MULTIPLY, 1, m, &cBinop_JnT7wEbc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_aoWBsKC4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YNlZodPs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_SSWR2RfW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rmWtN2Gg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_FWGDmW9G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_3S0BXf4k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1bnaKHoW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_H9TMuHke_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ys3AfGc8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_8Byksiwf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_lAWoq0rn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2HxPtPC7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_1vE5WKzH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PYXVUWc1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_7EzXnQP4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_T8AOSnTh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qjycYjoL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_44671vJp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_44671vJp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KdyltgR0, HV_BINOP_MULTIPLY, 1, m, &cBinop_KdyltgR0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KdyltgR0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_jlJ3I22W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jlJ3I22W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7EzXnQP4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_KuWjCK7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_HbGjah53_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HbGjah53_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DBy5f46s_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AsMkliOz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KMPuo8TT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oNoPWfLT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6jU6Cvti_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zcEXKdwz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4pMoxTtf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6OduBRvL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_0wJhe5pk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FGg1S3SO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_gS2r8i8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SCrdmjeb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_8g6c1Z1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ksjif8CM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_JnT7wEbc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AAqszRZY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_rnuRHZpN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aoWBsKC4, 0, m, &cVar_aoWBsKC4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VtaEXtwf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FWGDmW9G, 1, m, &cVar_FWGDmW9G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oNoPWfLT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gS2r8i8G, HV_BINOP_MULTIPLY, 0, m, &cBinop_gS2r8i8G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DBy5f46s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_zcEXKdwz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4pMoxTtf, HV_BINOP_MULTIPLY, 0, m, &cBinop_4pMoxTtf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KMPuo8TT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8g6c1Z1J, HV_BINOP_MULTIPLY, 0, m, &cBinop_8g6c1Z1J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6jU6Cvti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0wJhe5pk, HV_BINOP_MULTIPLY, 0, m, &cBinop_0wJhe5pk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AsMkliOz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JnT7wEbc, HV_BINOP_MULTIPLY, 0, m, &cBinop_JnT7wEbc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rmWtN2Gg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4CjgcEX8, 0, m, &cVar_4CjgcEX8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YNlZodPs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FWGDmW9G, 0, m, &cVar_FWGDmW9G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XYB28KHB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NVxjQnl8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FmpC3waL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SDGkcoaF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Nc4K3lDy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ALKocCTi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_KAyQ6pLh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XPo78D2W, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Cr1Fbptd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HwupW4k5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_HwupW4k5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xKJSNxMQ, HV_BINOP_DIVIDE, 1, m, &cBinop_xKJSNxMQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZfffY2af_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_q5BKgZ0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_KOz1tOeo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KztTDY4o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_q5BKgZ0x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KOz1tOeo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xKJSNxMQ, HV_BINOP_DIVIDE, 0, m, &cBinop_xKJSNxMQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZfffY2af_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KztTDY4o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_xKJSNxMQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1XDpaiOa, HV_BINOP_MULTIPLY, 1, m, &cBinop_1XDpaiOa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1XDpaiOa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m3XaFiii_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nn8xBjUM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_KICiDEjA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_03xM8Z72_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_E8ULYnbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1QNy02HZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_LLITEIQw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_w3VBYHP8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_w3VBYHP8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1XDpaiOa, HV_BINOP_MULTIPLY, 0, m, &cBinop_1XDpaiOa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ecrRWcb4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_Z94uMU8S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Z94uMU8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_k3MpGiKP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_cUQ6p99y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wck7DKCk, HV_BINOP_MULTIPLY, 1, m, &cBinop_Wck7DKCk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0iHzikMg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UiCHDLdn, 1, m, &cVar_UiCHDLdn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_g0JdSOcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K1IgWour, HV_BINOP_MULTIPLY, 1, m, &cBinop_K1IgWour_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rGPdlWlS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_7ZeT4trg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7ZeT4trg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MzRn2Tn1, HV_BINOP_MULTIPLY, 1, m, &cBinop_MzRn2Tn1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_UiCHDLdn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l2vjAYeA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_7j6EFgvQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZVK9Tf4n_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_LLITEIQw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fxSx7A7i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_VUCCKkx4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_ecrRWcb4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_m3XaFiii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_KICiDEjA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nn8xBjUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_E8ULYnbe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_03xM8Z72_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_75R5CVgs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_1QNy02HZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_I8Jbvq9G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_lON2GGZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rJVRUZJH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_k3MpGiKP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_UUlUeKcZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UUlUeKcZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5VuBizdq, HV_BINOP_MULTIPLY, 1, m, &cBinop_5VuBizdq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5VuBizdq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_1AWAMAl8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1AWAMAl8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lON2GGZL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_l2vjAYeA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_cngAAgzI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cngAAgzI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D9Mp3iyO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZQ33qs8L_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kgyierHc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Gz4dacU5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eEnNoL6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XYB28KHB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Wck7DKCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FmpC3waL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_K1IgWour_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Nc4K3lDy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_MzRn2Tn1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KAyQ6pLh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_dAJQuYbj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VUCCKkx4, 1, m, &cVar_VUCCKkx4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uRTZ7HvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7j6EFgvQ, 0, m, &cVar_7j6EFgvQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZVK9Tf4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VUCCKkx4, 0, m, &cVar_VUCCKkx4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fxSx7A7i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UiCHDLdn, 0, m, &cVar_UiCHDLdn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kgyierHc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wck7DKCk, HV_BINOP_MULTIPLY, 0, m, &cBinop_Wck7DKCk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZQ33qs8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K1IgWour, HV_BINOP_MULTIPLY, 0, m, &cBinop_K1IgWour_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Gz4dacU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eEnNoL6u, HV_BINOP_MULTIPLY, 0, m, &cBinop_eEnNoL6u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_D9Mp3iyO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MzRn2Tn1, HV_BINOP_MULTIPLY, 0, m, &cBinop_MzRn2Tn1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jA5Lh9pN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yexUL0vG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hx7U6wGH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FVCZeWQg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_rRjizDDF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tLlV6mpz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_2dcKDCEt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TBAKZDFl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_onZF1kfl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eXBMm8go, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qs8HKoWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_AYhAwIV6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_AYhAwIV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_02shqL1f, HV_BINOP_DIVIDE, 1, m, &cBinop_02shqL1f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ifiI2Mo5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_aKn1VHZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_5i75tcYB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_a0bI86wo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_aKn1VHZe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5i75tcYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_02shqL1f, HV_BINOP_DIVIDE, 0, m, &cBinop_02shqL1f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ifiI2Mo5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a0bI86wo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_02shqL1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9NkCPwy8, HV_BINOP_MULTIPLY, 1, m, &cBinop_9NkCPwy8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9NkCPwy8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uAJZKLhG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z8yg2U9E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_F8JBhJMF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dXKtiLHx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_9Y7cZvcR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5AIcPpLo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_WhzJ4JuM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_upuTKdVZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_upuTKdVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9NkCPwy8, HV_BINOP_MULTIPLY, 0, m, &cBinop_9NkCPwy8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XNZu5gZo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_A1jmnxRf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_A1jmnxRf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PqigfqEm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ikitDNjo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eOyDaL6Y, HV_BINOP_MULTIPLY, 1, m, &cBinop_eOyDaL6Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7Ruakr6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_WV7NzKdm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WV7NzKdm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ikitDNjo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ifWY9jHa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_BTGiMS9i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BTGiMS9i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iKf29xYd, HV_BINOP_MULTIPLY, 1, m, &cBinop_iKf29xYd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7FrXzIjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ksG9oyzO, HV_BINOP_MULTIPLY, 1, m, &cBinop_ksG9oyzO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9T0fgkk2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_F6suetdw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_F6suetdw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7FrXzIjb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_T6Eu7pQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uCQZRaxr, 1, m, &cVar_uCQZRaxr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vMXk0Ueo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_URkCFUBs, HV_BINOP_MULTIPLY, 1, m, &cBinop_URkCFUBs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jYOlMOWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_COkbAVlZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_COkbAVlZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0WnE5PCI, HV_BINOP_MULTIPLY, 1, m, &cBinop_0WnE5PCI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_uCQZRaxr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cnlkaRXw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_cf0irE00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4qrYmAuU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_WhzJ4JuM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CZ232O11_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_59LfuHYj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_XNZu5gZo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uAJZKLhG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_F8JBhJMF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_z8yg2U9E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_9Y7cZvcR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_dXKtiLHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_553Iso7K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_5AIcPpLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_14W1NNmd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_vHcLiCEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rcaGEspo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PqigfqEm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ONBwX0Au_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ONBwX0Au_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ECHVyQqx, HV_BINOP_MULTIPLY, 1, m, &cBinop_ECHVyQqx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ECHVyQqx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_2OHwg1Xb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2OHwg1Xb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vHcLiCEu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_cnlkaRXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_srN0lP2Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_srN0lP2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_y55ufC16_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_unFez692_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FDi4rK8B_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GYzOurjB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wjHJyDX0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hOrEg82s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eOyDaL6Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jA5Lh9pN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_iKf29xYd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hx7U6wGH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ksG9oyzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rRjizDDF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_URkCFUBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2dcKDCEt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_0WnE5PCI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_onZF1kfl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_HSSh4xfv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cf0irE00, 0, m, &cVar_cf0irE00_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UTqQg1Eb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_59LfuHYj, 1, m, &cVar_59LfuHYj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_y55ufC16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_hOrEg82s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eOyDaL6Y, HV_BINOP_MULTIPLY, 0, m, &cBinop_eOyDaL6Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FDi4rK8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_URkCFUBs, HV_BINOP_MULTIPLY, 0, m, &cBinop_URkCFUBs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wjHJyDX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iKf29xYd, HV_BINOP_MULTIPLY, 0, m, &cBinop_iKf29xYd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_unFez692_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0WnE5PCI, HV_BINOP_MULTIPLY, 0, m, &cBinop_0WnE5PCI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GYzOurjB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ksG9oyzO, HV_BINOP_MULTIPLY, 0, m, &cBinop_ksG9oyzO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CZ232O11_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uCQZRaxr, 0, m, &cVar_uCQZRaxr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4qrYmAuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_59LfuHYj, 0, m, &cVar_59LfuHYj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lbrSDkTm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dvmyzcMt, 1, m, &cIf_dvmyzcMt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JarakPAu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_UdgW0mGU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_bodMSSQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JarakPAu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_WqkBD5Fs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dvmyzcMt, 0, m, &cIf_dvmyzcMt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qHRECAJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mawsVzU3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_UdgW0mGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OwL1sSW8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_sS3GSWhy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wa75jf5a, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_f7IJAAPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_lbrSDkTm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bodMSSQL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Wq8IK9BC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_WqkBD5Fs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_LB7wfc1K_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zMIewIzW, 0, m, &cSlice_zMIewIzW_sendMessage);
      break;
    }
    default: {
      cSwitchcase_8tREUY3g_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_zMIewIzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Gv5AjN3c_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Gv5AjN3c_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_olQPGbyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Gv5AjN3c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Gv5AjN3c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fafaDxZn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_fGCSvT8A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_pREGU4oZ_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_p3vWFAKt, 0, m, &cIf_p3vWFAKt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_p3vWFAKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_THUKrnLJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_OrJfAzr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_nEVVnpSi_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_X1vAoUmx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_zvAsnrl9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_MWXKiS7t, HV_BINOP_POW, 0, m, &cBinop_MWXKiS7t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MWXKiS7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6HagrQdh, 0, m, &cIf_6HagrQdh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FtjAAyfR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_3swKioUW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Qt0WitI7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ngym0Vyk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tYSWPI6x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OrJfAzr7, 0, m, &cIf_OrJfAzr7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ngym0Vyk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OrJfAzr7, 1, m, &cIf_OrJfAzr7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_X1vAoUmx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_FtjAAyfR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nEVVnpSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_6HagrQdh, 0, m, &cIf_6HagrQdh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3swKioUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MWXKiS7t, HV_BINOP_POW, 1, m, &cBinop_MWXKiS7t_sendMessage);
  cMsg_zvAsnrl9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_6HagrQdh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YRXqInnz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_pREGU4oZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_p3vWFAKt, 1, m, &cIf_p3vWFAKt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_THUKrnLJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tMR5AHl5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XX1MxHzu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PNn0TrV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Qt0WitI7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tYSWPI6x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_B7gWrSjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6HagrQdh, 1, m, &cIf_6HagrQdh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PcF6ycMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4tm1KHjX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4tm1KHjX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_YRXqInnz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_tbJmRBfu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_PNn0TrV0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XX1MxHzu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B7gWrSjc, HV_BINOP_GREATER_THAN, 1, m, &cBinop_B7gWrSjc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tMR5AHl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PcF6ycMs, HV_BINOP_EQ, 1, m, &cBinop_PcF6ycMs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_d0bQcL2i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tbJmRBfu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_p9ql59ku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B7gWrSjc, HV_BINOP_GREATER_THAN, 0, m, &cBinop_B7gWrSjc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RtgPadxW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fGCSvT8A, 0, m, &cVar_fGCSvT8A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5wbfdt5H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PcF6ycMs, HV_BINOP_EQ, 0, m, &cBinop_PcF6ycMs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_fPQRrE0s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_uTigtWVs_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_qT9GbkrX, 0, m, &cIf_qT9GbkrX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_qT9GbkrX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_CygTzM7U_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_wvozEkPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_mAJ0NUfd_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_kwgJ9KWx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_5FcO0inG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xlxrp2SF, HV_BINOP_POW, 0, m, &cBinop_xlxrp2SF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xlxrp2SF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_G8IbKafE, 0, m, &cIf_G8IbKafE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ik4ZgWlP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_0vIhG9UN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fZjqMf4h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_P8399Gox_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BgEroylJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wvozEkPR, 0, m, &cIf_wvozEkPR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_P8399Gox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wvozEkPR, 1, m, &cIf_wvozEkPR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kwgJ9KWx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_ik4ZgWlP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mAJ0NUfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_G8IbKafE, 0, m, &cIf_G8IbKafE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0vIhG9UN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xlxrp2SF, HV_BINOP_POW, 1, m, &cBinop_xlxrp2SF_sendMessage);
  cMsg_5FcO0inG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_G8IbKafE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UQQC4dKY_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s6nAZaBH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_uTigtWVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qT9GbkrX, 1, m, &cIf_qT9GbkrX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CygTzM7U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lXdhIrpC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yKPjc0GN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RgW38IJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fZjqMf4h_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BgEroylJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dEHjxB7u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_G8IbKafE, 1, m, &cIf_G8IbKafE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FNvePRw6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PXRQIkUe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PXRQIkUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UQQC4dKY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s6nAZaBH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mARRx8bq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_RgW38IJt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yKPjc0GN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dEHjxB7u, HV_BINOP_GREATER_THAN, 1, m, &cBinop_dEHjxB7u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lXdhIrpC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FNvePRw6, HV_BINOP_EQ, 1, m, &cBinop_FNvePRw6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_u65geins_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fPQRrE0s, 0, m, &cVar_fPQRrE0s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HZgdvX4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dEHjxB7u, HV_BINOP_GREATER_THAN, 0, m, &cBinop_dEHjxB7u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jm80aMk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FNvePRw6, HV_BINOP_EQ, 0, m, &cBinop_FNvePRw6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uhYKSJiN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mARRx8bq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ZJeQA4mh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ZSay5oIB_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_dgxbQy7Y, 0, m, &cIf_dgxbQy7Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_dgxbQy7Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_NPm3i6Wa_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_U02Q0B62_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_dqnQKG8P_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_tnuI48fG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_Ww2AFeDK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZEkZjAay, HV_BINOP_POW, 0, m, &cBinop_ZEkZjAay_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZEkZjAay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Zx3Cxwga, 0, m, &cIf_Zx3Cxwga_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_towyIne0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_OF7Ex0e6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WhT9C9Bh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U02Q0B62, 0, m, &cIf_U02Q0B62_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fPpBouvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_OfxVKYhn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OfxVKYhn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U02Q0B62, 1, m, &cIf_U02Q0B62_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tnuI48fG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_towyIne0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dqnQKG8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Zx3Cxwga, 0, m, &cIf_Zx3Cxwga_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OF7Ex0e6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZEkZjAay, HV_BINOP_POW, 1, m, &cBinop_ZEkZjAay_sendMessage);
  cMsg_Ww2AFeDK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_Zx3Cxwga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uD685OQi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_ZSay5oIB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dgxbQy7Y, 1, m, &cIf_dgxbQy7Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NPm3i6Wa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TjG1SdPY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AH0q1duF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AgFpXIsj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fPpBouvP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WhT9C9Bh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nlUtfb2D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Zx3Cxwga, 1, m, &cIf_Zx3Cxwga_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Nv1kKZXI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_t1xRSWno_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_t1xRSWno_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_uD685OQi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_sp0cZ1nH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_AgFpXIsj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AH0q1duF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nlUtfb2D, HV_BINOP_GREATER_THAN, 1, m, &cBinop_nlUtfb2D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TjG1SdPY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Nv1kKZXI, HV_BINOP_EQ, 1, m, &cBinop_Nv1kKZXI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TK2p5fmd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Nv1kKZXI, HV_BINOP_EQ, 0, m, &cBinop_Nv1kKZXI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qpkHFIzg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sp0cZ1nH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Vy7Yk4f8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZJeQA4mh, 0, m, &cVar_ZJeQA4mh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3xrLN2po_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nlUtfb2D, HV_BINOP_GREATER_THAN, 0, m, &cBinop_nlUtfb2D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_zPcsPl6M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RI8uZwCW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_186j02Fr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GCpHv0Fc, 0, m, &cSlice_GCpHv0Fc_sendMessage);
      break;
    }
    default: {
      cSwitchcase_D4pgh72y_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_GCpHv0Fc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_3lpqkrZY_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_3lpqkrZY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_9aMUZ4LS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3lpqkrZY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_3lpqkrZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9w9DgtJK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_D4pgh72y_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_KKKhRgIw, 0, m, &cSlice_KKKhRgIw_sendMessage);
      break;
    }
    default: {
      cSwitchcase_LB7wfc1K_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_KKKhRgIw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_uaGEYxrR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_uaGEYxrR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_xyjqi6fw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uaGEYxrR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_uaGEYxrR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZUdG1JSt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_8tREUY3g_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9J9WVdkr, 0, m, &cSlice_9J9WVdkr_sendMessage);
      break;
    }
    default: {
      cSwitchcase_c9HlQSyd_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_9J9WVdkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_UVPsRYFz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_UVPsRYFz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_MXLzkZzs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UVPsRYFz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_UVPsRYFz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hgK6cwIU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_c9HlQSyd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_BhVRqS9s, 0, m, &cSlice_BhVRqS9s_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_BhVRqS9s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_iJK4DgcM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_iJK4DgcM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_SDVg9zrD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iJK4DgcM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_iJK4DgcM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1dSNCbAi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UAyyJ6Os_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UxYunt9Z, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_orSHcPm9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WxGO5sky, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_q7C3E6FO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2cyd2HI4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_QoUHXQ1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NGkbo151, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zgT4xBmy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KmrYJsfz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_UEYMecw2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_a4bY7Uwh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_a4bY7Uwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F7vI2hDI, HV_BINOP_DIVIDE, 1, m, &cBinop_F7vI2hDI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VSw1T8XT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_O7MxQJwM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_TDEjCWRp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CFwtKWYk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_O7MxQJwM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TDEjCWRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F7vI2hDI, HV_BINOP_DIVIDE, 0, m, &cBinop_F7vI2hDI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VSw1T8XT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CFwtKWYk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_F7vI2hDI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WAbj6MZo, HV_BINOP_MULTIPLY, 1, m, &cBinop_WAbj6MZo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WAbj6MZo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l8z5nioK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_U75pnO9h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_5BMobzlL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zTd2KnXR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_YfTiAZVg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YusiDrNu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_lGeg7WNE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_b8sJOexa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_b8sJOexa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WAbj6MZo, HV_BINOP_MULTIPLY, 0, m, &cBinop_WAbj6MZo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yY4UaoQf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_1Jq8VsNT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1Jq8VsNT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ErEj0F0r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_K63XJRJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_69pASwxu, 1, m, &cVar_69pASwxu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_69pASwxu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_23NfdkDj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_HuguaJqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NKG49AxJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_NKG49AxJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uxIDl6gS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_HuguaJqD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EGB39VHz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_WF0wG73l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WF0wG73l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WjtsJ35C, HV_BINOP_MULTIPLY, 1, m, &cBinop_WjtsJ35C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zTTIJ3xs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zfW3QBJu, HV_BINOP_MULTIPLY, 1, m, &cBinop_zfW3QBJu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VynF1Ooz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zTTIJ3xs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZZmK87fo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FwCWtARW, HV_BINOP_MULTIPLY, 1, m, &cBinop_FwCWtARW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NN6SIK3m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_zNDd7X78_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zNDd7X78_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sTdd8YeT, HV_BINOP_MULTIPLY, 1, m, &cBinop_sTdd8YeT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_2eYvfeT1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uruO5IIZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_lGeg7WNE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_snyIIKGJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_A3s9Cj0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_yY4UaoQf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_l8z5nioK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_5BMobzlL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_U75pnO9h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_YfTiAZVg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_zTd2KnXR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vCySTAWn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_YusiDrNu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5pl9RoFh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_P8o4YB7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HOVjzIAH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ErEj0F0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_yMADl6Gk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yMADl6Gk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qfl4goeV, HV_BINOP_MULTIPLY, 1, m, &cBinop_Qfl4goeV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Qfl4goeV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_vbcS9KOw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vbcS9KOw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_P8o4YB7F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_23NfdkDj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_z9ytQzA2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_z9ytQzA2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DpgHvkaI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BhDNNNcZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fciUhnTV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_w6KfEt6r_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E0OH0qyB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UbZQTc3E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NKG49AxJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UAyyJ6Os_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_WjtsJ35C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_orSHcPm9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_zfW3QBJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q7C3E6FO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_FwCWtARW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QoUHXQ1C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_sTdd8YeT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zgT4xBmy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_yMcqfN8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2eYvfeT1, 0, m, &cVar_2eYvfeT1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AL1nAadw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_A3s9Cj0J, 1, m, &cVar_A3s9Cj0J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DpgHvkaI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_UbZQTc3E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NKG49AxJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_NKG49AxJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fciUhnTV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FwCWtARW, HV_BINOP_MULTIPLY, 0, m, &cBinop_FwCWtARW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_E0OH0qyB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WjtsJ35C, HV_BINOP_MULTIPLY, 0, m, &cBinop_WjtsJ35C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BhDNNNcZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sTdd8YeT, HV_BINOP_MULTIPLY, 0, m, &cBinop_sTdd8YeT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_w6KfEt6r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zfW3QBJu, HV_BINOP_MULTIPLY, 0, m, &cBinop_zfW3QBJu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_snyIIKGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_69pASwxu, 0, m, &cVar_69pASwxu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uruO5IIZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_A3s9Cj0J, 0, m, &cVar_A3s9Cj0J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wRACt7IF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_q0M14IhK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_KWhp8pHK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ep96rZYL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HOfKS8Ir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_slHWrL6L, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_2j2Gqnod_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8m9lBJHp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_BtKHpq92_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rYUXshoz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_rYUXshoz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_awJpMbkI, HV_BINOP_DIVIDE, 1, m, &cBinop_awJpMbkI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7ClaPPWY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_s9DtTXJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_FpeM2aNU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KT6853ga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_s9DtTXJo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FpeM2aNU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_awJpMbkI, HV_BINOP_DIVIDE, 0, m, &cBinop_awJpMbkI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7ClaPPWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KT6853ga_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_awJpMbkI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZgCmRGiX, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZgCmRGiX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZgCmRGiX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_W7qdK36G_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RGRWLZ0Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_T1AaBMhp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OLz3fvx8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_3P6IWp6m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PHVvdPfU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_PBvmCiUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_9rxYUGqr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9rxYUGqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZgCmRGiX, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZgCmRGiX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2lZux33e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_MJ9wWXHa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MJ9wWXHa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7dnHFRdT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_dL7ABZsS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k3qgQYCf, HV_BINOP_MULTIPLY, 1, m, &cBinop_k3qgQYCf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5SRwg7wl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xCGQrGGP, 1, m, &cVar_xCGQrGGP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_U8EG0f4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UO7eZAqF, HV_BINOP_MULTIPLY, 1, m, &cBinop_UO7eZAqF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dZJPCc4h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_4BTFCpC5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4BTFCpC5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_89mF8LDw, HV_BINOP_MULTIPLY, 1, m, &cBinop_89mF8LDw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_xCGQrGGP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ScGK23XK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_vViOuSws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CjdSnc2r_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_PBvmCiUk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MF932oK8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_7CP3BMfI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_2lZux33e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_W7qdK36G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_T1AaBMhp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RGRWLZ0Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_3P6IWp6m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_OLz3fvx8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8R13FmlE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_PHVvdPfU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fTJ8jQhJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_V3CsYcvo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7CUWnQnI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7dnHFRdT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_JFF80xE3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JFF80xE3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b8WCUmAD, HV_BINOP_MULTIPLY, 1, m, &cBinop_b8WCUmAD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_b8WCUmAD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_K7g7rKwA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_K7g7rKwA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_V3CsYcvo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ScGK23XK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_1au5bYEb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1au5bYEb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_h2FpJ9pR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zO198adf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UGVx8ptG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4aEzikJn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JflyvtUp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wRACt7IF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_k3qgQYCf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KWhp8pHK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_UO7eZAqF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HOfKS8Ir_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_89mF8LDw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2j2Gqnod_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_TafYfLDm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7CP3BMfI, 1, m, &cVar_7CP3BMfI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_j6vJHS8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vViOuSws, 0, m, &cVar_vViOuSws_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MF932oK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xCGQrGGP, 0, m, &cVar_xCGQrGGP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CjdSnc2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7CP3BMfI, 0, m, &cVar_7CP3BMfI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UGVx8ptG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k3qgQYCf, HV_BINOP_MULTIPLY, 0, m, &cBinop_k3qgQYCf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zO198adf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UO7eZAqF, HV_BINOP_MULTIPLY, 0, m, &cBinop_UO7eZAqF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4aEzikJn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JflyvtUp, HV_BINOP_MULTIPLY, 0, m, &cBinop_JflyvtUp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_h2FpJ9pR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_89mF8LDw, HV_BINOP_MULTIPLY, 0, m, &cBinop_89mF8LDw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cAoM8Jo2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FA8cnVyE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yIyalFCB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KdNFiuFT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zJ5vMARR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jwfWwdB7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_DBLKBBdR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_luAPr5kk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_46Jkb6BL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EIWIIEoV, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_cKvcZXPY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_im0RsBd2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_im0RsBd2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E542eAUk, HV_BINOP_DIVIDE, 1, m, &cBinop_E542eAUk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vSEWNfEn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_m9xFANSE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Hzim2WzX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XF6ImWwW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_m9xFANSE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Hzim2WzX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E542eAUk, HV_BINOP_DIVIDE, 0, m, &cBinop_E542eAUk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vSEWNfEn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XF6ImWwW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_E542eAUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GWrE8OaU, HV_BINOP_MULTIPLY, 1, m, &cBinop_GWrE8OaU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GWrE8OaU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_49n4meSm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lb6ce7MQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_XHqxjO5J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XC0CgNLP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_jPmISR3O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QmhvrLAz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_HuCrHivv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_BGxqxVFJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BGxqxVFJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GWrE8OaU, HV_BINOP_MULTIPLY, 0, m, &cBinop_GWrE8OaU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aFYReJHY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_6AWIdch9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6AWIdch9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qFIZDgu8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_r22jPD3p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5zwROeys, HV_BINOP_MULTIPLY, 1, m, &cBinop_5zwROeys_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zO1QrZTI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_gt9eoyik_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gt9eoyik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_r22jPD3p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wxk2zNFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_DSus3M0z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DSus3M0z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yXyxKM0I, HV_BINOP_MULTIPLY, 1, m, &cBinop_yXyxKM0I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DU8U5APJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7pAycBPi, HV_BINOP_MULTIPLY, 1, m, &cBinop_7pAycBPi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UpOMlOlc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_iMrXWS72_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iMrXWS72_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_DU8U5APJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_W9AC9kNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9QFznsvg, 1, m, &cVar_9QFznsvg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_J7jvZiAV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ClXT6Vmk, HV_BINOP_MULTIPLY, 1, m, &cBinop_ClXT6Vmk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_huTxSDsK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_sZgny0si_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sZgny0si_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LVYmrQeS, HV_BINOP_MULTIPLY, 1, m, &cBinop_LVYmrQeS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_9QFznsvg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cfrZ3MOn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_IFkzGaee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1tBJEqDB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_HuCrHivv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_S1oOkASO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_FWF0CzRG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_aFYReJHY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lb6ce7MQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_jPmISR3O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_49n4meSm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_XHqxjO5J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_XC0CgNLP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xZ9FaN6I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_QmhvrLAz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cnKnw0gR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_cTFCbjqR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ul7mgnHj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qFIZDgu8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_nGbiSngL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nGbiSngL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7ALrXqSG, HV_BINOP_MULTIPLY, 1, m, &cBinop_7ALrXqSG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7ALrXqSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_43a4Guhe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_43a4Guhe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cTFCbjqR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_cfrZ3MOn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_PMqf7yeG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PMqf7yeG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NLgoMkzb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TtkiJG7l_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pK0Sd61Y_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bLgvhrnf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xvjiaRhA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pz3KvIRX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5zwROeys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cAoM8Jo2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_yXyxKM0I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yIyalFCB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_7pAycBPi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zJ5vMARR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ClXT6Vmk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DBLKBBdR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_LVYmrQeS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_46Jkb6BL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_F3Y0yBBv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FWF0CzRG, 1, m, &cVar_FWF0CzRG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GV5fbBTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IFkzGaee, 0, m, &cVar_IFkzGaee_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bLgvhrnf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7pAycBPi, HV_BINOP_MULTIPLY, 0, m, &cBinop_7pAycBPi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NLgoMkzb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_pz3KvIRX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5zwROeys, HV_BINOP_MULTIPLY, 0, m, &cBinop_5zwROeys_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pK0Sd61Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ClXT6Vmk, HV_BINOP_MULTIPLY, 0, m, &cBinop_ClXT6Vmk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xvjiaRhA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yXyxKM0I, HV_BINOP_MULTIPLY, 0, m, &cBinop_yXyxKM0I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TtkiJG7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LVYmrQeS, HV_BINOP_MULTIPLY, 0, m, &cBinop_LVYmrQeS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1tBJEqDB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FWF0CzRG, 0, m, &cVar_FWF0CzRG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_S1oOkASO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9QFznsvg, 0, m, &cVar_9QFznsvg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tf45vCrS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zPcsPl6M, 1, m, &cIf_zPcsPl6M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_H5PG9AHQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_RI8uZwCW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_2lWLmj9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H5PG9AHQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_OIBAWpPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zPcsPl6M, 0, m, &cIf_zPcsPl6M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YRXqInnz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SToXVaC3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_RI8uZwCW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NVP5gANv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_uD685OQi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ytDMHiuZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_UQQC4dKY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_tf45vCrS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2lWLmj9b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_s6nAZaBH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_OIBAWpPR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_TPBrwfmc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rViMwwBz, HV_BINOP_DIVIDE, 0, m, &cBinop_rViMwwBz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_9v982nhZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7qTTTcZw, HV_BINOP_DIVIDE, 1, m, &cBinop_7qTTTcZw_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rViMwwBz, HV_BINOP_DIVIDE, 1, m, &cBinop_rViMwwBz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_ins91cyz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qGEhFU1l, HV_BINOP_DIVIDE, 0, m, &cBinop_qGEhFU1l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_PeofQg7X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qGEhFU1l, HV_BINOP_DIVIDE, 1, m, &cBinop_qGEhFU1l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yASzfH3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TPBrwfmc, 0, m, &cVar_TPBrwfmc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tsZEk5og_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9v982nhZ, 0, m, &cVar_9v982nhZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vrFcI7Rs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7qTTTcZw, HV_BINOP_DIVIDE, 0, m, &cBinop_7qTTTcZw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7qTTTcZw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_ins91cyz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rViMwwBz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_PeofQg7X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qGEhFU1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_DP9VWBK7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_bsaObVyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_mJaQ7bx9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hgdgEO9E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_SMEB7ABK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DP9VWBK7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_hgdgEO9E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SMEB7ABK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_bsaObVyV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mJaQ7bx9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Aevld0Fq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_t29WPkeB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_i65wIapF, 0, m, &cSlice_i65wIapF_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_i65wIapF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5LksoC7S_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5LksoC7S_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_0x7J47mD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5LksoC7S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_5LksoC7S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sDMRjJdm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_iWIkr1kZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_NYNoTN5v_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NYNoTN5v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_hBjgS5PB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hBjgS5PB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_RdGGthLC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RdGGthLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cG0WrvZ1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SjuK7sqY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SjuK7sqY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GY9pvHre_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_cG0WrvZ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Bv2dYHou_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Bv2dYHou_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_3KE2eUse_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GY9pvHre_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_DaBSX6Xf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DaBSX6Xf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_MOOpJwP3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3KE2eUse_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rveKNr9W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_MOOpJwP3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tR1G4J43_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rveKNr9W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RFeTYkdi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tR1G4J43_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KCVjVWAO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_IBcdgxWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sb7VpBxp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_r8wfZLqX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LN7BR8uy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_jczo023Q_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a4AhMhYo_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ek8a3vt1_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JhazGsoz_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yLkLFqAA_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mcViQr47_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VDrpXxfc_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_a4AhMhYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fAsybNbR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Ek8a3vt1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KJArjarr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_JhazGsoz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GSAqZLeW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_yLkLFqAA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZZDVqQix_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_mcViQr47_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TPXkhcxP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_VDrpXxfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ngPfk9XT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_LytZMXta_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mJOHkQBt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Yq9qYhrr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BkhzzGaw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_vs0BAuSN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_QbAishYc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_QbAishYc_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_scty9HDL, 1, m, &cDelay_scty9HDL_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UBwvKNjn_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_scty9HDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_scty9HDL, m);
  cIf_onMessage(_c, &Context(_c)->cIf_LytZMXta, 0, m, &cIf_LytZMXta_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QbAishYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_scty9HDL, 0, m, &cDelay_scty9HDL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UBwvKNjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_scty9HDL, 0, m, &cDelay_scty9HDL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_l5hSbTFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZMqnrgbQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z3ofO5sD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_C3q8aOry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lyUyfrnP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oNTo8dvw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lyUyfrnP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LytZMXta, 1, m, &cIf_LytZMXta_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oNTo8dvw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_vs0BAuSN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ZMqnrgbQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Yq9qYhrr, 1, m, &cIf_Yq9qYhrr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_z3ofO5sD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Yq9qYhrr, 0, m, &cIf_Yq9qYhrr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BkhzzGaw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Y8nZLxwb, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_mJOHkQBt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Y8nZLxwb, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_oom8aqMi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WhI3wZDl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_wkR0KBAe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gRasR2yQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Fv31OGLz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_96mwHTmP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_96mwHTmP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_aAK4xb0b, 1, m, &cDelay_aAK4xb0b_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uKkaDbNp_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_aAK4xb0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_aAK4xb0b, m);
  cIf_onMessage(_c, &Context(_c)->cIf_oom8aqMi, 0, m, &cIf_oom8aqMi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_96mwHTmP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_aAK4xb0b, 0, m, &cDelay_aAK4xb0b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uKkaDbNp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_aAK4xb0b, 0, m, &cDelay_aAK4xb0b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZOU3LxyB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tGaCm15m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_t5MLi7PI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mGIcmNy6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HkjMnAXC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LXhU0h8n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HkjMnAXC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oom8aqMi, 1, m, &cIf_oom8aqMi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LXhU0h8n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Fv31OGLz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_tGaCm15m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wkR0KBAe, 1, m, &cIf_wkR0KBAe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_t5MLi7PI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wkR0KBAe, 0, m, &cIf_wkR0KBAe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gRasR2yQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1cgHQtsR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_WhI3wZDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1cgHQtsR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_RSmn0pkq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0QC022JK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_5hacUM1Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vJfnzTkN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_YASZLhjL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_c2rZUlZ3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_c2rZUlZ3_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_LLrPLOd8, 1, m, &cDelay_LLrPLOd8_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_K5zXBYPw_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_LLrPLOd8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LLrPLOd8, m);
  cIf_onMessage(_c, &Context(_c)->cIf_RSmn0pkq, 0, m, &cIf_RSmn0pkq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_c2rZUlZ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_LLrPLOd8, 0, m, &cDelay_LLrPLOd8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_K5zXBYPw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_LLrPLOd8, 0, m, &cDelay_LLrPLOd8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nJdos7DH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tlJIpBlz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uPZTlUqd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ohGDzizA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9wkrn4ru_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aA6vMt1k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9wkrn4ru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RSmn0pkq, 1, m, &cIf_RSmn0pkq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aA6vMt1k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_YASZLhjL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_uPZTlUqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5hacUM1Y, 0, m, &cIf_5hacUM1Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tlJIpBlz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5hacUM1Y, 1, m, &cIf_5hacUM1Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vJfnzTkN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_n294RCd6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0QC022JK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_n294RCd6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Dxs02FeK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_r3fnKYVV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_kze2KA10_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aUqdzYUg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_odK3aRXP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_0IPxHY8f_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_0IPxHY8f_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_waqHaLjN, 1, m, &cDelay_waqHaLjN_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YMRKzwD4_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_waqHaLjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_waqHaLjN, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Dxs02FeK, 0, m, &cIf_Dxs02FeK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0IPxHY8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_waqHaLjN, 0, m, &cDelay_waqHaLjN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YMRKzwD4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_waqHaLjN, 0, m, &cDelay_waqHaLjN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EI9NN4hE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_itezif6w_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UBrlzuce_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_O8QZjyi1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7vXk8YQQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4hCJC3vO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4hCJC3vO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_odK3aRXP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_7vXk8YQQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Dxs02FeK, 1, m, &cIf_Dxs02FeK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UBrlzuce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kze2KA10, 0, m, &cIf_kze2KA10_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_itezif6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kze2KA10, 1, m, &cIf_kze2KA10_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aUqdzYUg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HQ6Xu0B9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_r3fnKYVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HQ6Xu0B9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_V4FH86Jf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PABwImzi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_P0RgNRja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Zqv1ZUg3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9JiUeo0t_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_7rdfJlrB_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_7rdfJlrB_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_WDhmTAOO, 1, m, &cDelay_WDhmTAOO_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F34LOHIp_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_WDhmTAOO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WDhmTAOO, m);
  cIf_onMessage(_c, &Context(_c)->cIf_V4FH86Jf, 0, m, &cIf_V4FH86Jf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7rdfJlrB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_WDhmTAOO, 0, m, &cDelay_WDhmTAOO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_F34LOHIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WDhmTAOO, 0, m, &cDelay_WDhmTAOO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_O0lkmtHP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jCCOcUM1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qjcMEUaZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uSsuYBjq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0ebXdnQs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lFxHPgvO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lFxHPgvO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9JiUeo0t_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_0ebXdnQs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_V4FH86Jf, 1, m, &cIf_V4FH86Jf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qjcMEUaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_P0RgNRja, 0, m, &cIf_P0RgNRja_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jCCOcUM1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_P0RgNRja, 1, m, &cIf_P0RgNRja_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Zqv1ZUg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NsFpXWm1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_PABwImzi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NsFpXWm1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_VaSGk8hN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KZ2txO1D_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_kEkRTH7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_a8hkXkK7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_E2iprob2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_3fAW972W_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_3fAW972W_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_BHG69H8v, 1, m, &cDelay_BHG69H8v_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2OdQL9Zb_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_BHG69H8v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BHG69H8v, m);
  cIf_onMessage(_c, &Context(_c)->cIf_VaSGk8hN, 0, m, &cIf_VaSGk8hN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3fAW972W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_BHG69H8v, 0, m, &cDelay_BHG69H8v_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2OdQL9Zb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BHG69H8v, 0, m, &cDelay_BHG69H8v_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DCk09axs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7WwMZALy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FnaJXhHn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cQfi0285_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZFS3rpOT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tAMmWukq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZFS3rpOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VaSGk8hN, 1, m, &cIf_VaSGk8hN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tAMmWukq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_E2iprob2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_FnaJXhHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kEkRTH7x, 0, m, &cIf_kEkRTH7x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7WwMZALy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kEkRTH7x, 1, m, &cIf_kEkRTH7x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_a8hkXkK7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gJc8PNeP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_KZ2txO1D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gJc8PNeP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_y7bhcqfe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FxYkLcsI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_IRXWTNsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SRJucTTh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_A6Z6knLv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_fL4GOKKT_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_fL4GOKKT_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_5wijxg8L, 1, m, &cDelay_5wijxg8L_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qE7tFpVJ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_5wijxg8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5wijxg8L, m);
  cIf_onMessage(_c, &Context(_c)->cIf_y7bhcqfe, 0, m, &cIf_y7bhcqfe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fL4GOKKT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_5wijxg8L, 0, m, &cDelay_5wijxg8L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qE7tFpVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5wijxg8L, 0, m, &cDelay_5wijxg8L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hV0AELwH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LiQWm8bd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ivqzivzj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0oZJydaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_q34fGoJg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NSvRaTuK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_q34fGoJg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_y7bhcqfe, 1, m, &cIf_y7bhcqfe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NSvRaTuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_A6Z6knLv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_LiQWm8bd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IRXWTNsy, 1, m, &cIf_IRXWTNsy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ivqzivzj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IRXWTNsy, 0, m, &cIf_IRXWTNsy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SRJucTTh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_clx4w716, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FxYkLcsI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_clx4w716, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Hkwua7Y1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_J9JRUKMW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_3YJVNkYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_T7VppxEh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_J53hwJri_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_F0m4NN2A_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_F0m4NN2A_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ORjxiAFh, 1, m, &cDelay_ORjxiAFh_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YsHQTa4k_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ORjxiAFh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ORjxiAFh, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Hkwua7Y1, 0, m, &cIf_Hkwua7Y1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_F0m4NN2A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ORjxiAFh, 0, m, &cDelay_ORjxiAFh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YsHQTa4k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ORjxiAFh, 0, m, &cDelay_ORjxiAFh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VfgD1R1L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2MnedIFC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tj54MZM8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ufCnWLNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CprpThFf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9uJxo3Xh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CprpThFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hkwua7Y1, 1, m, &cIf_Hkwua7Y1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9uJxo3Xh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_J53hwJri_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_2MnedIFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3YJVNkYT, 1, m, &cIf_3YJVNkYT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tj54MZM8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3YJVNkYT, 0, m, &cIf_3YJVNkYT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_T7VppxEh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IADvtpRx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_J9JRUKMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IADvtpRx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_KZdIjpDe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8a8dvVSR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_8aYRA4T1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6HwIRCbh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Rmsw2lLR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_GcyS13tD_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_GcyS13tD_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_m1TTw6Pa, 1, m, &cDelay_m1TTw6Pa_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oAdNYZ1E_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_m1TTw6Pa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_m1TTw6Pa, m);
  cIf_onMessage(_c, &Context(_c)->cIf_KZdIjpDe, 0, m, &cIf_KZdIjpDe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GcyS13tD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_m1TTw6Pa, 0, m, &cDelay_m1TTw6Pa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oAdNYZ1E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_m1TTw6Pa, 0, m, &cDelay_m1TTw6Pa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vtg56Eo6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jnx96Mel_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MJEec9MD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RpCnljGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x8Sx6MRV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P1vYaqx5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_P1vYaqx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Rmsw2lLR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_x8Sx6MRV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KZdIjpDe, 1, m, &cIf_KZdIjpDe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jnx96Mel_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8aYRA4T1, 1, m, &cIf_8aYRA4T1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MJEec9MD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8aYRA4T1, 0, m, &cIf_8aYRA4T1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6HwIRCbh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EFn9NHaU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_8a8dvVSR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EFn9NHaU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_uyPS3YvW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_egeLaWXf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_7l69yQ9n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PAtUvP4A_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_wc06kb0L_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_PfRsNhMj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_PfRsNhMj_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_zlP0HDtv, 1, m, &cDelay_zlP0HDtv_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kftSMSOc_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_zlP0HDtv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zlP0HDtv, m);
  cIf_onMessage(_c, &Context(_c)->cIf_uyPS3YvW, 0, m, &cIf_uyPS3YvW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PfRsNhMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zlP0HDtv, 0, m, &cDelay_zlP0HDtv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kftSMSOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zlP0HDtv, 0, m, &cDelay_zlP0HDtv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uKEzE8P4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RvxxRm3d_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jdr31iVJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dxZJltdi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Vp2FgTuZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Hz94RRVh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Hz94RRVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_wc06kb0L_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Vp2FgTuZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uyPS3YvW, 1, m, &cIf_uyPS3YvW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jdr31iVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7l69yQ9n, 0, m, &cIf_7l69yQ9n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RvxxRm3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7l69yQ9n, 1, m, &cIf_7l69yQ9n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PAtUvP4A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8a6MMoqJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_egeLaWXf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8a6MMoqJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_dmoOvVW7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Oow11DzI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_4VNiifGi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TkvmN3lZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_SxW1JZ1x_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ZAn5ryLC_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ZAn5ryLC_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_p7h0bdAC, 1, m, &cDelay_p7h0bdAC_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5jpT9QDR_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_p7h0bdAC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_p7h0bdAC, m);
  cIf_onMessage(_c, &Context(_c)->cIf_dmoOvVW7, 0, m, &cIf_dmoOvVW7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZAn5ryLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_p7h0bdAC, 0, m, &cDelay_p7h0bdAC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5jpT9QDR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_p7h0bdAC, 0, m, &cDelay_p7h0bdAC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CmInowvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5iQwc7P6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_smt5K0pa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PAUU9WDZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cKLWkdOb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hxzF4bJe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cKLWkdOb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dmoOvVW7, 1, m, &cIf_dmoOvVW7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hxzF4bJe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_SxW1JZ1x_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_5iQwc7P6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4VNiifGi, 1, m, &cIf_4VNiifGi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_smt5K0pa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4VNiifGi, 0, m, &cIf_4VNiifGi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TkvmN3lZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RIykccS3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Oow11DzI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RIykccS3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_fmsNEt2c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_r25ZfB8m_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_NAtROjtR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JxTqE7kk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_XuAGUhrY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_7BY89CsP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_7BY89CsP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_4E698XfB, 1, m, &cDelay_4E698XfB_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q0OiRD09_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_4E698XfB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4E698XfB, m);
  cIf_onMessage(_c, &Context(_c)->cIf_fmsNEt2c, 0, m, &cIf_fmsNEt2c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7BY89CsP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4E698XfB, 0, m, &cDelay_4E698XfB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Q0OiRD09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4E698XfB, 0, m, &cDelay_4E698XfB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ipt2MgCe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l7YjJtFL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oQjJfHPE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mPZbOaRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q7iRQRQu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7txMUc1J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Q7iRQRQu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fmsNEt2c, 1, m, &cIf_fmsNEt2c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7txMUc1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_XuAGUhrY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_l7YjJtFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NAtROjtR, 1, m, &cIf_NAtROjtR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oQjJfHPE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NAtROjtR, 0, m, &cIf_NAtROjtR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JxTqE7kk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7aXjVofq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_r25ZfB8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7aXjVofq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_fAsybNbR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_KGO6NrNn_sendMessage(_c, 0, m);
  cMsg_4b85cmyb_sendMessage(_c, 0, m);
  cMsg_fpRYnIbb_sendMessage(_c, 0, m);
  cMsg_yzIel2aE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_KJArjarr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_KGO6NrNn_sendMessage(_c, 0, m);
  cMsg_wrSLLt46_sendMessage(_c, 0, m);
  cMsg_ptXSKbq9_sendMessage(_c, 0, m);
  cMsg_KizcM2Xs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GSAqZLeW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_hF6v8DNW_sendMessage(_c, 0, m);
  cMsg_wrSLLt46_sendMessage(_c, 0, m);
  cMsg_yzIel2aE_sendMessage(_c, 0, m);
  cMsg_FVQ9ekl5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ZZDVqQix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_hF6v8DNW_sendMessage(_c, 0, m);
  cMsg_JaQiZSbW_sendMessage(_c, 0, m);
  cMsg_fpRYnIbb_sendMessage(_c, 0, m);
  cMsg_cSydjsvA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_TPXkhcxP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_KOuA0RZ5_sendMessage(_c, 0, m);
  cMsg_KizcM2Xs_sendMessage(_c, 0, m);
  cMsg_6uU0uz9P_sendMessage(_c, 0, m);
  cMsg_fpRYnIbb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ngPfk9XT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_KOuA0RZ5_sendMessage(_c, 0, m);
  cMsg_cSydjsvA_sendMessage(_c, 0, m);
  cMsg_wrSLLt46_sendMessage(_c, 0, m);
  cMsg_5lJwzcoT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kQi8bGoG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_C3q8aOry_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_l5hSbTFm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_k8r68Quw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_C3q8aOry_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_l5hSbTFm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mGtciPfP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mGIcmNy6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZOU3LxyB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VkNkL50r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mGIcmNy6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZOU3LxyB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mYJwE1oK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ohGDzizA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nJdos7DH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_P1Go2dxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ohGDzizA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nJdos7DH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KGO6NrNn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_kQi8bGoG_sendMessage(_c, 0, m);
  cMsg_VkNkL50r_sendMessage(_c, 0, m);
  cMsg_P1Go2dxp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_hF6v8DNW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_k8r68Quw_sendMessage(_c, 0, m);
  cMsg_mGtciPfP_sendMessage(_c, 0, m);
  cMsg_P1Go2dxp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_KOuA0RZ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_k8r68Quw_sendMessage(_c, 0, m);
  cMsg_VkNkL50r_sendMessage(_c, 0, m);
  cMsg_mYJwE1oK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_v9Jlm8PF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_O8QZjyi1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EI9NN4hE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GRiOpIsl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_O8QZjyi1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EI9NN4hE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gQdr16m9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_uSsuYBjq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_O0lkmtHP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AFsTsZQv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_uSsuYBjq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_O0lkmtHP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EDDpNrvR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cQfi0285_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DCk09axs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MXMwzRIw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cQfi0285_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DCk09axs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wrSLLt46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_GRiOpIsl_sendMessage(_c, 0, m);
  cMsg_AFsTsZQv_sendMessage(_c, 0, m);
  cMsg_MXMwzRIw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4b85cmyb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_GRiOpIsl_sendMessage(_c, 0, m);
  cMsg_gQdr16m9_sendMessage(_c, 0, m);
  cMsg_EDDpNrvR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JaQiZSbW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_v9Jlm8PF_sendMessage(_c, 0, m);
  cMsg_AFsTsZQv_sendMessage(_c, 0, m);
  cMsg_EDDpNrvR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_eEMw0dq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dxZJltdi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uKEzE8P4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lzDUSi3E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dxZJltdi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uKEzE8P4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SBgc0cVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PAUU9WDZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CmInowvF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RFP84YX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PAUU9WDZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CmInowvF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YiBsX8Eh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mPZbOaRM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ipt2MgCe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0DEuIucd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mPZbOaRM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ipt2MgCe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cSydjsvA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_eEMw0dq8_sendMessage(_c, 0, m);
  cMsg_RFP84YX8_sendMessage(_c, 0, m);
  cMsg_0DEuIucd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_KizcM2Xs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_lzDUSi3E_sendMessage(_c, 0, m);
  cMsg_SBgc0cVU_sendMessage(_c, 0, m);
  cMsg_0DEuIucd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_yzIel2aE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_lzDUSi3E_sendMessage(_c, 0, m);
  cMsg_RFP84YX8_sendMessage(_c, 0, m);
  cMsg_YiBsX8Eh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_I5ClIDQv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0oZJydaj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hV0AELwH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_szCfkwrR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0oZJydaj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hV0AELwH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BfY3wm2O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ufCnWLNa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VfgD1R1L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ayOa2Ibh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ufCnWLNa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VfgD1R1L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Vj9ykNss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_RpCnljGU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vtg56Eo6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3xNVrkae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_RpCnljGU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vtg56Eo6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fpRYnIbb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_szCfkwrR_sendMessage(_c, 0, m);
  cMsg_ayOa2Ibh_sendMessage(_c, 0, m);
  cMsg_3xNVrkae_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ptXSKbq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_szCfkwrR_sendMessage(_c, 0, m);
  cMsg_BfY3wm2O_sendMessage(_c, 0, m);
  cMsg_Vj9ykNss_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5lJwzcoT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_I5ClIDQv_sendMessage(_c, 0, m);
  cMsg_BfY3wm2O_sendMessage(_c, 0, m);
  cMsg_3xNVrkae_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6uU0uz9P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_v9Jlm8PF_sendMessage(_c, 0, m);
  cMsg_gQdr16m9_sendMessage(_c, 0, m);
  cMsg_MXMwzRIw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_FVQ9ekl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_I5ClIDQv_sendMessage(_c, 0, m);
  cMsg_ayOa2Ibh_sendMessage(_c, 0, m);
  cMsg_Vj9ykNss_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_25Sz3RI5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EwQS6OQl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zdW5ISRL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_2NIN2hP4, 0, m, &cSlice_2NIN2hP4_sendMessage);
      break;
    }
    default: {
      cSwitchcase_a44yXJ98_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_2NIN2hP4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_dnl6TX3f_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_dnl6TX3f_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_JDkpE6oY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dnl6TX3f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_dnl6TX3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fII2LWuP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Y2Up8rvZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_inutEfIb, 0, m, &cSlice_inutEfIb_sendMessage);
      break;
    }
    default: {
      cSwitchcase_k8psBqTC_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_inutEfIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_TSwmRv2K_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_TSwmRv2K_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_IRcBMK7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TSwmRv2K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_TSwmRv2K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CK9IXeBC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_k8psBqTC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_WEsRWAMu, 0, m, &cSlice_WEsRWAMu_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zdW5ISRL_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_WEsRWAMu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_uNYWzZiw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_uNYWzZiw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_nK0U0mbg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uNYWzZiw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_uNYWzZiw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zY3h3ABA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_a44yXJ98_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_R9h09YLP, 0, m, &cSlice_R9h09YLP_sendMessage);
      break;
    }
    default: {
      cSwitchcase_mR4uSL2h_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_R9h09YLP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_rWl5ygcj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_rWl5ygcj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Kp1w2zBA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rWl5ygcj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_rWl5ygcj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_iOylIHin_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_mR4uSL2h_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_KwNFuGHY, 0, m, &cSlice_KwNFuGHY_sendMessage);
      break;
    }
    default: {
      cSwitchcase_vDHXaV4G_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_KwNFuGHY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_XA9PLavR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_XA9PLavR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_fMZiRdWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XA9PLavR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_XA9PLavR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QB1zvJpk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_3Aih7iie_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_yjtMxAY8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_yjtMxAY8_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_0kKeT0jm, 1, m, &cDelay_0kKeT0jm_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HR1Obsfa_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_0kKeT0jm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0kKeT0jm, m);
  cMsg_wswHei7L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_yjtMxAY8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0kKeT0jm, 0, m, &cDelay_0kKeT0jm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HR1Obsfa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0kKeT0jm, 0, m, &cDelay_0kKeT0jm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_rNrQfe51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k3wCxZS7, HV_BINOP_SUBTRACT, 0, m, &cBinop_k3wCxZS7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_VjIVSelq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5XOUNu1v_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_DXyfkSni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5XOUNu1v_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_0vLXw4DE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rNrQfe51, 0, m, &cVar_rNrQfe51_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_X6VhQUUt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SmsCnbpJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2Wrhbcf7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gSBQRTRU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_k3wCxZS7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_flmIinxm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_flmIinxm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_jsLSk0F2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jsLSk0F2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_HMQirvOr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fMGvGAMY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Hj10UCiO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tl8l85R8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tl8l85R8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HbyocJNY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Hj10UCiO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VjIVSelq, 1, m, &cIf_VjIVSelq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3H62RqEF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DXyfkSni, 1, m, &cIf_DXyfkSni_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HbyocJNY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_VjIVSelq, 0, m, &cIf_VjIVSelq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HMQirvOr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DXyfkSni, 0, m, &cIf_DXyfkSni_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2Wrhbcf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k3wCxZS7, HV_BINOP_SUBTRACT, 1, m, &cBinop_k3wCxZS7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SmsCnbpJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_gSBQRTRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rNrQfe51, 0, m, &cVar_rNrQfe51_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5XOUNu1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LJyZoAzY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_vDHXaV4G_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_r9DeRBgf, 0, m, &cSlice_r9DeRBgf_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_r9DeRBgf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_TcQLwAX0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_TcQLwAX0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_gPTj32a2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TcQLwAX0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_TcQLwAX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YX0SDn3T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_sb7VpBxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GuuVTCeA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_LN7BR8uy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8dzZnWs7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_NToPBbeu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_r8wfZLqX, 0, m, &cVar_r8wfZLqX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EwQS6OQl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TcKZZxAD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_VizWKMtd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3Aih7iie_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_bmtsu8If_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q27RaNae_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wswHei7L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wCiqSjlu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Q27RaNae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wCiqSjlu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_U5lqehuQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_zA75tdi9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zA75tdi9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e44S3AfY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_e44S3AfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ze0mF9sT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_DEFMfnuu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a6nIzvvL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_P1zW5wg7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JiVGVoVa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_1UKLv2Mj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PHgxF3rw_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tDdOUgSp_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DCstcpG7_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OMHZQtHG_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NaLza30L_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JkgE9SuT_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_PHgxF3rw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KI4a5D3f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_tDdOUgSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6KAgZ9u6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_DCstcpG7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jWMydxNt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_OMHZQtHG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eQA4r2mx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_NaLza30L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LDTAa8bu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_JkgE9SuT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_86jdQKsf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_rGr0MlCr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4DVfQEfz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_rvU8u9tP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_kfbgSRbu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_YBO14oi1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_9Cz1r6JU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_9Cz1r6JU_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_IxR6Bq9w, 1, m, &cDelay_IxR6Bq9w_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cVQ9T7YS_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_IxR6Bq9w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IxR6Bq9w, m);
  cIf_onMessage(_c, &Context(_c)->cIf_rGr0MlCr, 0, m, &cIf_rGr0MlCr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9Cz1r6JU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_IxR6Bq9w, 0, m, &cDelay_IxR6Bq9w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cVQ9T7YS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_IxR6Bq9w, 0, m, &cDelay_IxR6Bq9w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AGBkIdey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hdvcMSqg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gY5mMERr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_M5bEl7CO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vrwmxh0T_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sQLdTqWZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sQLdTqWZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_YBO14oi1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_vrwmxh0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rGr0MlCr, 1, m, &cIf_rGr0MlCr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gY5mMERr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rvU8u9tP, 0, m, &cIf_rvU8u9tP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hdvcMSqg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rvU8u9tP, 1, m, &cIf_rvU8u9tP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kfbgSRbu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iYkY0hHB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4DVfQEfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iYkY0hHB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_p9IGal1Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aJEvm8PD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ZiLcuVTo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DxK8PdrJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_JEeGCgaw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Lgzxyuq4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Lgzxyuq4_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_qfZsRQLu, 1, m, &cDelay_qfZsRQLu_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sU8Vs6TI_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_qfZsRQLu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qfZsRQLu, m);
  cIf_onMessage(_c, &Context(_c)->cIf_p9IGal1Y, 0, m, &cIf_p9IGal1Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Lgzxyuq4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_qfZsRQLu, 0, m, &cDelay_qfZsRQLu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sU8Vs6TI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_qfZsRQLu, 0, m, &cDelay_qfZsRQLu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7g2nbqms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2OfxmNT1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_23vuxCJj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kGwKoRo3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_slX4f3L9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QZY54JDA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_slX4f3L9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_p9IGal1Y, 1, m, &cIf_p9IGal1Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QZY54JDA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JEeGCgaw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_2OfxmNT1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZiLcuVTo, 1, m, &cIf_ZiLcuVTo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_23vuxCJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZiLcuVTo, 0, m, &cIf_ZiLcuVTo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DxK8PdrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_R9Dmo8Lf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_aJEvm8PD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_R9Dmo8Lf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Jwwqfwac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5t262szW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Zr6SGiaz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HOemLch5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_aTrtOpwM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_CF57dW3G_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_CF57dW3G_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_fTFlDa7A, 1, m, &cDelay_fTFlDa7A_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iipe1CdO_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_fTFlDa7A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fTFlDa7A, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Jwwqfwac, 0, m, &cIf_Jwwqfwac_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CF57dW3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_fTFlDa7A, 0, m, &cDelay_fTFlDa7A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iipe1CdO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fTFlDa7A, 0, m, &cDelay_fTFlDa7A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CV35NRtG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wTEb6teG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q0feHxkZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_u8kLZh7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OpVqSw4h_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yH5NirV0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yH5NirV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_aTrtOpwM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_OpVqSw4h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Jwwqfwac, 1, m, &cIf_Jwwqfwac_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wTEb6teG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Zr6SGiaz, 1, m, &cIf_Zr6SGiaz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_q0feHxkZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Zr6SGiaz, 0, m, &cIf_Zr6SGiaz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HOemLch5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_91mblq9h, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5t262szW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_91mblq9h, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_90PLhf6v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3DJcTjOm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Y9li8S14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HPFk1KCM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_tGAhZzaY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ZYHWjJw5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ZYHWjJw5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_YGMpW5aD, 1, m, &cDelay_YGMpW5aD_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MPNEbYmP_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_YGMpW5aD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YGMpW5aD, m);
  cIf_onMessage(_c, &Context(_c)->cIf_90PLhf6v, 0, m, &cIf_90PLhf6v_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZYHWjJw5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_YGMpW5aD, 0, m, &cDelay_YGMpW5aD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MPNEbYmP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_YGMpW5aD, 0, m, &cDelay_YGMpW5aD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EbPzJR7n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XFrDS4Pg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_czPe5Euf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7qMukNjA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_970Hxule_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BcdiGenS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BcdiGenS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tGAhZzaY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_970Hxule_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_90PLhf6v, 1, m, &cIf_90PLhf6v_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_czPe5Euf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Y9li8S14, 0, m, &cIf_Y9li8S14_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XFrDS4Pg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Y9li8S14, 1, m, &cIf_Y9li8S14_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HPFk1KCM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wg2wgXps, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3DJcTjOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wg2wgXps, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_GdGygfhL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_pHXyaxSG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_4qzNz1yB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_u1zCLmbr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_iREiQQcM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_HCBeN4xC_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_HCBeN4xC_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_tOWBaq8W, 1, m, &cDelay_tOWBaq8W_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NSVawgQ6_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_tOWBaq8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tOWBaq8W, m);
  cIf_onMessage(_c, &Context(_c)->cIf_GdGygfhL, 0, m, &cIf_GdGygfhL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HCBeN4xC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tOWBaq8W, 0, m, &cDelay_tOWBaq8W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NSVawgQ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tOWBaq8W, 0, m, &cDelay_tOWBaq8W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6T9lvuri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6Jjwi2qS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zf4wehCG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0ZWAjzsB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z8jTM8Gz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HgWyBsQr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HgWyBsQr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_iREiQQcM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_z8jTM8Gz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GdGygfhL, 1, m, &cIf_GdGygfhL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zf4wehCG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4qzNz1yB, 0, m, &cIf_4qzNz1yB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6Jjwi2qS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4qzNz1yB, 1, m, &cIf_4qzNz1yB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_u1zCLmbr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_S3kLqp0Y, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_pHXyaxSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_S3kLqp0Y, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ETamw3B8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RbznUTgP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_T1NI7VeP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6ic6MefL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Bq439H5v_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Khg7Deam_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Khg7Deam_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Oizm8CD6, 1, m, &cDelay_Oizm8CD6_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PV43TDys_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Oizm8CD6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Oizm8CD6, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ETamw3B8, 0, m, &cIf_ETamw3B8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Khg7Deam_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Oizm8CD6, 0, m, &cDelay_Oizm8CD6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PV43TDys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Oizm8CD6, 0, m, &cDelay_Oizm8CD6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oUSMOaLD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fbxlkq0c_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mnLAePoB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Z14AyiMg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RuLLrZo1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4k06d9Zd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4k06d9Zd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Bq439H5v_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_RuLLrZo1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ETamw3B8, 1, m, &cIf_ETamw3B8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mnLAePoB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_T1NI7VeP, 0, m, &cIf_T1NI7VeP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fbxlkq0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_T1NI7VeP, 1, m, &cIf_T1NI7VeP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6ic6MefL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nMqFbXeQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_RbznUTgP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nMqFbXeQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ZjZfVCMJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0iCc3wBk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_uaDI5Udv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eZXx3MCk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_AEkOesvU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_zHXrTIor_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_zHXrTIor_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_HOHmF4Zp, 1, m, &cDelay_HOHmF4Zp_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nzeoiXD3_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_HOHmF4Zp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HOHmF4Zp, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ZjZfVCMJ, 0, m, &cIf_ZjZfVCMJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zHXrTIor_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_HOHmF4Zp, 0, m, &cDelay_HOHmF4Zp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nzeoiXD3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HOHmF4Zp, 0, m, &cDelay_HOHmF4Zp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qVziXyca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JbJIAqT0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fzrDPQOx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9pyD0ODS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iOQ50x1f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q5NriOA3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_q5NriOA3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_AEkOesvU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_iOQ50x1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZjZfVCMJ, 1, m, &cIf_ZjZfVCMJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fzrDPQOx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uaDI5Udv, 0, m, &cIf_uaDI5Udv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JbJIAqT0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uaDI5Udv, 1, m, &cIf_uaDI5Udv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eZXx3MCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rJYNLifm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0iCc3wBk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rJYNLifm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_LyTXZySr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7GIQEwn8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_IbHlbaCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bXQRahOf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_wIHWWebH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_mSqaDBqD_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_mSqaDBqD_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wrkDIHcG, 1, m, &cDelay_wrkDIHcG_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DmmSQAmM_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_wrkDIHcG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wrkDIHcG, m);
  cIf_onMessage(_c, &Context(_c)->cIf_LyTXZySr, 0, m, &cIf_LyTXZySr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mSqaDBqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wrkDIHcG, 0, m, &cDelay_wrkDIHcG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DmmSQAmM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wrkDIHcG, 0, m, &cDelay_wrkDIHcG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_p7uCumqG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_K3RznGKI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_o189vJOs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5HGVqlBl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sTzWXG3G_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JgOjTsIk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sTzWXG3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LyTXZySr, 1, m, &cIf_LyTXZySr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JgOjTsIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_wIHWWebH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_o189vJOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IbHlbaCA, 0, m, &cIf_IbHlbaCA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_K3RznGKI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IbHlbaCA, 1, m, &cIf_IbHlbaCA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bXQRahOf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_APcNkI4j, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_7GIQEwn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_APcNkI4j, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_SMNfGEp3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1OdjNoh0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_G6rcEvPU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_CdNArKlD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_yGOdDHmt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Ol2orXzD_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Ol2orXzD_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_p6inJrBi, 1, m, &cDelay_p6inJrBi_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xfJaFtmq_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_p6inJrBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_p6inJrBi, m);
  cIf_onMessage(_c, &Context(_c)->cIf_SMNfGEp3, 0, m, &cIf_SMNfGEp3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ol2orXzD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_p6inJrBi, 0, m, &cDelay_p6inJrBi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xfJaFtmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_p6inJrBi, 0, m, &cDelay_p6inJrBi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4VN6zedd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ceoguTcY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kvB7M45w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rE9OGlEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3IEWqaUj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KF1tkY7p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KF1tkY7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_yGOdDHmt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_3IEWqaUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SMNfGEp3, 1, m, &cIf_SMNfGEp3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kvB7M45w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_G6rcEvPU, 0, m, &cIf_G6rcEvPU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ceoguTcY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_G6rcEvPU, 1, m, &cIf_G6rcEvPU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CdNArKlD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IdA1qZPZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1OdjNoh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IdA1qZPZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_iN4Oe7jQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JGS20LZi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_kUWeCwb0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wYpqrk1P_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_HCmm6QmJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_sRgh9KzW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_sRgh9KzW_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_mpuyrbHN, 1, m, &cDelay_mpuyrbHN_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BdwY1k0F_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_mpuyrbHN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mpuyrbHN, m);
  cIf_onMessage(_c, &Context(_c)->cIf_iN4Oe7jQ, 0, m, &cIf_iN4Oe7jQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sRgh9KzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_mpuyrbHN, 0, m, &cDelay_mpuyrbHN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BdwY1k0F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mpuyrbHN, 0, m, &cDelay_mpuyrbHN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tDe3F8l9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rvTc7ddT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q9k0Rjic_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VK3BxlFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_87WboQsN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WkFyqirZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WkFyqirZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_HCmm6QmJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_87WboQsN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iN4Oe7jQ, 1, m, &cIf_iN4Oe7jQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Q9k0Rjic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kUWeCwb0, 0, m, &cIf_kUWeCwb0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rvTc7ddT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kUWeCwb0, 1, m, &cIf_kUWeCwb0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wYpqrk1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ebeZcP8o, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JGS20LZi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ebeZcP8o, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_7GeC5Sm1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aunGqHL7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_DX7SXTxc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jYZ92of5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_sqO1ldaZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_UmtlNUHg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_UmtlNUHg_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_CoWP2Qoj, 1, m, &cDelay_CoWP2Qoj_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_g8cpGvTu_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_CoWP2Qoj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CoWP2Qoj, m);
  cIf_onMessage(_c, &Context(_c)->cIf_7GeC5Sm1, 0, m, &cIf_7GeC5Sm1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UmtlNUHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_CoWP2Qoj, 0, m, &cDelay_CoWP2Qoj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_g8cpGvTu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CoWP2Qoj, 0, m, &cDelay_CoWP2Qoj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uT3BwnzR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PfFqjfgl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Cd4SK2DN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_48TocgGP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hyH9EvUo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_reOnqKwC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_reOnqKwC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_sqO1ldaZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_hyH9EvUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7GeC5Sm1, 1, m, &cIf_7GeC5Sm1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Cd4SK2DN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DX7SXTxc, 0, m, &cIf_DX7SXTxc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PfFqjfgl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DX7SXTxc, 1, m, &cIf_DX7SXTxc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jYZ92of5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tI4Q5Y6d, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_aunGqHL7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tI4Q5Y6d, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_K12HQNuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uynBsweb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Ix8e2RYF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_M7rcJ50Y_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PqMI3Xg5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_5Hwta7qI_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_5Hwta7qI_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_IMgf7nsx, 1, m, &cDelay_IMgf7nsx_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oweTmYMy_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_IMgf7nsx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IMgf7nsx, m);
  cIf_onMessage(_c, &Context(_c)->cIf_K12HQNuE, 0, m, &cIf_K12HQNuE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5Hwta7qI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_IMgf7nsx, 0, m, &cDelay_IMgf7nsx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oweTmYMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_IMgf7nsx, 0, m, &cDelay_IMgf7nsx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_P0nZIM3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CRPXhSdR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uK7hXWxH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NqsCTznQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VDnDoQey_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jIr5XVpw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VDnDoQey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K12HQNuE, 1, m, &cIf_K12HQNuE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jIr5XVpw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_PqMI3Xg5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_uK7hXWxH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ix8e2RYF, 0, m, &cIf_Ix8e2RYF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CRPXhSdR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ix8e2RYF, 1, m, &cIf_Ix8e2RYF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_M7rcJ50Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3sJV3a89, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_uynBsweb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3sJV3a89, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_KI4a5D3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_gwB0Goq9_sendMessage(_c, 0, m);
  cMsg_y1UE5Qk4_sendMessage(_c, 0, m);
  cMsg_EpEJjMw2_sendMessage(_c, 0, m);
  cMsg_XMADVFJT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6KAgZ9u6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_gwB0Goq9_sendMessage(_c, 0, m);
  cMsg_pDrVOyDf_sendMessage(_c, 0, m);
  cMsg_MjyAxWML_sendMessage(_c, 0, m);
  cMsg_YqHsXTUq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jWMydxNt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_IgmRjiOz_sendMessage(_c, 0, m);
  cMsg_pDrVOyDf_sendMessage(_c, 0, m);
  cMsg_XMADVFJT_sendMessage(_c, 0, m);
  cMsg_r4CkQnKD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_eQA4r2mx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_IgmRjiOz_sendMessage(_c, 0, m);
  cMsg_wsQEG6nW_sendMessage(_c, 0, m);
  cMsg_EpEJjMw2_sendMessage(_c, 0, m);
  cMsg_MrPu5mmT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LDTAa8bu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_PkfIR5sL_sendMessage(_c, 0, m);
  cMsg_YqHsXTUq_sendMessage(_c, 0, m);
  cMsg_gF1rgDoc_sendMessage(_c, 0, m);
  cMsg_EpEJjMw2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_86jdQKsf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_PkfIR5sL_sendMessage(_c, 0, m);
  cMsg_MrPu5mmT_sendMessage(_c, 0, m);
  cMsg_pDrVOyDf_sendMessage(_c, 0, m);
  cMsg_TuFZgupA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_g9Nq3DVd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_M5bEl7CO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AGBkIdey_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_n7ynxImn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_M5bEl7CO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AGBkIdey_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BLJu4A61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kGwKoRo3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7g2nbqms_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GKR6hH2A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kGwKoRo3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7g2nbqms_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EaCR1PIj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_u8kLZh7D_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CV35NRtG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XXymkuQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_u8kLZh7D_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CV35NRtG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gwB0Goq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_g9Nq3DVd_sendMessage(_c, 0, m);
  cMsg_GKR6hH2A_sendMessage(_c, 0, m);
  cMsg_XXymkuQy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_IgmRjiOz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_n7ynxImn_sendMessage(_c, 0, m);
  cMsg_BLJu4A61_sendMessage(_c, 0, m);
  cMsg_XXymkuQy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PkfIR5sL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_n7ynxImn_sendMessage(_c, 0, m);
  cMsg_GKR6hH2A_sendMessage(_c, 0, m);
  cMsg_EaCR1PIj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_HdZC6qsg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7qMukNjA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EbPzJR7n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZVC3yYqe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7qMukNjA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EbPzJR7n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EvRbCNes_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0ZWAjzsB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6T9lvuri_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KXOnKNh5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0ZWAjzsB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6T9lvuri_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_G6DxTzms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Z14AyiMg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oUSMOaLD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_e5qpA2iD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Z14AyiMg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oUSMOaLD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pDrVOyDf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_ZVC3yYqe_sendMessage(_c, 0, m);
  cMsg_KXOnKNh5_sendMessage(_c, 0, m);
  cMsg_e5qpA2iD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_y1UE5Qk4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_ZVC3yYqe_sendMessage(_c, 0, m);
  cMsg_EvRbCNes_sendMessage(_c, 0, m);
  cMsg_G6DxTzms_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wsQEG6nW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_HdZC6qsg_sendMessage(_c, 0, m);
  cMsg_KXOnKNh5_sendMessage(_c, 0, m);
  cMsg_G6DxTzms_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Fmar9ffF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VK3BxlFj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tDe3F8l9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hAMQaP1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VK3BxlFj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tDe3F8l9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BYFLujii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_48TocgGP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uT3BwnzR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JBTF7wXD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_48TocgGP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uT3BwnzR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rxDdhgcl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_NqsCTznQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_P0nZIM3f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cu6e7L9N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_NqsCTznQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_P0nZIM3f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MrPu5mmT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_Fmar9ffF_sendMessage(_c, 0, m);
  cMsg_JBTF7wXD_sendMessage(_c, 0, m);
  cMsg_cu6e7L9N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_YqHsXTUq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_hAMQaP1H_sendMessage(_c, 0, m);
  cMsg_BYFLujii_sendMessage(_c, 0, m);
  cMsg_cu6e7L9N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_XMADVFJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_hAMQaP1H_sendMessage(_c, 0, m);
  cMsg_JBTF7wXD_sendMessage(_c, 0, m);
  cMsg_rxDdhgcl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pYEij583_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9pyD0ODS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qVziXyca_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8ayOkoOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9pyD0ODS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qVziXyca_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZQdNlDs7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5HGVqlBl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_p7uCumqG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_krkbH2mc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5HGVqlBl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_p7uCumqG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZcLVVVtv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rE9OGlEZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4VN6zedd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mEf2rU1W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rE9OGlEZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4VN6zedd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EpEJjMw2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_8ayOkoOs_sendMessage(_c, 0, m);
  cMsg_krkbH2mc_sendMessage(_c, 0, m);
  cMsg_mEf2rU1W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_MjyAxWML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_8ayOkoOs_sendMessage(_c, 0, m);
  cMsg_ZQdNlDs7_sendMessage(_c, 0, m);
  cMsg_ZcLVVVtv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_TuFZgupA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_pYEij583_sendMessage(_c, 0, m);
  cMsg_ZQdNlDs7_sendMessage(_c, 0, m);
  cMsg_mEf2rU1W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_gF1rgDoc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_HdZC6qsg_sendMessage(_c, 0, m);
  cMsg_EvRbCNes_sendMessage(_c, 0, m);
  cMsg_e5qpA2iD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_r4CkQnKD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_pYEij583_sendMessage(_c, 0, m);
  cMsg_krkbH2mc_sendMessage(_c, 0, m);
  cMsg_ZcLVVVtv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_7QzWHacc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dZ3048Jj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_qojw01FI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_b3QzQuAd, 0, m, &cSlice_b3QzQuAd_sendMessage);
      break;
    }
    default: {
      cSwitchcase_9HqbgcOR_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_b3QzQuAd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_riDSybIb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_riDSybIb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_N6nVAae4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_riDSybIb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_riDSybIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OWNASTZ7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Zb1Xzwon_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_YdzSMMPD, 0, m, &cSlice_YdzSMMPD_sendMessage);
      break;
    }
    default: {
      cSwitchcase_cUVhMJdA_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_YdzSMMPD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Lt4n2sQS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Lt4n2sQS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_2us1DNKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Lt4n2sQS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Lt4n2sQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eJq5xGfp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_cUVhMJdA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_APL5IOJg, 0, m, &cSlice_APL5IOJg_sendMessage);
      break;
    }
    default: {
      cSwitchcase_qojw01FI_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_APL5IOJg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zspAcKK4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zspAcKK4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_jQKDssvQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zspAcKK4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_zspAcKK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_if0Uz0pL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9HqbgcOR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_OAZdHQdF, 0, m, &cSlice_OAZdHQdF_sendMessage);
      break;
    }
    default: {
      cSwitchcase_k0YaV0LS_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_OAZdHQdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_tH30xSbH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_tH30xSbH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_JBbVVxFv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tH30xSbH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_tH30xSbH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JAHT2qDU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_k0YaV0LS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_RNyvD4Bz, 0, m, &cSlice_RNyvD4Bz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_MF5hIxQY_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_RNyvD4Bz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zg3mBN7D_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zg3mBN7D_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_7Hm77VZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zg3mBN7D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_zg3mBN7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HZxBjXjZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_GaRlkQWU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ZfoAmdND_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ZfoAmdND_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Hpggc0Ki, 1, m, &cDelay_Hpggc0Ki_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vtbHe6kg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Hpggc0Ki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Hpggc0Ki, m);
  cMsg_IlnT6phf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ZfoAmdND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Hpggc0Ki, 0, m, &cDelay_Hpggc0Ki_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vtbHe6kg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Hpggc0Ki, 0, m, &cDelay_Hpggc0Ki_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_k6KKjbyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e0TUzQC5, HV_BINOP_SUBTRACT, 0, m, &cBinop_e0TUzQC5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_IU8kLC3Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xlXu1dQ1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_DvF4eO03_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xlXu1dQ1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_lXJoZoFl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_k6KKjbyY, 0, m, &cVar_k6KKjbyY_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_bvphXsZx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xLAYiBHB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Za9q3ke9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_S4TFUade_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_e0TUzQC5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CZuU4BX4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CZuU4BX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_CvqlHBsD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CvqlHBsD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_OWU0pnLN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NEwb12M5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8HJYqtzU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RO8BcaOv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8HJYqtzU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IU8kLC3Y, 1, m, &cIf_IU8kLC3Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RO8BcaOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W2EsVcdl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_QAxjuBfJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DvF4eO03, 1, m, &cIf_DvF4eO03_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_W2EsVcdl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_IU8kLC3Y, 0, m, &cIf_IU8kLC3Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OWU0pnLN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DvF4eO03, 0, m, &cIf_DvF4eO03_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xLAYiBHB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_S4TFUade_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_k6KKjbyY, 0, m, &cVar_k6KKjbyY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Za9q3ke9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e0TUzQC5, HV_BINOP_SUBTRACT, 1, m, &cBinop_e0TUzQC5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xlXu1dQ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_t3bi42mH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_MF5hIxQY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_cD6nTWWV, 0, m, &cSlice_cD6nTWWV_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_cD6nTWWV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Hhb9DBUb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Hhb9DBUb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_gZYRfL5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Hhb9DBUb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Hhb9DBUb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3ANAxUma_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_a6nIzvvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SClschGm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JiVGVoVa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LVqPhta4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_5nKml6kW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_P1zW5wg7, 0, m, &cVar_P1zW5wg7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dZ3048Jj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Arn3lTzT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_7HdVdeNl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZRvTDjXx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_DOVhqnNW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_GaRlkQWU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_IlnT6phf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JYfbQUby, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ZRvTDjXx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JYfbQUby, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_6rDepEPI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_9Fljdbnb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9Fljdbnb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OIQja3v7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OIQja3v7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_l4FU55Kl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_dfiMQfTV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0tyrI7W1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_wqjDDt7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oPEZnTZ6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_hb37dN8I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wwoTASs6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_9toWFASb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FNwC1kam_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_26fwkrrn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qLNl0qfB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_cxvdBAaq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TTkwCiHU_sendMessage);
  cMsg_PHkuUUD3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_TTkwCiHU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cxvdBAaq, 1, m, &cVar_cxvdBAaq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_n5SwLQIz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gGJHz1vL_sendMessage(_c, 0, m);
  cMsg_VYXUP5uX_sendMessage(_c, 0, m);
  cMsg_kaxdypRg_sendMessage(_c, 0, m);
  cMsg_zXux4eVp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_KPicc8nH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_YqlLV05q, 0, m, &cSlice_YqlLV05q_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_YqlLV05q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Y8PaDfGg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Y8PaDfGg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_lFqd7G7a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Y8PaDfGg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Y8PaDfGg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_aIQqFWDI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_xQAq4GB7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_OSXnH68U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OSXnH68U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_iw4qnqos_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iw4qnqos_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ROrxiW3Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ROrxiW3Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y1o9u0y9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_G4X885Hl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_G4X885Hl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RDQmGEAM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_y1o9u0y9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_yyGom7Jf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yyGom7Jf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_QHiaTdEW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RDQmGEAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_XQlmVSSL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XQlmVSSL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_4Vym5Ct5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QHiaTdEW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xp8rCAm5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_4Vym5Ct5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TL75OpHj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xp8rCAm5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ewj5byRN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_TL75OpHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_elVf9Vnz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_jU53TK8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tFtDs91G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Dk67hGaW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eIzNGAZY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_3hZODIBW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7lQMOX1e_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1g9lWJm9_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_K291UMtN_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v6PA1oql_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cBKjrehV_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PgckEhd3_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_7lQMOX1e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pqfz1qFJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_1g9lWJm9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5x1DbwFI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_K291UMtN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2tPl6TWW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_v6PA1oql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L20NBsFL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_cBKjrehV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FvXK6al9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_PgckEhd3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YR50vttK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_bpW84bqp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_w2oofY6P_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ZXnygVJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OrLPwPjl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_HMBvk8l6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_gs4TSW0T_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_gs4TSW0T_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Cmf6q2Ns, 1, m, &cDelay_Cmf6q2Ns_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TdFRCBEM_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Cmf6q2Ns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Cmf6q2Ns, m);
  cIf_onMessage(_c, &Context(_c)->cIf_bpW84bqp, 0, m, &cIf_bpW84bqp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gs4TSW0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cmf6q2Ns, 0, m, &cDelay_Cmf6q2Ns_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TdFRCBEM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cmf6q2Ns, 0, m, &cDelay_Cmf6q2Ns_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qLknpozi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JtJNH1L3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xXvbwFah_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cIxpelUU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FkObgaxG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OZI41JMz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OZI41JMz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_HMBvk8l6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_FkObgaxG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bpW84bqp, 1, m, &cIf_bpW84bqp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xXvbwFah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZXnygVJr, 0, m, &cIf_ZXnygVJr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JtJNH1L3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZXnygVJr, 1, m, &cIf_ZXnygVJr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OrLPwPjl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XKdUOyXt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_w2oofY6P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XKdUOyXt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_YhtssPr8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ORHoA8oM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_CeZGIPhc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5qpyYmIp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_GdGhAj0i_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_WZ0H00TO_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_WZ0H00TO_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_zo9u949S, 1, m, &cDelay_zo9u949S_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JTrs6aVG_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_zo9u949S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zo9u949S, m);
  cIf_onMessage(_c, &Context(_c)->cIf_YhtssPr8, 0, m, &cIf_YhtssPr8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WZ0H00TO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zo9u949S, 0, m, &cDelay_zo9u949S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JTrs6aVG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zo9u949S, 0, m, &cDelay_zo9u949S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yXrL8Nz0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gH1QUw2o_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fk5JnFAZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5gxm3vKs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hhAQW1t4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Bf6PnCVu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Bf6PnCVu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_GdGhAj0i_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_hhAQW1t4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YhtssPr8, 1, m, &cIf_YhtssPr8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fk5JnFAZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CeZGIPhc, 0, m, &cIf_CeZGIPhc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gH1QUw2o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CeZGIPhc, 1, m, &cIf_CeZGIPhc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5qpyYmIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JOpHP5TD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ORHoA8oM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JOpHP5TD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Kul25jGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TJXKIrIL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_15kgzMnW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_a8uDoqrI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4tN9ekl3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_xT5lmeXM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_xT5lmeXM_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ASuR2k4A, 1, m, &cDelay_ASuR2k4A_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TfM65z6s_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ASuR2k4A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ASuR2k4A, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Kul25jGu, 0, m, &cIf_Kul25jGu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xT5lmeXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ASuR2k4A, 0, m, &cDelay_ASuR2k4A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TfM65z6s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ASuR2k4A, 0, m, &cDelay_ASuR2k4A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sgNQmPAn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iHUywLSj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5WTxzvSq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_x9XD8exf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Gxxb1Ar3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eSHpDjVM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eSHpDjVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4tN9ekl3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Gxxb1Ar3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Kul25jGu, 1, m, &cIf_Kul25jGu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5WTxzvSq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_15kgzMnW, 0, m, &cIf_15kgzMnW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iHUywLSj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_15kgzMnW, 1, m, &cIf_15kgzMnW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_a8uDoqrI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_i4Gtz4ZS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_TJXKIrIL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_i4Gtz4ZS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_lY7g8PUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_d9OJuCqo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_bt9gPPgf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YF7qnJYo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_XhoYAXym_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Z6mSryHe_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Z6mSryHe_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_L93L98vn, 1, m, &cDelay_L93L98vn_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bE04Pgsa_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_L93L98vn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_L93L98vn, m);
  cIf_onMessage(_c, &Context(_c)->cIf_lY7g8PUG, 0, m, &cIf_lY7g8PUG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Z6mSryHe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_L93L98vn, 0, m, &cDelay_L93L98vn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bE04Pgsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_L93L98vn, 0, m, &cDelay_L93L98vn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AQh1SvC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PxsyCfEM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Z7Q0BtH9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VLtiLIpC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IWWBvwcy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_d5DA3wI2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_d5DA3wI2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_XhoYAXym_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_IWWBvwcy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lY7g8PUG, 1, m, &cIf_lY7g8PUG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PxsyCfEM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bt9gPPgf, 1, m, &cIf_bt9gPPgf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Z7Q0BtH9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bt9gPPgf, 0, m, &cIf_bt9gPPgf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YF7qnJYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_j5oT2Mgm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_d9OJuCqo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_j5oT2Mgm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_JGt23hR0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gdIRXut5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_UEduO0Q7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eiNW5P02_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_dxmITER9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_T4w0Wa42_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_T4w0Wa42_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Y9fSbdz5, 1, m, &cDelay_Y9fSbdz5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YFLb5rOa_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Y9fSbdz5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Y9fSbdz5, m);
  cIf_onMessage(_c, &Context(_c)->cIf_JGt23hR0, 0, m, &cIf_JGt23hR0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_T4w0Wa42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y9fSbdz5, 0, m, &cDelay_Y9fSbdz5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YFLb5rOa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y9fSbdz5, 0, m, &cDelay_Y9fSbdz5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Jie9AxHy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xkCgGFHq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vwnNcDri_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_u8BUOpKL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SMObM6Rd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XNRiUSyV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XNRiUSyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_dxmITER9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_SMObM6Rd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JGt23hR0, 1, m, &cIf_JGt23hR0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vwnNcDri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UEduO0Q7, 0, m, &cIf_UEduO0Q7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xkCgGFHq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UEduO0Q7, 1, m, &cIf_UEduO0Q7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eiNW5P02_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_x8SUfxUU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_gdIRXut5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_x8SUfxUU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_iZW7lNkt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rIW2aUwg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Fw0SBQeX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gvEu1R5o_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PgKMrvNv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_uOHMUBzC_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_uOHMUBzC_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_EboaYano, 1, m, &cDelay_EboaYano_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Oh6YTbti_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_EboaYano_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EboaYano, m);
  cIf_onMessage(_c, &Context(_c)->cIf_iZW7lNkt, 0, m, &cIf_iZW7lNkt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uOHMUBzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_EboaYano, 0, m, &cDelay_EboaYano_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Oh6YTbti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EboaYano, 0, m, &cDelay_EboaYano_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2Sv9hyP0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eHXCI64J_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TREBBnDb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zJhlMEjU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uLFJyrII_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kH7l1Pbe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kH7l1Pbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_PgKMrvNv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_uLFJyrII_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iZW7lNkt, 1, m, &cIf_iZW7lNkt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TREBBnDb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Fw0SBQeX, 0, m, &cIf_Fw0SBQeX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eHXCI64J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Fw0SBQeX, 1, m, &cIf_Fw0SBQeX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gvEu1R5o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EW4g4xpW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_rIW2aUwg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EW4g4xpW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Kwb0vueD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rtO1lDbx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_EEHb5mn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NXewMg1u_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_aCeYqjcL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_oN0phPAx_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_oN0phPAx_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_AhmtaJy7, 1, m, &cDelay_AhmtaJy7_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xUfwxUgb_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_AhmtaJy7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AhmtaJy7, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Kwb0vueD, 0, m, &cIf_Kwb0vueD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oN0phPAx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_AhmtaJy7, 0, m, &cDelay_AhmtaJy7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xUfwxUgb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AhmtaJy7, 0, m, &cDelay_AhmtaJy7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RYjGCbdB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UUQYfbtV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_35ef0sKN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cLPf9q91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nEPFGGKB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QrTsjocM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QrTsjocM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_aCeYqjcL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_nEPFGGKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Kwb0vueD, 1, m, &cIf_Kwb0vueD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_35ef0sKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EEHb5mn5, 0, m, &cIf_EEHb5mn5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UUQYfbtV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EEHb5mn5, 1, m, &cIf_EEHb5mn5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NXewMg1u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_72MT8g6v, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_rtO1lDbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_72MT8g6v, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_uC2kacbS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tUk7BBBH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_mRS5rkXL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jBO5RtEv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_DbSwsZM2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_8jQN8Uja_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_8jQN8Uja_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_XaCEPKKl, 1, m, &cDelay_XaCEPKKl_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_95pTZ7Hd_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_XaCEPKKl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XaCEPKKl, m);
  cIf_onMessage(_c, &Context(_c)->cIf_uC2kacbS, 0, m, &cIf_uC2kacbS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8jQN8Uja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_XaCEPKKl, 0, m, &cDelay_XaCEPKKl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_95pTZ7Hd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_XaCEPKKl, 0, m, &cDelay_XaCEPKKl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yQHL6Kuj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7uma2w8N_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cSKVkoGL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_smwGd1Ez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZtveX3r7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2QYnemuJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2QYnemuJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_DbSwsZM2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ZtveX3r7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uC2kacbS, 1, m, &cIf_uC2kacbS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cSKVkoGL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mRS5rkXL, 0, m, &cIf_mRS5rkXL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7uma2w8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mRS5rkXL, 1, m, &cIf_mRS5rkXL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jBO5RtEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZDX8w7Jk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tUk7BBBH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZDX8w7Jk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_vux7M62K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_f4t2Qy7D_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_d7zjIZPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_f5LKoWaw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_vLL0ullU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_tWamRWIQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_tWamRWIQ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_g9puk30z, 1, m, &cDelay_g9puk30z_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dHMTaZ40_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_g9puk30z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_g9puk30z, m);
  cIf_onMessage(_c, &Context(_c)->cIf_vux7M62K, 0, m, &cIf_vux7M62K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tWamRWIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_g9puk30z, 0, m, &cDelay_g9puk30z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dHMTaZ40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_g9puk30z, 0, m, &cDelay_g9puk30z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7IWQZ7jX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tjh5MJVc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r0duL1Hz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GDgAvhac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xath0C59_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WxOhIR1J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xath0C59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vux7M62K, 1, m, &cIf_vux7M62K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WxOhIR1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_vLL0ullU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_r0duL1Hz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_d7zjIZPm, 0, m, &cIf_d7zjIZPm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tjh5MJVc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_d7zjIZPm, 1, m, &cIf_d7zjIZPm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_f5LKoWaw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mjr4eL4w, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_f4t2Qy7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mjr4eL4w, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_rWaqLkWe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_GGPSnYu1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_dZhCbWKI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HBmGpFuN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_uc8fxF1K_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_VbSbgkCv_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_VbSbgkCv_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_blcQPNle, 1, m, &cDelay_blcQPNle_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kWASKjJV_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_blcQPNle_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_blcQPNle, m);
  cIf_onMessage(_c, &Context(_c)->cIf_rWaqLkWe, 0, m, &cIf_rWaqLkWe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VbSbgkCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_blcQPNle, 0, m, &cDelay_blcQPNle_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kWASKjJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_blcQPNle, 0, m, &cDelay_blcQPNle_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qMq22RqJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_p70kjrsX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W2S2YfG2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_izcvKDm1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_irYX6gZh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yzqRuiJT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_irYX6gZh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rWaqLkWe, 1, m, &cIf_rWaqLkWe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yzqRuiJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_uc8fxF1K_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_p70kjrsX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dZhCbWKI, 1, m, &cIf_dZhCbWKI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_W2S2YfG2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dZhCbWKI, 0, m, &cIf_dZhCbWKI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HBmGpFuN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mAK40YQY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GGPSnYu1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mAK40YQY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_lEq2HdXC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HVyR5XUy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_prVRm4Df_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1eIKIwC8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6VzZC57A_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_UfbgLvWN_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_UfbgLvWN_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_UafJabio, 1, m, &cDelay_UafJabio_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jU93QDf5_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_UafJabio_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UafJabio, m);
  cIf_onMessage(_c, &Context(_c)->cIf_lEq2HdXC, 0, m, &cIf_lEq2HdXC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UfbgLvWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_UafJabio, 0, m, &cDelay_UafJabio_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jU93QDf5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UafJabio, 0, m, &cDelay_UafJabio_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RL8b9CqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WR2UDzTa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_krMIt7xN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gwj9rnpU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ifzjl6MJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AgcU8weL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ifzjl6MJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lEq2HdXC, 1, m, &cIf_lEq2HdXC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AgcU8weL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6VzZC57A_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_WR2UDzTa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_prVRm4Df, 1, m, &cIf_prVRm4Df_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_krMIt7xN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_prVRm4Df, 0, m, &cIf_prVRm4Df_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1eIKIwC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YfoEZAEN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HVyR5XUy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YfoEZAEN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_hnIKZfmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JaYcr61w_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_5CqYb335_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bT2gpSpU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_KOV1eW6J_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_FYGKR2tY_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_FYGKR2tY_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_cPDobivr, 1, m, &cDelay_cPDobivr_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7wdypFYW_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_cPDobivr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cPDobivr, m);
  cIf_onMessage(_c, &Context(_c)->cIf_hnIKZfmI, 0, m, &cIf_hnIKZfmI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FYGKR2tY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_cPDobivr, 0, m, &cDelay_cPDobivr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7wdypFYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cPDobivr, 0, m, &cDelay_cPDobivr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SXswbcat_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ljUubJVY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UIv6YXcL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5b6PLeoD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vIVUgMO9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WqricTIZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WqricTIZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_KOV1eW6J_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_vIVUgMO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hnIKZfmI, 1, m, &cIf_hnIKZfmI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UIv6YXcL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5CqYb335, 0, m, &cIf_5CqYb335_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ljUubJVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5CqYb335, 1, m, &cIf_5CqYb335_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bT2gpSpU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lAR1Xg2G, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JaYcr61w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lAR1Xg2G, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_pqfz1qFJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_WoGcPXMf_sendMessage(_c, 0, m);
  cMsg_CWQ1jQSf_sendMessage(_c, 0, m);
  cMsg_WsvCn0S0_sendMessage(_c, 0, m);
  cMsg_XdDZAyW0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5x1DbwFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_WoGcPXMf_sendMessage(_c, 0, m);
  cMsg_G3joBhdY_sendMessage(_c, 0, m);
  cMsg_c20in9FJ_sendMessage(_c, 0, m);
  cMsg_Ags9VqBF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2tPl6TWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_CBCu4Zrc_sendMessage(_c, 0, m);
  cMsg_G3joBhdY_sendMessage(_c, 0, m);
  cMsg_XdDZAyW0_sendMessage(_c, 0, m);
  cMsg_NHtCh18R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_L20NBsFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_CBCu4Zrc_sendMessage(_c, 0, m);
  cMsg_qszehmoh_sendMessage(_c, 0, m);
  cMsg_WsvCn0S0_sendMessage(_c, 0, m);
  cMsg_tvx0xC6a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_FvXK6al9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_3dNgSukO_sendMessage(_c, 0, m);
  cMsg_Ags9VqBF_sendMessage(_c, 0, m);
  cMsg_V5rWvfZi_sendMessage(_c, 0, m);
  cMsg_WsvCn0S0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_YR50vttK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_3dNgSukO_sendMessage(_c, 0, m);
  cMsg_tvx0xC6a_sendMessage(_c, 0, m);
  cMsg_G3joBhdY_sendMessage(_c, 0, m);
  cMsg_3KD9bf8m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fVnSuXt3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cIxpelUU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qLknpozi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_N0e7lKMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cIxpelUU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qLknpozi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_01NkXE2K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5gxm3vKs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yXrL8Nz0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aDibHngS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5gxm3vKs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yXrL8Nz0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AL1OZfW4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_x9XD8exf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sgNQmPAn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qFO5ee4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_x9XD8exf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sgNQmPAn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WoGcPXMf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_fVnSuXt3_sendMessage(_c, 0, m);
  cMsg_aDibHngS_sendMessage(_c, 0, m);
  cMsg_qFO5ee4n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CBCu4Zrc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_N0e7lKMa_sendMessage(_c, 0, m);
  cMsg_01NkXE2K_sendMessage(_c, 0, m);
  cMsg_qFO5ee4n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3dNgSukO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_N0e7lKMa_sendMessage(_c, 0, m);
  cMsg_aDibHngS_sendMessage(_c, 0, m);
  cMsg_AL1OZfW4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PMXFBvcz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VLtiLIpC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AQh1SvC3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rS4HbIDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VLtiLIpC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AQh1SvC3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EA7tCPEJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_u8BUOpKL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Jie9AxHy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TQMzjyHE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_u8BUOpKL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Jie9AxHy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_msDQYQLN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zJhlMEjU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2Sv9hyP0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Cq93Sa8F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zJhlMEjU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2Sv9hyP0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_G3joBhdY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_rS4HbIDh_sendMessage(_c, 0, m);
  cMsg_TQMzjyHE_sendMessage(_c, 0, m);
  cMsg_Cq93Sa8F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CWQ1jQSf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_rS4HbIDh_sendMessage(_c, 0, m);
  cMsg_EA7tCPEJ_sendMessage(_c, 0, m);
  cMsg_msDQYQLN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qszehmoh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_PMXFBvcz_sendMessage(_c, 0, m);
  cMsg_TQMzjyHE_sendMessage(_c, 0, m);
  cMsg_msDQYQLN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1bfLEwzl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_izcvKDm1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qMq22RqJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Dno13gGY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_izcvKDm1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qMq22RqJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LvZjvglc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gwj9rnpU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RL8b9CqC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rL34N1E1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gwj9rnpU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RL8b9CqC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_utwt5JVj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5b6PLeoD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_SXswbcat_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YHKF3NIu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5b6PLeoD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_SXswbcat_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tvx0xC6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_1bfLEwzl_sendMessage(_c, 0, m);
  cMsg_rL34N1E1_sendMessage(_c, 0, m);
  cMsg_YHKF3NIu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Ags9VqBF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_Dno13gGY_sendMessage(_c, 0, m);
  cMsg_LvZjvglc_sendMessage(_c, 0, m);
  cMsg_YHKF3NIu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_XdDZAyW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_Dno13gGY_sendMessage(_c, 0, m);
  cMsg_rL34N1E1_sendMessage(_c, 0, m);
  cMsg_utwt5JVj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_tLhF8bVK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cLPf9q91_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RYjGCbdB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nHmPzjo6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cLPf9q91_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RYjGCbdB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GWUPEVRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_smwGd1Ez_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yQHL6Kuj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XWrLGOoU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_smwGd1Ez_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yQHL6Kuj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ssi3q5Hv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GDgAvhac_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7IWQZ7jX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6hWljAnb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GDgAvhac_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7IWQZ7jX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WsvCn0S0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_nHmPzjo6_sendMessage(_c, 0, m);
  cMsg_XWrLGOoU_sendMessage(_c, 0, m);
  cMsg_6hWljAnb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_c20in9FJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_nHmPzjo6_sendMessage(_c, 0, m);
  cMsg_GWUPEVRp_sendMessage(_c, 0, m);
  cMsg_ssi3q5Hv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3KD9bf8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_tLhF8bVK_sendMessage(_c, 0, m);
  cMsg_GWUPEVRp_sendMessage(_c, 0, m);
  cMsg_6hWljAnb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_V5rWvfZi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_PMXFBvcz_sendMessage(_c, 0, m);
  cMsg_EA7tCPEJ_sendMessage(_c, 0, m);
  cMsg_Cq93Sa8F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_NHtCh18R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_tLhF8bVK_sendMessage(_c, 0, m);
  cMsg_XWrLGOoU_sendMessage(_c, 0, m);
  cMsg_ssi3q5Hv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_f7NPBKnN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lYNoGtVQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_RmTD6mvy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9REUbK9j, 0, m, &cSlice_9REUbK9j_sendMessage);
      break;
    }
    default: {
      cSwitchcase_XKAps7a7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_9REUbK9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ngnRUcQ0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ngnRUcQ0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_9VWgHGMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ngnRUcQ0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ngnRUcQ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ObEk1ixs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_FsffiyJT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ChMssFQh, 0, m, &cSlice_ChMssFQh_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zU0eeOfr_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ChMssFQh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_kD0QTjct_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_kD0QTjct_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_qhcjrmBy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kD0QTjct_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_kD0QTjct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uC1OmnhV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zU0eeOfr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1uVkBWAR, 0, m, &cSlice_1uVkBWAR_sendMessage);
      break;
    }
    default: {
      cSwitchcase_RmTD6mvy_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_1uVkBWAR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_lIlMMVcP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_lIlMMVcP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_YZUWV0hv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lIlMMVcP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_lIlMMVcP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PR82eDCm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_XKAps7a7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GiTmA7Cm, 0, m, &cSlice_GiTmA7Cm_sendMessage);
      break;
    }
    default: {
      cSwitchcase_3RifXbgU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_GiTmA7Cm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_yz8pQuJw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_yz8pQuJw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_XeQ9T5Wg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yz8pQuJw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_yz8pQuJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sN5VzAK0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_3RifXbgU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rpIgJiot, 0, m, &cSlice_rpIgJiot_sendMessage);
      break;
    }
    default: {
      cSwitchcase_4sBd18wH_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_rpIgJiot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_OO1WQjQF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_OO1WQjQF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_hqDqKmQm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OO1WQjQF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_OO1WQjQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nZUl1MxT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_eSalEXut_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_nRUkORkd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_nRUkORkd_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_uRaDSgzC, 1, m, &cDelay_uRaDSgzC_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tAh5fITt_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_uRaDSgzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uRaDSgzC, m);
  cMsg_hKkmCNG4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nRUkORkd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_uRaDSgzC, 0, m, &cDelay_uRaDSgzC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tAh5fITt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_uRaDSgzC, 0, m, &cDelay_uRaDSgzC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_96yXdXUg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_79BwAJDu, HV_BINOP_SUBTRACT, 0, m, &cBinop_79BwAJDu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_tnlxBOlI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_cqtYWOX8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_yeIX9NKZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_cqtYWOX8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_Vab8C2Nk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_96yXdXUg, 0, m, &cVar_96yXdXUg_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_7LSo0ycF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QahdHdn1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c4QVDElY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TtJzUu65_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_79BwAJDu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X3b9QTrg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_X3b9QTrg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_VnYWEeK2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VnYWEeK2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_X9tDhCW3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sZq5HPPd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ekZNInEf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_spL99HYp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ekZNInEf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tnlxBOlI, 1, m, &cIf_tnlxBOlI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_spL99HYp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GTqLuzap_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ksI84ipw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yeIX9NKZ, 1, m, &cIf_yeIX9NKZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GTqLuzap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_tnlxBOlI, 0, m, &cIf_tnlxBOlI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_X9tDhCW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yeIX9NKZ, 0, m, &cIf_yeIX9NKZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QahdHdn1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_TtJzUu65_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_96yXdXUg, 0, m, &cVar_96yXdXUg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_c4QVDElY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_79BwAJDu, HV_BINOP_SUBTRACT, 1, m, &cBinop_79BwAJDu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cqtYWOX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Yag7Sdav, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4sBd18wH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gt0zZab3, 0, m, &cSlice_gt0zZab3_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_gt0zZab3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_gB4OYSf8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_gB4OYSf8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_YvGhDbvH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gB4OYSf8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_gB4OYSf8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MI2TqDNN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_tFtDs91G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gLlNlnA8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_eIzNGAZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5tIOs5Qy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_FR2fQ6dz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Dk67hGaW, 0, m, &cVar_Dk67hGaW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lYNoGtVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8qUFWHDl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_uQ5Eq88U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zsObU9MP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_cfSb4A0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_eSalEXut_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hKkmCNG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1zitPqRt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zsObU9MP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1zitPqRt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_fkSYBsH4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_IuYdSmGu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IuYdSmGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GC3DomD3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GC3DomD3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DGWtYZyf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_th0exKwl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kG7MdSAO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_b7nTVroj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7rtZ7Xd6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_dZjZuMsz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pMUiDbA9_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_joplLVQe_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6ayOw6gY_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_I4PJ9pgG_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_icTVt6tY_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PscEM3at_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_pMUiDbA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O2xMZLHF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_joplLVQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QQYXAJ4F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_6ayOw6gY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x4WM1tte_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_I4PJ9pgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a2eeSZiF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_icTVt6tY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3VzMXpFN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_PscEM3at_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UCllNmuG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_kyrWk2Dg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YktHotfU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_g26FUaQq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HUmcQVU7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_5Pl3RUXo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_vwQAcqGA_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_vwQAcqGA_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Ji2QncZv, 1, m, &cDelay_Ji2QncZv_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j7E3VZRZ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Ji2QncZv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Ji2QncZv, m);
  cIf_onMessage(_c, &Context(_c)->cIf_kyrWk2Dg, 0, m, &cIf_kyrWk2Dg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vwQAcqGA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ji2QncZv, 0, m, &cDelay_Ji2QncZv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_j7E3VZRZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ji2QncZv, 0, m, &cDelay_Ji2QncZv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BXj5PCDS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Dkoh1b2p_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wPGROHk8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HLjA0xrc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YYmlNSX1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dh6lGakj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YYmlNSX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kyrWk2Dg, 1, m, &cIf_kyrWk2Dg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dh6lGakj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5Pl3RUXo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Dkoh1b2p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_g26FUaQq, 1, m, &cIf_g26FUaQq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wPGROHk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_g26FUaQq, 0, m, &cIf_g26FUaQq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HUmcQVU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VDwP6j68, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YktHotfU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VDwP6j68, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ZJhpIUH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lHOYnxt0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_9TukPgLz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NcoK7lsX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_XKq07mpR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Ddbi9Lvu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Ddbi9Lvu_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Hhmx3ZNK, 1, m, &cDelay_Hhmx3ZNK_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dou3Q06r_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Hhmx3ZNK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Hhmx3ZNK, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ZJhpIUH3, 0, m, &cIf_ZJhpIUH3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ddbi9Lvu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Hhmx3ZNK, 0, m, &cDelay_Hhmx3ZNK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dou3Q06r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Hhmx3ZNK, 0, m, &cDelay_Hhmx3ZNK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eQUjTL37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YQ7vJukE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CefWrqHR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yUc6DVh8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DBbvRMFL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5sFEmMlC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5sFEmMlC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_XKq07mpR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_DBbvRMFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZJhpIUH3, 1, m, &cIf_ZJhpIUH3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YQ7vJukE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9TukPgLz, 1, m, &cIf_9TukPgLz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CefWrqHR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9TukPgLz, 0, m, &cIf_9TukPgLz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NcoK7lsX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XX44TUy7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_lHOYnxt0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XX44TUy7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_9IDvH2KG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0YjDvO2N_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_5fZxIEVj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_G6J6Yw0J_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Io7jeTTv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_oGQSq2mI_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_oGQSq2mI_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_cwVmen6I, 1, m, &cDelay_cwVmen6I_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qR1WKBzO_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_cwVmen6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cwVmen6I, m);
  cIf_onMessage(_c, &Context(_c)->cIf_9IDvH2KG, 0, m, &cIf_9IDvH2KG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oGQSq2mI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_cwVmen6I, 0, m, &cDelay_cwVmen6I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qR1WKBzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cwVmen6I, 0, m, &cDelay_cwVmen6I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_u7SvucYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Gx1vhZKm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cvl3Yizf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ShkELIbz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DIU6MDbp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ig5d7M7z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DIU6MDbp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9IDvH2KG, 1, m, &cIf_9IDvH2KG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ig5d7M7z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Io7jeTTv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_cvl3Yizf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5fZxIEVj, 0, m, &cIf_5fZxIEVj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Gx1vhZKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5fZxIEVj, 1, m, &cIf_5fZxIEVj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_G6J6Yw0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_w6aXpICg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0YjDvO2N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_w6aXpICg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_xKGnNvsR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_I0OmslJJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_UzP9jYoc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_I21jRrNU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_dk0DKMqE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_mW3hdvaq_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_mW3hdvaq_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Mz7KzGko, 1, m, &cDelay_Mz7KzGko_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w0gX8WNG_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Mz7KzGko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Mz7KzGko, m);
  cIf_onMessage(_c, &Context(_c)->cIf_xKGnNvsR, 0, m, &cIf_xKGnNvsR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mW3hdvaq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Mz7KzGko, 0, m, &cDelay_Mz7KzGko_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_w0gX8WNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Mz7KzGko, 0, m, &cDelay_Mz7KzGko_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vWvoVekI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_988jpJa2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X8RM3SfX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fuCOIIuB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WoLVUdVI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gRqOKSxI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WoLVUdVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xKGnNvsR, 1, m, &cIf_xKGnNvsR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gRqOKSxI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_dk0DKMqE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_988jpJa2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UzP9jYoc, 1, m, &cIf_UzP9jYoc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_X8RM3SfX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UzP9jYoc, 0, m, &cIf_UzP9jYoc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_I21jRrNU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_f6BOh6kk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_I0OmslJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_f6BOh6kk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_in4CBi4o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7AXgCp1J_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_RwoeIumg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ebxlRYTf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PwkBqaNM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_He8QmAoO_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_He8QmAoO_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_S3cy4mvl, 1, m, &cDelay_S3cy4mvl_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_S8MkUKYY_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_S3cy4mvl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_S3cy4mvl, m);
  cIf_onMessage(_c, &Context(_c)->cIf_in4CBi4o, 0, m, &cIf_in4CBi4o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_He8QmAoO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_S3cy4mvl, 0, m, &cDelay_S3cy4mvl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_S8MkUKYY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_S3cy4mvl, 0, m, &cDelay_S3cy4mvl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_N7NxINuk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_taG4DTtG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Orf0Dzuj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oHzxjOaO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4dlI9dAl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jZGgVdX7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4dlI9dAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_in4CBi4o, 1, m, &cIf_in4CBi4o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jZGgVdX7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_PwkBqaNM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_taG4DTtG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RwoeIumg, 1, m, &cIf_RwoeIumg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Orf0Dzuj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RwoeIumg, 0, m, &cIf_RwoeIumg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ebxlRYTf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_n3yD6RiJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_7AXgCp1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_n3yD6RiJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_LrvUoj6o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eLvpSson_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_rb16PU4e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xDpSDmoD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UR3GgiaA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_BMbe1uBs_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_BMbe1uBs_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_yKFHDoOf, 1, m, &cDelay_yKFHDoOf_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q709DhBP_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_yKFHDoOf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yKFHDoOf, m);
  cIf_onMessage(_c, &Context(_c)->cIf_LrvUoj6o, 0, m, &cIf_LrvUoj6o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BMbe1uBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_yKFHDoOf, 0, m, &cDelay_yKFHDoOf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_q709DhBP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_yKFHDoOf, 0, m, &cDelay_yKFHDoOf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wMAUWeJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qhahgxUN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6rxxTrNU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_26r01KPJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kS7dBZiH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LiPwLxWm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LiPwLxWm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_UR3GgiaA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_kS7dBZiH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LrvUoj6o, 1, m, &cIf_LrvUoj6o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qhahgxUN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rb16PU4e, 1, m, &cIf_rb16PU4e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6rxxTrNU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rb16PU4e, 0, m, &cIf_rb16PU4e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xDpSDmoD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_plRZ9nUu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_eLvpSson_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_plRZ9nUu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_HEVrgmuN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EF23UJjk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_v24aE7JG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zQhJ4p66_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_rwUoAtVD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ecCXMVVb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ecCXMVVb_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_y40DZmnM, 1, m, &cDelay_y40DZmnM_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z32fyx7P_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_y40DZmnM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_y40DZmnM, m);
  cIf_onMessage(_c, &Context(_c)->cIf_HEVrgmuN, 0, m, &cIf_HEVrgmuN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ecCXMVVb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_y40DZmnM, 0, m, &cDelay_y40DZmnM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_z32fyx7P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_y40DZmnM, 0, m, &cDelay_y40DZmnM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5IsEtDH0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_223BDr2k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tDPklsXL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ko2wjnP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_om54UNAK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9wfp7lBl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9wfp7lBl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_rwUoAtVD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_om54UNAK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HEVrgmuN, 1, m, &cIf_HEVrgmuN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tDPklsXL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_v24aE7JG, 0, m, &cIf_v24aE7JG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_223BDr2k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_v24aE7JG, 1, m, &cIf_v24aE7JG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zQhJ4p66_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_C6tFtCZA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_EF23UJjk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_C6tFtCZA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_1RRXLW96_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5tUo6y0Z_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_FRW54VVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Naamis2g_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_kuubqAFS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_JGc1TfoJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_JGc1TfoJ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_D6deAFAV, 1, m, &cDelay_D6deAFAV_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DQgQJoei_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_D6deAFAV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_D6deAFAV, m);
  cIf_onMessage(_c, &Context(_c)->cIf_1RRXLW96, 0, m, &cIf_1RRXLW96_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JGc1TfoJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_D6deAFAV, 0, m, &cDelay_D6deAFAV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DQgQJoei_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_D6deAFAV, 0, m, &cDelay_D6deAFAV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JIBb1Txx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GWq42RZT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ms5yHIch_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XwXVyfUO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ENzVjIvI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v2hhNonu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_v2hhNonu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_kuubqAFS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ENzVjIvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1RRXLW96, 1, m, &cIf_1RRXLW96_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ms5yHIch_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FRW54VVT, 0, m, &cIf_FRW54VVT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GWq42RZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FRW54VVT, 1, m, &cIf_FRW54VVT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Naamis2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1v52Lauc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5tUo6y0Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1v52Lauc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_0ei1eoC0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_W5Qw0RWQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_jG267RVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_krHsC48H_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_nsa2X09P_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_eiLG7AcD_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_eiLG7AcD_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_HfaKCh2Z, 1, m, &cDelay_HfaKCh2Z_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u7C9gMaj_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_HfaKCh2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HfaKCh2Z, m);
  cIf_onMessage(_c, &Context(_c)->cIf_0ei1eoC0, 0, m, &cIf_0ei1eoC0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eiLG7AcD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_HfaKCh2Z, 0, m, &cDelay_HfaKCh2Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_u7C9gMaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HfaKCh2Z, 0, m, &cDelay_HfaKCh2Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jNz6VTTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BU44kScs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EiSKqiWI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nqj6HKng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yn6kOFEL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hQbqRuVV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hQbqRuVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_nsa2X09P_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_yn6kOFEL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0ei1eoC0, 1, m, &cIf_0ei1eoC0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EiSKqiWI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jG267RVs, 0, m, &cIf_jG267RVs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BU44kScs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jG267RVs, 1, m, &cIf_jG267RVs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_krHsC48H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dojQ6Ax2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_W5Qw0RWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dojQ6Ax2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_f4aINsLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_e8nmO6f6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_DHb277t7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Su99EXW2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_HKXTIln1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_zd7rCC0G_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_zd7rCC0G_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_kmWVIcbA, 1, m, &cDelay_kmWVIcbA_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QO5HukoX_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_kmWVIcbA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kmWVIcbA, m);
  cIf_onMessage(_c, &Context(_c)->cIf_f4aINsLO, 0, m, &cIf_f4aINsLO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zd7rCC0G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_kmWVIcbA, 0, m, &cDelay_kmWVIcbA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QO5HukoX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kmWVIcbA, 0, m, &cDelay_kmWVIcbA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3OoFUPy0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1aiRPuNi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_22nwyXFH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9PM01srF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6R1RmKUY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MNybxZYG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MNybxZYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_HKXTIln1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_6R1RmKUY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_f4aINsLO, 1, m, &cIf_f4aINsLO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1aiRPuNi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DHb277t7, 1, m, &cIf_DHb277t7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_22nwyXFH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DHb277t7, 0, m, &cIf_DHb277t7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Su99EXW2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ECvhcurD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_e8nmO6f6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ECvhcurD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_uTlSzZXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XXmsZRyZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_T5ffRsf8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TUkxNV13_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_C3RggvQ7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_muEDWqZ8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_muEDWqZ8_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_zuUBfjme, 1, m, &cDelay_zuUBfjme_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5ccOxX1F_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_zuUBfjme_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zuUBfjme, m);
  cIf_onMessage(_c, &Context(_c)->cIf_uTlSzZXw, 0, m, &cIf_uTlSzZXw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_muEDWqZ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zuUBfjme, 0, m, &cDelay_zuUBfjme_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5ccOxX1F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zuUBfjme, 0, m, &cDelay_zuUBfjme_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RnoIGzVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tYB4yEep_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EF6aIB8I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XvnTqP7i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ta8RLgQj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Qd13p6Hc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Qd13p6Hc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_C3RggvQ7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ta8RLgQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uTlSzZXw, 1, m, &cIf_uTlSzZXw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EF6aIB8I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_T5ffRsf8, 0, m, &cIf_T5ffRsf8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tYB4yEep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_T5ffRsf8, 1, m, &cIf_T5ffRsf8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TUkxNV13_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lawUtHkC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_XXmsZRyZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lawUtHkC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_2dsI1VOR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lXqZ8jp3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Ta8aL6Ay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hnOGuQHP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_k7h3aDPA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ei3bOe0H_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ei3bOe0H_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_PwbEgWNT, 1, m, &cDelay_PwbEgWNT_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Con8PaUk_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_PwbEgWNT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PwbEgWNT, m);
  cIf_onMessage(_c, &Context(_c)->cIf_2dsI1VOR, 0, m, &cIf_2dsI1VOR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ei3bOe0H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_PwbEgWNT, 0, m, &cDelay_PwbEgWNT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Con8PaUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PwbEgWNT, 0, m, &cDelay_PwbEgWNT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dly0f9vt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wEwjxSR7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tcp13UdO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FsTYuIVL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s8AuZfKa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZoJ5eowe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZoJ5eowe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_k7h3aDPA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_s8AuZfKa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2dsI1VOR, 1, m, &cIf_2dsI1VOR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tcp13UdO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ta8aL6Ay, 0, m, &cIf_Ta8aL6Ay_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wEwjxSR7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ta8aL6Ay, 1, m, &cIf_Ta8aL6Ay_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hnOGuQHP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0Y5Sf33o, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_lXqZ8jp3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0Y5Sf33o, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_O2xMZLHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_ahiRza1s_sendMessage(_c, 0, m);
  cMsg_YpE7CQjd_sendMessage(_c, 0, m);
  cMsg_J0iyzDWd_sendMessage(_c, 0, m);
  cMsg_lDnFedbX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_QQYXAJ4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_ahiRza1s_sendMessage(_c, 0, m);
  cMsg_OazeMIbP_sendMessage(_c, 0, m);
  cMsg_vquWpsBU_sendMessage(_c, 0, m);
  cMsg_XPkJzOqD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_x4WM1tte_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_XUMocKM5_sendMessage(_c, 0, m);
  cMsg_OazeMIbP_sendMessage(_c, 0, m);
  cMsg_lDnFedbX_sendMessage(_c, 0, m);
  cMsg_otioyuoc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_a2eeSZiF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_XUMocKM5_sendMessage(_c, 0, m);
  cMsg_scTCSCLQ_sendMessage(_c, 0, m);
  cMsg_J0iyzDWd_sendMessage(_c, 0, m);
  cMsg_ohz6EKjz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3VzMXpFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_HUwjF6me_sendMessage(_c, 0, m);
  cMsg_XPkJzOqD_sendMessage(_c, 0, m);
  cMsg_T9JYM9NA_sendMessage(_c, 0, m);
  cMsg_J0iyzDWd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UCllNmuG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_HUwjF6me_sendMessage(_c, 0, m);
  cMsg_ohz6EKjz_sendMessage(_c, 0, m);
  cMsg_OazeMIbP_sendMessage(_c, 0, m);
  cMsg_Eko9BRFa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ooDsF0GF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HLjA0xrc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BXj5PCDS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BZTcgwiA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HLjA0xrc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BXj5PCDS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9KvLUQgz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yUc6DVh8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eQUjTL37_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dNLfPA1N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yUc6DVh8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eQUjTL37_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xSwtGEby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ShkELIbz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_u7SvucYP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_15G9i10V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ShkELIbz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_u7SvucYP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ahiRza1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_ooDsF0GF_sendMessage(_c, 0, m);
  cMsg_dNLfPA1N_sendMessage(_c, 0, m);
  cMsg_15G9i10V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_XUMocKM5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_BZTcgwiA_sendMessage(_c, 0, m);
  cMsg_9KvLUQgz_sendMessage(_c, 0, m);
  cMsg_15G9i10V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_HUwjF6me_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_BZTcgwiA_sendMessage(_c, 0, m);
  cMsg_dNLfPA1N_sendMessage(_c, 0, m);
  cMsg_xSwtGEby_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_TjcBvhKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fuCOIIuB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vWvoVekI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aEYltyTJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fuCOIIuB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vWvoVekI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ScaAv0rz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_oHzxjOaO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_N7NxINuk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MgxnodKM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_oHzxjOaO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_N7NxINuk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_O7P9RGNU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_26r01KPJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wMAUWeJZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3zbg6H6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_26r01KPJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wMAUWeJZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OazeMIbP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_aEYltyTJ_sendMessage(_c, 0, m);
  cMsg_MgxnodKM_sendMessage(_c, 0, m);
  cMsg_3zbg6H6V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_YpE7CQjd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_aEYltyTJ_sendMessage(_c, 0, m);
  cMsg_ScaAv0rz_sendMessage(_c, 0, m);
  cMsg_O7P9RGNU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_scTCSCLQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_TjcBvhKg_sendMessage(_c, 0, m);
  cMsg_MgxnodKM_sendMessage(_c, 0, m);
  cMsg_O7P9RGNU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ps6hun3O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9PM01srF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3OoFUPy0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UvSjedvj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9PM01srF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3OoFUPy0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rNUCW62l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XvnTqP7i_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RnoIGzVH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Z1w8naDy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XvnTqP7i_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RnoIGzVH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MZSPolqH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_FsTYuIVL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dly0f9vt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TUBN6PmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_FsTYuIVL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dly0f9vt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ohz6EKjz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_ps6hun3O_sendMessage(_c, 0, m);
  cMsg_Z1w8naDy_sendMessage(_c, 0, m);
  cMsg_TUBN6PmC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_XPkJzOqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_UvSjedvj_sendMessage(_c, 0, m);
  cMsg_rNUCW62l_sendMessage(_c, 0, m);
  cMsg_TUBN6PmC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lDnFedbX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_UvSjedvj_sendMessage(_c, 0, m);
  cMsg_Z1w8naDy_sendMessage(_c, 0, m);
  cMsg_MZSPolqH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_cBcGu7wE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ko2wjnP5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5IsEtDH0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_50WSy6Do_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ko2wjnP5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5IsEtDH0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_h5JswWMn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XwXVyfUO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JIBb1Txx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_A3ywQdCc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XwXVyfUO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JIBb1Txx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Cfg9OUpV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_nqj6HKng_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jNz6VTTY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CoBNfXZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_nqj6HKng_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jNz6VTTY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_J0iyzDWd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_50WSy6Do_sendMessage(_c, 0, m);
  cMsg_A3ywQdCc_sendMessage(_c, 0, m);
  cMsg_CoBNfXZI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_vquWpsBU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_50WSy6Do_sendMessage(_c, 0, m);
  cMsg_h5JswWMn_sendMessage(_c, 0, m);
  cMsg_Cfg9OUpV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Eko9BRFa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_cBcGu7wE_sendMessage(_c, 0, m);
  cMsg_h5JswWMn_sendMessage(_c, 0, m);
  cMsg_CoBNfXZI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_T9JYM9NA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_TjcBvhKg_sendMessage(_c, 0, m);
  cMsg_ScaAv0rz_sendMessage(_c, 0, m);
  cMsg_3zbg6H6V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_otioyuoc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_cBcGu7wE_sendMessage(_c, 0, m);
  cMsg_A3ywQdCc_sendMessage(_c, 0, m);
  cMsg_Cfg9OUpV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_TU32IZjr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P639FrLb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_CAtMclir_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GNjHZZGt, 0, m, &cSlice_GNjHZZGt_sendMessage);
      break;
    }
    default: {
      cSwitchcase_S5XU9h2w_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_GNjHZZGt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_4cwhuzqE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_4cwhuzqE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Qj11yOFv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4cwhuzqE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_4cwhuzqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9jom1PUg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_qTR0tZ48_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_QumeeFHZ, 0, m, &cSlice_QumeeFHZ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_6bvJywNQ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_QumeeFHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_OunQTXma_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_OunQTXma_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_jZY58dxA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OunQTXma_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_OunQTXma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JzQj7yWu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6bvJywNQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_theEZZ1b, 0, m, &cSlice_theEZZ1b_sendMessage);
      break;
    }
    default: {
      cSwitchcase_CAtMclir_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_theEZZ1b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_o2ibOhIp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_o2ibOhIp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_L4J08TWe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_o2ibOhIp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_o2ibOhIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dRx3HTzB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_S5XU9h2w_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ugHx8vNO, 0, m, &cSlice_ugHx8vNO_sendMessage);
      break;
    }
    default: {
      cSwitchcase_hMOMcoLD_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ugHx8vNO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MjVo8m3y_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MjVo8m3y_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_jK8qyWDU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MjVo8m3y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_MjVo8m3y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dl3aLlne_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_hMOMcoLD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_QP7GvFLq, 0, m, &cSlice_QP7GvFLq_sendMessage);
      break;
    }
    default: {
      cSwitchcase_183IY4ei_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_QP7GvFLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_CCQCcCr7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_CCQCcCr7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_o2Du3tv6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CCQCcCr7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_CCQCcCr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OcsAmQRr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_WonHhst9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_d1xYYnky_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_d1xYYnky_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Zeh1RHCo, 1, m, &cDelay_Zeh1RHCo_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ouyPfJ0V_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Zeh1RHCo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Zeh1RHCo, m);
  cMsg_jbpxnnpy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_d1xYYnky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Zeh1RHCo, 0, m, &cDelay_Zeh1RHCo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ouyPfJ0V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Zeh1RHCo, 0, m, &cDelay_Zeh1RHCo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_QFSsiNEW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pUs7x8Zf, HV_BINOP_SUBTRACT, 0, m, &cBinop_pUs7x8Zf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_i08fDHsz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_crcrVOoA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_2hFZZBY6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_crcrVOoA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_SebcApkC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QFSsiNEW, 0, m, &cVar_QFSsiNEW_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_NVpinrgk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_p46aZlKg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dvQPGc12_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O8N8HYNE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pUs7x8Zf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5YlVle0p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5YlVle0p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_MNgXy2Av_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MNgXy2Av_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_ayTKPYSi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GhzKuOoK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_h3l1N8sE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_upRiv8IU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_h3l1N8sE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_i08fDHsz, 1, m, &cIf_i08fDHsz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_upRiv8IU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_084brXXJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_xzS0O702_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2hFZZBY6, 1, m, &cIf_2hFZZBY6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_084brXXJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_i08fDHsz, 0, m, &cIf_i08fDHsz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ayTKPYSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2hFZZBY6, 0, m, &cIf_2hFZZBY6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_p46aZlKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_O8N8HYNE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QFSsiNEW, 0, m, &cVar_QFSsiNEW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dvQPGc12_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pUs7x8Zf, HV_BINOP_SUBTRACT, 1, m, &cBinop_pUs7x8Zf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_crcrVOoA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bI2EUWQ6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_183IY4ei_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_sRqHn11F, 0, m, &cSlice_sRqHn11F_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_sRqHn11F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_uNwFkL8h_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_uNwFkL8h_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_wJODObdJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uNwFkL8h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_uNwFkL8h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9enWemSC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kG7MdSAO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7eWR2twk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_7rtZ7Xd6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tsPkPeLQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_R5db3yHU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_b7nTVroj, 0, m, &cVar_b7nTVroj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_P639FrLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_g6gD2mH3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_B97YQO42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tPrmdRUX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_5KaJNu9n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_WonHhst9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jbpxnnpy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hCh9b5xs, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tPrmdRUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hCh9b5xs, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_uYZ2ErTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_SJznrr6J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SJznrr6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2LiwWYnj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2LiwWYnj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jp0p0uDd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_EE0A2WvJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BTOdCF3s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_KAyw8LI3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Gfnsg9g8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_np0c0xQX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8xJyRWJI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_oQKRtR1c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Vhy9uXVl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_lYcpsNve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4Xqh5RZ2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_vqRoXdF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wpq3Gw89_sendMessage);
  cMsg_yzQPEbXG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_wpq3Gw89_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vqRoXdF3, 1, m, &cVar_vqRoXdF3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VOOru5xs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HXcUbmJA_sendMessage(_c, 0, m);
  cMsg_0m8JEIur_sendMessage(_c, 0, m);
  cMsg_FpVNiMpB_sendMessage(_c, 0, m);
  cMsg_q0YO08FH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_odPXO5xX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ZAoUbb99, 0, m, &cSlice_ZAoUbb99_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ZAoUbb99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_J5HSSbvQ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_J5HSSbvQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_jUi3BycM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_J5HSSbvQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_J5HSSbvQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pQNOJMat_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_vsnWIXsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_8inI3A55_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8inI3A55_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_qMKpIu3a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qMKpIu3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_tP5ohMaE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tP5ohMaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4pQc57HA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y2vXg4NO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4pQc57HA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_tRa9fpDn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_y2vXg4NO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OhHfECxk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_tRa9fpDn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7mXUEMXL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OhHfECxk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_iyCkHukB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iyCkHukB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_k3GCpOIT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7mXUEMXL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gzx3yI4C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_k3GCpOIT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mT2DAK8L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_gzx3yI4C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zskjx6sR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_mT2DAK8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wt4CEhaf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_EnFXUabm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5bL6vL3k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_5NFce6E5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vTisWL0k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_j17i3mTU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Id7KBw5z_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JUl9KZXk_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n5F0kd73_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W8W7lQHc_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_huckbIbG_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jp77sXoK_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_Id7KBw5z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A62DJhZ1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_JUl9KZXk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rBYHzXIN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_n5F0kd73_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PxAMamC3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_W8W7lQHc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_znfO5XNh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_huckbIbG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DIdzrtf8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_jp77sXoK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_prhrs74W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_MYHhnbOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_z8vyB6cw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_lniVhoWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PtGwjCCU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_dhHBji1v_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_XrQzZc7C_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_XrQzZc7C_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_IuQ3D3kU, 1, m, &cDelay_IuQ3D3kU_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GQE6jxsx_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_IuQ3D3kU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IuQ3D3kU, m);
  cIf_onMessage(_c, &Context(_c)->cIf_MYHhnbOQ, 0, m, &cIf_MYHhnbOQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XrQzZc7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_IuQ3D3kU, 0, m, &cDelay_IuQ3D3kU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GQE6jxsx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_IuQ3D3kU, 0, m, &cDelay_IuQ3D3kU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JcTaZ1xI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T6RN7nxI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EjjbWTAB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wogS3eoZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QnkHoBe8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4qvixEdJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QnkHoBe8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MYHhnbOQ, 1, m, &cIf_MYHhnbOQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4qvixEdJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_dhHBji1v_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_T6RN7nxI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lniVhoWu, 1, m, &cIf_lniVhoWu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EjjbWTAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lniVhoWu, 0, m, &cIf_lniVhoWu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PtGwjCCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4evbcxnu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_z8vyB6cw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4evbcxnu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_xDEVbR2M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6q8HPzCA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_dnNqqgNO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Dv5RON9b_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_BsB6vEso_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_E8wa6MgT_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_E8wa6MgT_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_qejbIzqe, 1, m, &cDelay_qejbIzqe_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gOKHVCbC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_qejbIzqe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qejbIzqe, m);
  cIf_onMessage(_c, &Context(_c)->cIf_xDEVbR2M, 0, m, &cIf_xDEVbR2M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_E8wa6MgT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_qejbIzqe, 0, m, &cDelay_qejbIzqe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gOKHVCbC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_qejbIzqe, 0, m, &cDelay_qejbIzqe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KbKNtPhE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yYNS0FOT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dtqffFVf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Kl3Ly0kC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aQHvwqcv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hgJRK5yD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aQHvwqcv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xDEVbR2M, 1, m, &cIf_xDEVbR2M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hgJRK5yD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BsB6vEso_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_yYNS0FOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dnNqqgNO, 1, m, &cIf_dnNqqgNO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dtqffFVf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dnNqqgNO, 0, m, &cIf_dnNqqgNO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Dv5RON9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IRwnmGeo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_6q8HPzCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IRwnmGeo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_VC1Tgacs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PEYhzlqO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_JXnJg9Uy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zLrIXFvP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_FTZ1xK6I_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_WFT5gDdF_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_WFT5gDdF_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7R8qJMFE, 1, m, &cDelay_7R8qJMFE_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TuleLtvb_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_7R8qJMFE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7R8qJMFE, m);
  cIf_onMessage(_c, &Context(_c)->cIf_VC1Tgacs, 0, m, &cIf_VC1Tgacs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WFT5gDdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7R8qJMFE, 0, m, &cDelay_7R8qJMFE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TuleLtvb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7R8qJMFE, 0, m, &cDelay_7R8qJMFE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3Bj3uABc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oAgs56CV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XrLAMyIU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_S2sBBPIA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yHe00ZK9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mynUVb5K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mynUVb5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_FTZ1xK6I_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_yHe00ZK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VC1Tgacs, 1, m, &cIf_VC1Tgacs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oAgs56CV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JXnJg9Uy, 1, m, &cIf_JXnJg9Uy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XrLAMyIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JXnJg9Uy, 0, m, &cIf_JXnJg9Uy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zLrIXFvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tJmxRwCr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_PEYhzlqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tJmxRwCr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_jlQydz7B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Y0mBwR2F_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_wQR9ekG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_V4CpF2LT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_FxlK5S8h_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_1p3g4gOd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_1p3g4gOd_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_s4FsoRTD, 1, m, &cDelay_s4FsoRTD_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FvvWvLut_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_s4FsoRTD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_s4FsoRTD, m);
  cIf_onMessage(_c, &Context(_c)->cIf_jlQydz7B, 0, m, &cIf_jlQydz7B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1p3g4gOd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_s4FsoRTD, 0, m, &cDelay_s4FsoRTD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FvvWvLut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_s4FsoRTD, 0, m, &cDelay_s4FsoRTD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PDjTKqpE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X1k3gCFy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6qNPsh23_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aLdpMEoR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SEYic5Sy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ahJhrz9j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ahJhrz9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_FxlK5S8h_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_SEYic5Sy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jlQydz7B, 1, m, &cIf_jlQydz7B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6qNPsh23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wQR9ekG4, 0, m, &cIf_wQR9ekG4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_X1k3gCFy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wQR9ekG4, 1, m, &cIf_wQR9ekG4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_V4CpF2LT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nupK7uV8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Y0mBwR2F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nupK7uV8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_5M069YIm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EYS3nolw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_oMw3lWJA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_k7Ht87m5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_jAk5tMyn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_NQI22yxW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_NQI22yxW_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_USMc2VVU, 1, m, &cDelay_USMc2VVU_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JWBO6lrn_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_USMc2VVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_USMc2VVU, m);
  cIf_onMessage(_c, &Context(_c)->cIf_5M069YIm, 0, m, &cIf_5M069YIm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NQI22yxW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_USMc2VVU, 0, m, &cDelay_USMc2VVU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JWBO6lrn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_USMc2VVU, 0, m, &cDelay_USMc2VVU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yvOz8Dip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2gV55Hnb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_I3BlUJaJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_U1xWHruZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZAJy1aOS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_L5qzlZ2v_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZAJy1aOS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5M069YIm, 1, m, &cIf_5M069YIm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_L5qzlZ2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_jAk5tMyn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_2gV55Hnb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oMw3lWJA, 1, m, &cIf_oMw3lWJA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_I3BlUJaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oMw3lWJA, 0, m, &cIf_oMw3lWJA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_k7Ht87m5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HWilLpMo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_EYS3nolw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HWilLpMo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_lja8VwLt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UEPzkVVq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_KPY4DVhJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gWibqgFa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_lINtMhMk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_0jNjvsgZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_0jNjvsgZ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_nSv1mN0d, 1, m, &cDelay_nSv1mN0d_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LtzmB1ux_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_nSv1mN0d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nSv1mN0d, m);
  cIf_onMessage(_c, &Context(_c)->cIf_lja8VwLt, 0, m, &cIf_lja8VwLt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0jNjvsgZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_nSv1mN0d, 0, m, &cDelay_nSv1mN0d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LtzmB1ux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nSv1mN0d, 0, m, &cDelay_nSv1mN0d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7kKir1uY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v1bMXeVg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kywZshT2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1Hjy5Kht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ti5166ve_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_682dNulJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ti5166ve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lja8VwLt, 1, m, &cIf_lja8VwLt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_682dNulJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_lINtMhMk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_v1bMXeVg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KPY4DVhJ, 1, m, &cIf_KPY4DVhJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kywZshT2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KPY4DVhJ, 0, m, &cIf_KPY4DVhJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gWibqgFa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WbCaSSpp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_UEPzkVVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WbCaSSpp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_KAGxFEjH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_14bP4H1P_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_kmBK6ihI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0RWBHru9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Qzs7kb07_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_oysnDZ1d_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_oysnDZ1d_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_CdTmPXTk, 1, m, &cDelay_CdTmPXTk_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zYTqDXLA_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_CdTmPXTk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CdTmPXTk, m);
  cIf_onMessage(_c, &Context(_c)->cIf_KAGxFEjH, 0, m, &cIf_KAGxFEjH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oysnDZ1d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_CdTmPXTk, 0, m, &cDelay_CdTmPXTk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zYTqDXLA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CdTmPXTk, 0, m, &cDelay_CdTmPXTk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ARVegeFl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zGYKJu3z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u0xnE1xf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MA4GTxh9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nIRLkFUo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EYSHJz2Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EYSHJz2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Qzs7kb07_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_nIRLkFUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KAGxFEjH, 1, m, &cIf_KAGxFEjH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zGYKJu3z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kmBK6ihI, 1, m, &cIf_kmBK6ihI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_u0xnE1xf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kmBK6ihI, 0, m, &cIf_kmBK6ihI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0RWBHru9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yCcYTrOX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_14bP4H1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yCcYTrOX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_tJ3mKSK7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_plIfTgwQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_RWsvjuBI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_c89QvgAH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_xPKBiarM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_sgiokoTW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_sgiokoTW_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_I1Jx9ZGj, 1, m, &cDelay_I1Jx9ZGj_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_L33wYxGH_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_I1Jx9ZGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_I1Jx9ZGj, m);
  cIf_onMessage(_c, &Context(_c)->cIf_tJ3mKSK7, 0, m, &cIf_tJ3mKSK7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sgiokoTW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_I1Jx9ZGj, 0, m, &cDelay_I1Jx9ZGj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_L33wYxGH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_I1Jx9ZGj, 0, m, &cDelay_I1Jx9ZGj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vnYqjX1m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZvRKq5MW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9LgGw3P0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iTGsuEd3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v16cPnIR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_D94LVGAq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_D94LVGAq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_xPKBiarM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_v16cPnIR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tJ3mKSK7, 1, m, &cIf_tJ3mKSK7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9LgGw3P0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RWsvjuBI, 0, m, &cIf_RWsvjuBI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZvRKq5MW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RWsvjuBI, 1, m, &cIf_RWsvjuBI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_c89QvgAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PanNwXSZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_plIfTgwQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PanNwXSZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_CoIkMARe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qfduxJTz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_BrZbN1do_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LRFkIvGX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_KD0TzFSr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_YU7Err16_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_YU7Err16_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_hKUsDoQW, 1, m, &cDelay_hKUsDoQW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1S8se0hj_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_hKUsDoQW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hKUsDoQW, m);
  cIf_onMessage(_c, &Context(_c)->cIf_CoIkMARe, 0, m, &cIf_CoIkMARe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YU7Err16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_hKUsDoQW, 0, m, &cDelay_hKUsDoQW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1S8se0hj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hKUsDoQW, 0, m, &cDelay_hKUsDoQW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7G03gcDq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GIQb46ZK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i7bNifcL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9TD8rInB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bIWQbBxN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Zw9uylC2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Zw9uylC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_KD0TzFSr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_bIWQbBxN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CoIkMARe, 1, m, &cIf_CoIkMARe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_i7bNifcL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BrZbN1do, 0, m, &cIf_BrZbN1do_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GIQb46ZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BrZbN1do, 1, m, &cIf_BrZbN1do_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LRFkIvGX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hDomaCGc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qfduxJTz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hDomaCGc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_AHDFaYnb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EXsczfDx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_L35Yx1Bn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QzlQLMP3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_nJ03ib0r_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_fzG5qg4Y_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_fzG5qg4Y_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_bkuYv2md, 1, m, &cDelay_bkuYv2md_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zdzJyaOU_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_bkuYv2md_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bkuYv2md, m);
  cIf_onMessage(_c, &Context(_c)->cIf_AHDFaYnb, 0, m, &cIf_AHDFaYnb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fzG5qg4Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_bkuYv2md, 0, m, &cDelay_bkuYv2md_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zdzJyaOU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_bkuYv2md, 0, m, &cDelay_bkuYv2md_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YnnhJB6B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_daOeyEyx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4VoKPlJS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_E9MMpL1F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wjEo2Dsc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sQ7lqfcq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sQ7lqfcq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_nJ03ib0r_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_wjEo2Dsc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AHDFaYnb, 1, m, &cIf_AHDFaYnb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4VoKPlJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_L35Yx1Bn, 0, m, &cIf_L35Yx1Bn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_daOeyEyx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_L35Yx1Bn, 1, m, &cIf_L35Yx1Bn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QzlQLMP3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FAGprRyj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_EXsczfDx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FAGprRyj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_xmUUaMaN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0bCP9R80_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_tXY0Tzn7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9XWOavyn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_SS3Pynao_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_sltVL6hy_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_sltVL6hy_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_PNjF28iu, 1, m, &cDelay_PNjF28iu_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0igojIPI_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_PNjF28iu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PNjF28iu, m);
  cIf_onMessage(_c, &Context(_c)->cIf_xmUUaMaN, 0, m, &cIf_xmUUaMaN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sltVL6hy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_PNjF28iu, 0, m, &cDelay_PNjF28iu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0igojIPI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PNjF28iu, 0, m, &cDelay_PNjF28iu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LDSDwHXY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PYQUgIbl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_audnfrDp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IEQYWLUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eIEEZNxi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7WtldTLK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7WtldTLK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_SS3Pynao_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_eIEEZNxi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xmUUaMaN, 1, m, &cIf_xmUUaMaN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_audnfrDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tXY0Tzn7, 0, m, &cIf_tXY0Tzn7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PYQUgIbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tXY0Tzn7, 1, m, &cIf_tXY0Tzn7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9XWOavyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dObJ04sd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0bCP9R80_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dObJ04sd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Wgp8A5No_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OrlB9u8O_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_eIjvkspR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0Lv0Mpvz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Mh1s9BKc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_HxB7CmRP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_HxB7CmRP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_BbMPROBi, 1, m, &cDelay_BbMPROBi_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nQJEWq9B_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_BbMPROBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BbMPROBi, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Wgp8A5No, 0, m, &cIf_Wgp8A5No_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HxB7CmRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_BbMPROBi, 0, m, &cDelay_BbMPROBi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nQJEWq9B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BbMPROBi, 0, m, &cDelay_BbMPROBi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_drYzM3Bl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SQc2d3Sp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BSmB5osD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ekWNrIou_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xY2ZkRdW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VDz1DpQU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VDz1DpQU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Mh1s9BKc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_xY2ZkRdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Wgp8A5No, 1, m, &cIf_Wgp8A5No_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BSmB5osD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eIjvkspR, 0, m, &cIf_eIjvkspR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SQc2d3Sp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eIjvkspR, 1, m, &cIf_eIjvkspR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0Lv0Mpvz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_V0EU16uj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_OrlB9u8O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_V0EU16uj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_A62DJhZ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_SZTsRpWW_sendMessage(_c, 0, m);
  cMsg_IRCrr8XR_sendMessage(_c, 0, m);
  cMsg_CGKG5EJ5_sendMessage(_c, 0, m);
  cMsg_ch1AjSYb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rBYHzXIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_SZTsRpWW_sendMessage(_c, 0, m);
  cMsg_QpFfrrUK_sendMessage(_c, 0, m);
  cMsg_ZFfD3VYV_sendMessage(_c, 0, m);
  cMsg_uRMY3aJx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PxAMamC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_q0NziBxt_sendMessage(_c, 0, m);
  cMsg_QpFfrrUK_sendMessage(_c, 0, m);
  cMsg_ch1AjSYb_sendMessage(_c, 0, m);
  cMsg_kk1EN8Ds_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_znfO5XNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_q0NziBxt_sendMessage(_c, 0, m);
  cMsg_STLWP0h2_sendMessage(_c, 0, m);
  cMsg_CGKG5EJ5_sendMessage(_c, 0, m);
  cMsg_Yfc3qJbl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DIdzrtf8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_UNvu90uh_sendMessage(_c, 0, m);
  cMsg_uRMY3aJx_sendMessage(_c, 0, m);
  cMsg_iQlIQHqy_sendMessage(_c, 0, m);
  cMsg_CGKG5EJ5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_prhrs74W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_UNvu90uh_sendMessage(_c, 0, m);
  cMsg_Yfc3qJbl_sendMessage(_c, 0, m);
  cMsg_QpFfrrUK_sendMessage(_c, 0, m);
  cMsg_SUiRWEaH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_MFdxahQ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wogS3eoZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JcTaZ1xI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WzSRkkoz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wogS3eoZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JcTaZ1xI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zhTUQrI9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Kl3Ly0kC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KbKNtPhE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KCekViQc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Kl3Ly0kC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KbKNtPhE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Y0iv6gun_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_S2sBBPIA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3Bj3uABc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GAItisSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_S2sBBPIA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3Bj3uABc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SZTsRpWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_MFdxahQ1_sendMessage(_c, 0, m);
  cMsg_KCekViQc_sendMessage(_c, 0, m);
  cMsg_GAItisSi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_q0NziBxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_WzSRkkoz_sendMessage(_c, 0, m);
  cMsg_zhTUQrI9_sendMessage(_c, 0, m);
  cMsg_GAItisSi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UNvu90uh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_WzSRkkoz_sendMessage(_c, 0, m);
  cMsg_KCekViQc_sendMessage(_c, 0, m);
  cMsg_Y0iv6gun_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_yp0Ax4hW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_aLdpMEoR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PDjTKqpE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rQJs3orA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_aLdpMEoR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PDjTKqpE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hORD5Lm5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_U1xWHruZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yvOz8Dip_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0RmRLIjv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_U1xWHruZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yvOz8Dip_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BQ2RO8ku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1Hjy5Kht_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7kKir1uY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gTutZ9i6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1Hjy5Kht_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7kKir1uY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QpFfrrUK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_rQJs3orA_sendMessage(_c, 0, m);
  cMsg_0RmRLIjv_sendMessage(_c, 0, m);
  cMsg_gTutZ9i6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_IRCrr8XR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_rQJs3orA_sendMessage(_c, 0, m);
  cMsg_hORD5Lm5_sendMessage(_c, 0, m);
  cMsg_BQ2RO8ku_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_STLWP0h2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_yp0Ax4hW_sendMessage(_c, 0, m);
  cMsg_0RmRLIjv_sendMessage(_c, 0, m);
  cMsg_BQ2RO8ku_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_8nRrYuVm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_E9MMpL1F_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YnnhJB6B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zTDyTPPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_E9MMpL1F_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YnnhJB6B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GaMYC79k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_IEQYWLUR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LDSDwHXY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0h0W0Ahj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_IEQYWLUR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LDSDwHXY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JskfORa3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ekWNrIou_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_drYzM3Bl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hqDbdEPw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ekWNrIou_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_drYzM3Bl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Yfc3qJbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_8nRrYuVm_sendMessage(_c, 0, m);
  cMsg_0h0W0Ahj_sendMessage(_c, 0, m);
  cMsg_hqDbdEPw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_uRMY3aJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_zTDyTPPg_sendMessage(_c, 0, m);
  cMsg_GaMYC79k_sendMessage(_c, 0, m);
  cMsg_hqDbdEPw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ch1AjSYb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_zTDyTPPg_sendMessage(_c, 0, m);
  cMsg_0h0W0Ahj_sendMessage(_c, 0, m);
  cMsg_JskfORa3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_bxzecXrB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MA4GTxh9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ARVegeFl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fGx8Sy3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MA4GTxh9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ARVegeFl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_y7UMYKMN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iTGsuEd3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vnYqjX1m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5UKkqXbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iTGsuEd3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vnYqjX1m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_M28OiRWz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9TD8rInB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7G03gcDq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OV6lJw3b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9TD8rInB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7G03gcDq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CGKG5EJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_fGx8Sy3l_sendMessage(_c, 0, m);
  cMsg_5UKkqXbq_sendMessage(_c, 0, m);
  cMsg_OV6lJw3b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ZFfD3VYV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_fGx8Sy3l_sendMessage(_c, 0, m);
  cMsg_y7UMYKMN_sendMessage(_c, 0, m);
  cMsg_M28OiRWz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SUiRWEaH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_bxzecXrB_sendMessage(_c, 0, m);
  cMsg_y7UMYKMN_sendMessage(_c, 0, m);
  cMsg_OV6lJw3b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_iQlIQHqy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_yp0Ax4hW_sendMessage(_c, 0, m);
  cMsg_hORD5Lm5_sendMessage(_c, 0, m);
  cMsg_gTutZ9i6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kk1EN8Ds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_bxzecXrB_sendMessage(_c, 0, m);
  cMsg_5UKkqXbq_sendMessage(_c, 0, m);
  cMsg_M28OiRWz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_9xYvZgsu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h5VS7bW6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VYet53rK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Z1A3EXvq, 0, m, &cSlice_Z1A3EXvq_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Mv2RL9Zn_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Z1A3EXvq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_FDBCFpoC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_FDBCFpoC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_6iPb83CS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FDBCFpoC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_FDBCFpoC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_aG8VYCE0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_akOeeURA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0GEby73d, 0, m, &cSlice_0GEby73d_sendMessage);
      break;
    }
    default: {
      cSwitchcase_9al3DTgz_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_0GEby73d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_PaFcXO5T_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_PaFcXO5T_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_AiwS0bSa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PaFcXO5T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_PaFcXO5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CUIvw89q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9al3DTgz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_hxAlRUfP, 0, m, &cSlice_hxAlRUfP_sendMessage);
      break;
    }
    default: {
      cSwitchcase_VYet53rK_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_hxAlRUfP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_dhft3ygM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_dhft3ygM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Ifi40YJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dhft3ygM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_dhft3ygM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_afLXrcJ9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Mv2RL9Zn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_tUYoT2dQ, 0, m, &cSlice_tUYoT2dQ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_VC8SAccz_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_tUYoT2dQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_s8iRtHHX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_s8iRtHHX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_YKjOtGOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_s8iRtHHX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_s8iRtHHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yi5F4Zzf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VC8SAccz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_AEwLAJkM, 0, m, &cSlice_AEwLAJkM_sendMessage);
      break;
    }
    default: {
      cSwitchcase_bztBasBx_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_AEwLAJkM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jpIYAfRo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jpIYAfRo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_hf2w8GAX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jpIYAfRo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_jpIYAfRo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WVZeA7tg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_iqovOSOW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_mkwSXFjQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_mkwSXFjQ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_QZQXE8jo, 1, m, &cDelay_QZQXE8jo_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DTwLJzdJ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_QZQXE8jo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_QZQXE8jo, m);
  cMsg_infYFkx9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_mkwSXFjQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_QZQXE8jo, 0, m, &cDelay_QZQXE8jo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DTwLJzdJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_QZQXE8jo, 0, m, &cDelay_QZQXE8jo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_vSCVUS06_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q3WQBCMs, HV_BINOP_SUBTRACT, 0, m, &cBinop_q3WQBCMs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_fRaeeWfk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zigSgN3o_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_eyRLdUVc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zigSgN3o_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_SXUIox5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vSCVUS06, 0, m, &cVar_vSCVUS06_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_bgmQ18zr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uWiHZsbT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_arcSFUSw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3CwdBBuz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_q3WQBCMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F4GaxVUQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_F4GaxVUQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_FCvDbnkw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FCvDbnkw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_q6UX4L76_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PGCgJkyl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lQdLjxaE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JiwngqTo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JiwngqTo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BmupXGZR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_lQdLjxaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fRaeeWfk, 1, m, &cIf_fRaeeWfk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tB8QG58s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eyRLdUVc, 1, m, &cIf_eyRLdUVc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BmupXGZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_fRaeeWfk, 0, m, &cIf_fRaeeWfk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_q6UX4L76_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eyRLdUVc, 0, m, &cIf_eyRLdUVc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_arcSFUSw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q3WQBCMs, HV_BINOP_SUBTRACT, 1, m, &cBinop_q3WQBCMs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uWiHZsbT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_3CwdBBuz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vSCVUS06, 0, m, &cVar_vSCVUS06_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zigSgN3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Jh39WsDN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_bztBasBx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_FzNh9wyP, 0, m, &cSlice_FzNh9wyP_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_FzNh9wyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_lSMaD8HL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_lSMaD8HL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_D7mlBY4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lSMaD8HL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_lSMaD8HL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1txFQGsz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5bL6vL3k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Jq7zY0aX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_vTisWL0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6xI3KZ7e, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_H846D9pl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5NFce6E5, 0, m, &cVar_5NFce6E5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_h5VS7bW6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rg70aCQ4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_qwze7OkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_iqovOSOW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_GviFBsdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Bp5uIgiI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_infYFkx9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4COV11Cx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Bp5uIgiI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4COV11Cx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_NHS2y8DX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_unMVTnPT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_unMVTnPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q8fWxIdf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Q8fWxIdf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5JoV6qyc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_NGMJuspW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Uq0dF1a6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_F1uObOX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qyLM60tL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_7xrHeX2C_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DIOUd3hM_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PzanD5kz_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uCuv9Fla_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QTGaa9pv_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i4iTsKDB_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VBLmdpmT_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_DIOUd3hM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qur8JWWE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_PzanD5kz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kEzuUMkc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_uCuv9Fla_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RPEInFda_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_QTGaa9pv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AKbjU4lX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_i4iTsKDB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PAE1s9EX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_VBLmdpmT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VAsY1j8M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_y2NvahtZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_i8gfN5Xl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_9tpdwyXt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MIMroGGk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_OunU0UsQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_xaf8PKAY_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_xaf8PKAY_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_q9eAbtrq, 1, m, &cDelay_q9eAbtrq_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4HmrBeRg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_q9eAbtrq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_q9eAbtrq, m);
  cIf_onMessage(_c, &Context(_c)->cIf_y2NvahtZ, 0, m, &cIf_y2NvahtZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xaf8PKAY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_q9eAbtrq, 0, m, &cDelay_q9eAbtrq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4HmrBeRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_q9eAbtrq, 0, m, &cDelay_q9eAbtrq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xIJ3atTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RSZVZVzi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wftf6ZP3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_E9PFRjec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8RAkFpcJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4gJmyeu5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4gJmyeu5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_OunU0UsQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_8RAkFpcJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_y2NvahtZ, 1, m, &cIf_y2NvahtZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Wftf6ZP3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9tpdwyXt, 0, m, &cIf_9tpdwyXt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RSZVZVzi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9tpdwyXt, 1, m, &cIf_9tpdwyXt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MIMroGGk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SDxmP6OQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_i8gfN5Xl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SDxmP6OQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_iVXau2MM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aAWOX9PO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_No05eEbO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_e0XXx4TI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_LdrEPSwU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_MuWUmd2R_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_MuWUmd2R_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_frSkqEvY, 1, m, &cDelay_frSkqEvY_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_J09dhPkR_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_frSkqEvY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_frSkqEvY, m);
  cIf_onMessage(_c, &Context(_c)->cIf_iVXau2MM, 0, m, &cIf_iVXau2MM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MuWUmd2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_frSkqEvY, 0, m, &cDelay_frSkqEvY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_J09dhPkR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_frSkqEvY, 0, m, &cDelay_frSkqEvY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ChforUDS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ukIGYpiR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LCfJe6Qt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9WCgSyzL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1z0bbvHh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZKwP5URq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1z0bbvHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iVXau2MM, 1, m, &cIf_iVXau2MM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZKwP5URq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_LdrEPSwU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_LCfJe6Qt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_No05eEbO, 0, m, &cIf_No05eEbO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ukIGYpiR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_No05eEbO, 1, m, &cIf_No05eEbO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_e0XXx4TI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_00Le1ti8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_aAWOX9PO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_00Le1ti8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_SmWSLipi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_s9M8iyxD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_7q7eFMOH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TLDTUk0y_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_aCySMZDG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_fqaSXqVh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_fqaSXqVh_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Sj01fPsE, 1, m, &cDelay_Sj01fPsE_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yonabn5i_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Sj01fPsE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Sj01fPsE, m);
  cIf_onMessage(_c, &Context(_c)->cIf_SmWSLipi, 0, m, &cIf_SmWSLipi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fqaSXqVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Sj01fPsE, 0, m, &cDelay_Sj01fPsE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yonabn5i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Sj01fPsE, 0, m, &cDelay_Sj01fPsE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_i7LC1iNp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ppglokBi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dhzHeQfs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bm1kQi6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KcJiUeh4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qpSl8HAB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KcJiUeh4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SmWSLipi, 1, m, &cIf_SmWSLipi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qpSl8HAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_aCySMZDG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_dhzHeQfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7q7eFMOH, 0, m, &cIf_7q7eFMOH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ppglokBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7q7eFMOH, 1, m, &cIf_7q7eFMOH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TLDTUk0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_u3olOA84, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_s9M8iyxD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_u3olOA84, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_gwXE9gQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_adazn5I0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_wEYirBpv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_CUiMnsNh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_0K7O9ydb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_uLIZfx1H_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_uLIZfx1H_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_WSGjX3yF, 1, m, &cDelay_WSGjX3yF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7uFmJeAw_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_WSGjX3yF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WSGjX3yF, m);
  cIf_onMessage(_c, &Context(_c)->cIf_gwXE9gQL, 0, m, &cIf_gwXE9gQL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uLIZfx1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_WSGjX3yF, 0, m, &cDelay_WSGjX3yF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7uFmJeAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WSGjX3yF, 0, m, &cDelay_WSGjX3yF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OyL9aynU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_frtm6Y3b_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z5dblaft_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lMndEirw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sSINttf7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Xc0XMElA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Xc0XMElA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0K7O9ydb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_sSINttf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gwXE9gQL, 1, m, &cIf_gwXE9gQL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_z5dblaft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wEYirBpv, 0, m, &cIf_wEYirBpv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_frtm6Y3b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wEYirBpv, 1, m, &cIf_wEYirBpv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CUiMnsNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bU5ybW5d, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_adazn5I0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bU5ybW5d, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_mQ8NyF0Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_CNStSmr1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_o382U2ti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Sno1Sp4S_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_tNJmWwEL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_COrT1PK8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_COrT1PK8_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_oNBomTWM, 1, m, &cDelay_oNBomTWM_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yBLvArpN_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_oNBomTWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oNBomTWM, m);
  cIf_onMessage(_c, &Context(_c)->cIf_mQ8NyF0Q, 0, m, &cIf_mQ8NyF0Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_COrT1PK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_oNBomTWM, 0, m, &cDelay_oNBomTWM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yBLvArpN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oNBomTWM, 0, m, &cDelay_oNBomTWM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nvJXaLFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fkzwPXnm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wTMDu2yk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8NE4oVwd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sBfEhm8i_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RZZnN1i7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RZZnN1i7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tNJmWwEL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_sBfEhm8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mQ8NyF0Q, 1, m, &cIf_mQ8NyF0Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wTMDu2yk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_o382U2ti, 0, m, &cIf_o382U2ti_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fkzwPXnm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_o382U2ti, 1, m, &cIf_o382U2ti_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Sno1Sp4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_k05MI0kE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_CNStSmr1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_k05MI0kE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_9KNGnSyU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4wk3wply_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_PxTkTccI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LfwkHDar_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_LrXxv2xZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_rJzHwKLy_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_rJzHwKLy_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wwzuJnNI, 1, m, &cDelay_wwzuJnNI_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jXMjT7tk_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_wwzuJnNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wwzuJnNI, m);
  cIf_onMessage(_c, &Context(_c)->cIf_9KNGnSyU, 0, m, &cIf_9KNGnSyU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rJzHwKLy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wwzuJnNI, 0, m, &cDelay_wwzuJnNI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jXMjT7tk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wwzuJnNI, 0, m, &cDelay_wwzuJnNI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qsKacyNM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2fddYeLI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TPe3pfzy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mFyUIjhe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x0zO0Iwy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ieOgkffO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_x0zO0Iwy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9KNGnSyU, 1, m, &cIf_9KNGnSyU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ieOgkffO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_LrXxv2xZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_TPe3pfzy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PxTkTccI, 0, m, &cIf_PxTkTccI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2fddYeLI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PxTkTccI, 1, m, &cIf_PxTkTccI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LfwkHDar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_s4XeWf9J, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4wk3wply_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_s4XeWf9J, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_jfVls1EK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Z5o0Wods_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_DqSaNpOV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WNmD4vHv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_r12gsgt2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_9vm1ON17_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_9vm1ON17_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_WVkyCjM1, 1, m, &cDelay_WVkyCjM1_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U2RPKjEv_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_WVkyCjM1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WVkyCjM1, m);
  cIf_onMessage(_c, &Context(_c)->cIf_jfVls1EK, 0, m, &cIf_jfVls1EK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9vm1ON17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_WVkyCjM1, 0, m, &cDelay_WVkyCjM1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_U2RPKjEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WVkyCjM1, 0, m, &cDelay_WVkyCjM1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5c884qbN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_W1KDVzHm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mrQInJbn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pHQ8nqEa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fhTbMRE7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_36AdZj2d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fhTbMRE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jfVls1EK, 1, m, &cIf_jfVls1EK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_36AdZj2d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_r12gsgt2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_W1KDVzHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DqSaNpOV, 1, m, &cIf_DqSaNpOV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mrQInJbn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DqSaNpOV, 0, m, &cIf_DqSaNpOV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WNmD4vHv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3f7SoeF2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Z5o0Wods_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3f7SoeF2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Ik2EUFoc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dVIdyqZc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_UgRGJXOd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5LAd3J9Z_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_EicZi7Xp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_5CCIuZud_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_5CCIuZud_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7KqFIZPt, 1, m, &cDelay_7KqFIZPt_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XG6uiRDE_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_7KqFIZPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7KqFIZPt, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Ik2EUFoc, 0, m, &cIf_Ik2EUFoc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5CCIuZud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7KqFIZPt, 0, m, &cDelay_7KqFIZPt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XG6uiRDE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7KqFIZPt, 0, m, &cDelay_7KqFIZPt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MCb4Kk6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0MwtDG38_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rEYV8Aas_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Aorgmy6h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0U9pv7Ms_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mrntExuD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0U9pv7Ms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ik2EUFoc, 1, m, &cIf_Ik2EUFoc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mrntExuD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_EicZi7Xp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_0MwtDG38_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UgRGJXOd, 1, m, &cIf_UgRGJXOd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rEYV8Aas_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UgRGJXOd, 0, m, &cIf_UgRGJXOd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5LAd3J9Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_b0oYX8rM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_dVIdyqZc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_b0oYX8rM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_t4dtMxQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OmIyFXIq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_R2yxEciV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_p7ddFNbi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Q9vNRhNB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_nKIxBIK0_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_nKIxBIK0_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_I9f2fzku, 1, m, &cDelay_I9f2fzku_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xaxsytcU_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_I9f2fzku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_I9f2fzku, m);
  cIf_onMessage(_c, &Context(_c)->cIf_t4dtMxQT, 0, m, &cIf_t4dtMxQT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nKIxBIK0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_I9f2fzku, 0, m, &cDelay_I9f2fzku_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xaxsytcU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_I9f2fzku, 0, m, &cDelay_I9f2fzku_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NZwzb4FM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8EJZXKeG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MgicVWJv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_C7JkUyRt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BMiBVTej_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rEIfD8hP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rEIfD8hP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Q9vNRhNB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_BMiBVTej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_t4dtMxQT, 1, m, &cIf_t4dtMxQT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8EJZXKeG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_R2yxEciV, 1, m, &cIf_R2yxEciV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MgicVWJv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_R2yxEciV, 0, m, &cIf_R2yxEciV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_p7ddFNbi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TQ0BTggM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_OmIyFXIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TQ0BTggM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_wRpurb9g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aUwPNG7m_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_jwB3MuHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wnQHLUwz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_NM5Fos04_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_7nE0UCPK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_7nE0UCPK_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_18peB7fy, 1, m, &cDelay_18peB7fy_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hHxI15hV_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_18peB7fy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_18peB7fy, m);
  cIf_onMessage(_c, &Context(_c)->cIf_wRpurb9g, 0, m, &cIf_wRpurb9g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7nE0UCPK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_18peB7fy, 0, m, &cDelay_18peB7fy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hHxI15hV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_18peB7fy, 0, m, &cDelay_18peB7fy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_y7VLf4mN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wWRLIxSB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_B7gtM6cb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yrX3FBFX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fGSrJRKL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X0Zb40Cm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_X0Zb40Cm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_NM5Fos04_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_fGSrJRKL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wRpurb9g, 1, m, &cIf_wRpurb9g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_B7gtM6cb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jwB3MuHX, 0, m, &cIf_jwB3MuHX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wWRLIxSB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jwB3MuHX, 1, m, &cIf_jwB3MuHX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wnQHLUwz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QnjqZWyq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_aUwPNG7m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QnjqZWyq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_EoVvuyCB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HNbamWO9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ACo2yRxk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1mYUaZI6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Wrk4qidj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_f1WD43fV_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_f1WD43fV_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_T3OfSqt5, 1, m, &cDelay_T3OfSqt5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vkgf3PGE_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_T3OfSqt5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_T3OfSqt5, m);
  cIf_onMessage(_c, &Context(_c)->cIf_EoVvuyCB, 0, m, &cIf_EoVvuyCB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_f1WD43fV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_T3OfSqt5, 0, m, &cDelay_T3OfSqt5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vkgf3PGE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_T3OfSqt5, 0, m, &cDelay_T3OfSqt5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_s4b2KV6U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_F0xbpUYW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5eKkRtc3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dc4PeA25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_od97QszV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uWnSfh52_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_od97QszV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EoVvuyCB, 1, m, &cIf_EoVvuyCB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uWnSfh52_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Wrk4qidj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_F0xbpUYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ACo2yRxk, 1, m, &cIf_ACo2yRxk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5eKkRtc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ACo2yRxk, 0, m, &cIf_ACo2yRxk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1mYUaZI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kOSS03Ry, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HNbamWO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kOSS03Ry, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_PSWU4JCd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QV3b8LOl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_NaIsAJRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yVJRvkr8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_SpeBk9Fn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_PnyHA0MJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_PnyHA0MJ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_METmT7OF, 1, m, &cDelay_METmT7OF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oRSRnOIq_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_METmT7OF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_METmT7OF, m);
  cIf_onMessage(_c, &Context(_c)->cIf_PSWU4JCd, 0, m, &cIf_PSWU4JCd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PnyHA0MJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_METmT7OF, 0, m, &cDelay_METmT7OF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oRSRnOIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_METmT7OF, 0, m, &cDelay_METmT7OF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Z3r8xQwc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7y6nM6Vm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qgChvgjK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IziKz1SF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uOHjMFpU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pB10Dcyr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uOHjMFpU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PSWU4JCd, 1, m, &cIf_PSWU4JCd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pB10Dcyr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_SpeBk9Fn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_7y6nM6Vm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NaIsAJRU, 1, m, &cIf_NaIsAJRU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qgChvgjK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NaIsAJRU, 0, m, &cIf_NaIsAJRU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yVJRvkr8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jLuLpq0c, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_QV3b8LOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jLuLpq0c, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qur8JWWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_Irri4Suy_sendMessage(_c, 0, m);
  cMsg_TjsAlFE6_sendMessage(_c, 0, m);
  cMsg_R7cKYIb1_sendMessage(_c, 0, m);
  cMsg_5iuIhvL9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kEzuUMkc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_Irri4Suy_sendMessage(_c, 0, m);
  cMsg_XtZpasSE_sendMessage(_c, 0, m);
  cMsg_0GfFIGLc_sendMessage(_c, 0, m);
  cMsg_1tSrWIyC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_RPEInFda_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_Y7cUWegh_sendMessage(_c, 0, m);
  cMsg_XtZpasSE_sendMessage(_c, 0, m);
  cMsg_5iuIhvL9_sendMessage(_c, 0, m);
  cMsg_ubQ0KFJQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_AKbjU4lX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_Y7cUWegh_sendMessage(_c, 0, m);
  cMsg_6jXVwKlf_sendMessage(_c, 0, m);
  cMsg_R7cKYIb1_sendMessage(_c, 0, m);
  cMsg_08qHmQ8f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PAE1s9EX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_r5u2C1hV_sendMessage(_c, 0, m);
  cMsg_1tSrWIyC_sendMessage(_c, 0, m);
  cMsg_ssWkhJUB_sendMessage(_c, 0, m);
  cMsg_R7cKYIb1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VAsY1j8M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_r5u2C1hV_sendMessage(_c, 0, m);
  cMsg_08qHmQ8f_sendMessage(_c, 0, m);
  cMsg_XtZpasSE_sendMessage(_c, 0, m);
  cMsg_s23ZTDes_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_hJwHU1Vk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_E9PFRjec_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xIJ3atTv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TEuo9IhZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_E9PFRjec_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xIJ3atTv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oKDWjGKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9WCgSyzL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ChforUDS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_T852omhh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9WCgSyzL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ChforUDS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kgNmGV1O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_bm1kQi6J_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_i7LC1iNp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rqU4Cv2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_bm1kQi6J_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_i7LC1iNp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Irri4Suy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_hJwHU1Vk_sendMessage(_c, 0, m);
  cMsg_T852omhh_sendMessage(_c, 0, m);
  cMsg_rqU4Cv2S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Y7cUWegh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_TEuo9IhZ_sendMessage(_c, 0, m);
  cMsg_oKDWjGKH_sendMessage(_c, 0, m);
  cMsg_rqU4Cv2S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_r5u2C1hV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_TEuo9IhZ_sendMessage(_c, 0, m);
  cMsg_T852omhh_sendMessage(_c, 0, m);
  cMsg_kgNmGV1O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_v3IytK9E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_lMndEirw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OyL9aynU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6Hz1HQky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_lMndEirw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OyL9aynU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZuEniOJb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_8NE4oVwd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nvJXaLFi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_h210yrEW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_8NE4oVwd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nvJXaLFi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iRzhVriK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mFyUIjhe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qsKacyNM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vnaSVS2I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mFyUIjhe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qsKacyNM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XtZpasSE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_6Hz1HQky_sendMessage(_c, 0, m);
  cMsg_h210yrEW_sendMessage(_c, 0, m);
  cMsg_vnaSVS2I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_TjsAlFE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_6Hz1HQky_sendMessage(_c, 0, m);
  cMsg_ZuEniOJb_sendMessage(_c, 0, m);
  cMsg_iRzhVriK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6jXVwKlf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_v3IytK9E_sendMessage(_c, 0, m);
  cMsg_h210yrEW_sendMessage(_c, 0, m);
  cMsg_iRzhVriK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_0GCsChGA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yrX3FBFX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_y7VLf4mN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0iOeVkRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yrX3FBFX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_y7VLf4mN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MyQ2qC6X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dc4PeA25_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_s4b2KV6U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MIXCKS38_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dc4PeA25_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_s4b2KV6U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WgZApBQa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_IziKz1SF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Z3r8xQwc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dEOmmNEa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_IziKz1SF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Z3r8xQwc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_08qHmQ8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_0GCsChGA_sendMessage(_c, 0, m);
  cMsg_MIXCKS38_sendMessage(_c, 0, m);
  cMsg_dEOmmNEa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1tSrWIyC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_0iOeVkRz_sendMessage(_c, 0, m);
  cMsg_MyQ2qC6X_sendMessage(_c, 0, m);
  cMsg_dEOmmNEa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5iuIhvL9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_0iOeVkRz_sendMessage(_c, 0, m);
  cMsg_MIXCKS38_sendMessage(_c, 0, m);
  cMsg_WgZApBQa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Myv3Xqgg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pHQ8nqEa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5c884qbN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GJze1U22_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pHQ8nqEa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5c884qbN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7yoaduYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Aorgmy6h_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MCb4Kk6J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_v9bE7lAj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Aorgmy6h_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MCb4Kk6J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_I5CTKwJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_C7JkUyRt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NZwzb4FM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kfzqAOKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_C7JkUyRt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NZwzb4FM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_R7cKYIb1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_GJze1U22_sendMessage(_c, 0, m);
  cMsg_v9bE7lAj_sendMessage(_c, 0, m);
  cMsg_kfzqAOKN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_0GfFIGLc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_GJze1U22_sendMessage(_c, 0, m);
  cMsg_7yoaduYL_sendMessage(_c, 0, m);
  cMsg_I5CTKwJH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_s23ZTDes_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_Myv3Xqgg_sendMessage(_c, 0, m);
  cMsg_7yoaduYL_sendMessage(_c, 0, m);
  cMsg_kfzqAOKN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ssWkhJUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_v3IytK9E_sendMessage(_c, 0, m);
  cMsg_ZuEniOJb_sendMessage(_c, 0, m);
  cMsg_vnaSVS2I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ubQ0KFJQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_Myv3Xqgg_sendMessage(_c, 0, m);
  cMsg_v9bE7lAj_sendMessage(_c, 0, m);
  cMsg_I5CTKwJH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_nn23TImq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TfbRyLdN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_eJiJcWbb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PQgvcMOy, 0, m, &cSlice_PQgvcMOy_sendMessage);
      break;
    }
    default: {
      cSwitchcase_W3IFl78n_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_PQgvcMOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_10a9mRJk_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_10a9mRJk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_tGEJlMjS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_10a9mRJk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_10a9mRJk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TZ0gvdYN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Cfx4mWu8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_nwsqT3ii, 0, m, &cSlice_nwsqT3ii_sendMessage);
      break;
    }
    default: {
      cSwitchcase_CPqgYyHo_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_nwsqT3ii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Xiy73AQj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Xiy73AQj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_h1FCjR5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Xiy73AQj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Xiy73AQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sRosxn5n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_CPqgYyHo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PqXHPy0m, 0, m, &cSlice_PqXHPy0m_sendMessage);
      break;
    }
    default: {
      cSwitchcase_eJiJcWbb_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_PqXHPy0m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_pyMY1dJu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_pyMY1dJu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_UwEseuhe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pyMY1dJu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_pyMY1dJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bcRmYSrI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_W3IFl78n_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_tq7sX6I1, 0, m, &cSlice_tq7sX6I1_sendMessage);
      break;
    }
    default: {
      cSwitchcase_lxDg1mSX_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_tq7sX6I1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_52NM9zRT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_52NM9zRT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_PxjGTUWL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_52NM9zRT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_52NM9zRT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CrstBReX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_lxDg1mSX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_scTq4fKW, 0, m, &cSlice_scTq4fKW_sendMessage);
      break;
    }
    default: {
      cSwitchcase_fqseyX4b_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_scTq4fKW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_gLALrQxH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_gLALrQxH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_9bTWvr0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gLALrQxH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_gLALrQxH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WpO7MRbC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Olg1BXnr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_4yD1VCJs_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_4yD1VCJs_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Ryp61Ovu, 1, m, &cDelay_Ryp61Ovu_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LEBHDsik_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Ryp61Ovu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Ryp61Ovu, m);
  cMsg_M6zS1tCI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4yD1VCJs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ryp61Ovu, 0, m, &cDelay_Ryp61Ovu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LEBHDsik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ryp61Ovu, 0, m, &cDelay_Ryp61Ovu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_8sxcQIZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9tV9FsoE, HV_BINOP_SUBTRACT, 0, m, &cBinop_9tV9FsoE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_n9FG4I6f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TVMqROvn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_GladYGQm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TVMqROvn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_eTwj183W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8sxcQIZQ, 0, m, &cVar_8sxcQIZQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_QADo3dvR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hO8VbLU3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JTzvDiuH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fzvvYBWs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9tV9FsoE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6RojRmJg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6RojRmJg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ouhxzS9b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ouhxzS9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_8zfLSthx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_j3BY9K7a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sM6guFQT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wxv7rqal_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Wxv7rqal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NFxzSyTf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_sM6guFQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n9FG4I6f, 1, m, &cIf_n9FG4I6f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kGhZVOVF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GladYGQm, 1, m, &cIf_GladYGQm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NFxzSyTf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_n9FG4I6f, 0, m, &cIf_n9FG4I6f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8zfLSthx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GladYGQm, 0, m, &cIf_GladYGQm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JTzvDiuH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9tV9FsoE, HV_BINOP_SUBTRACT, 1, m, &cBinop_9tV9FsoE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hO8VbLU3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_fzvvYBWs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8sxcQIZQ, 0, m, &cVar_8sxcQIZQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TVMqROvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cKRaaX4s, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fqseyX4b_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1sohhQYG, 0, m, &cSlice_1sohhQYG_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_1sohhQYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_dTXrZgC5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_dTXrZgC5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_LUsX6vvk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dTXrZgC5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_dTXrZgC5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_g6OG94uD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Uq0dF1a6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6uApRBZ9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qyLM60tL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YqdGmMqn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_HWbhZlq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_F1uObOX4, 0, m, &cVar_F1uObOX4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TfbRyLdN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cILf1MKD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_MGAz0Bxr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Olg1BXnr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_pW7Lj5J6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wV3aAuFz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_M6zS1tCI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9hihgmkH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_wV3aAuFz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9hihgmkH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_n1daqDu7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_3uuZSFVP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3uuZSFVP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5t2MIbbb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5t2MIbbb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Avrt8f19, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_p1IzKpDN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mlQ5IAqI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_4dIxWo09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KB419fxV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_F2jub07f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mVE1JVpV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_axngQP3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_t29WPkeB_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Y2Up8rvZ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Zb1Xzwon_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_kkNBwRjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_t29WPkeB_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Y2Up8rvZ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Zb1Xzwon_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_hnkhV7dx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_n0ak0z9R, 0, m, &cVar_n0ak0z9R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ek1f3pew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_t29WPkeB_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Y2Up8rvZ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Zb1Xzwon_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Ppy2vkvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_t29WPkeB_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Y2Up8rvZ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Zb1Xzwon_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_rKZGOZIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_t29WPkeB_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Y2Up8rvZ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Zb1Xzwon_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_msPD10S0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_TD2GC48h, 0, m, &cVar_TD2GC48h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lreVn81k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_Y3zEhTQN, 0, m, &cVar_Y3zEhTQN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tapR9NCA, 0, m, &cVar_tapR9NCA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OOav8DVl, 0, m, &cVar_OOav8DVl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uXHEUkbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_hnkhV7dx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bien8tI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_ePyxTWTH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_186j02Fr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HMcZMhxS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_ePyxTWTH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_186j02Fr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_6cS0IWAu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_ePyxTWTH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_186j02Fr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_eBLLjJ1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_ePyxTWTH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_186j02Fr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Aevld0Fq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_ePyxTWTH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_186j02Fr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_u0Hq7vYg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_cSacIwHE, 0, m, &cVar_cSacIwHE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Wx9Rtc3y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_rpqtljlv, 0, m, &cVar_rpqtljlv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GYD81vSg, 0, m, &cVar_GYD81vSg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5kaiuu8J, 0, m, &cVar_5kaiuu8J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_R6MNyP7h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_t29WPkeB_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Y2Up8rvZ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Zb1Xzwon_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0tyrI7W1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KPicc8nH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_FsffiyJT_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qTR0tZ48_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FNwC1kam_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KPicc8nH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_FsffiyJT_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qTR0tZ48_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_m1by7wTn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wqjDDt7J, 0, m, &cVar_wqjDDt7J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wwoTASs6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KPicc8nH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_FsffiyJT_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qTR0tZ48_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qLNl0qfB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KPicc8nH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_FsffiyJT_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qTR0tZ48_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_PHkuUUD3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KPicc8nH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_FsffiyJT_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qTR0tZ48_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_gGJHz1vL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_9toWFASb, 0, m, &cVar_9toWFASb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VYXUP5uX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_hb37dN8I, 0, m, &cVar_hb37dN8I_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_26fwkrrn, 0, m, &cVar_26fwkrrn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cxvdBAaq, 0, m, &cVar_cxvdBAaq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kaxdypRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_m1by7wTn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oPEZnTZ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KPicc8nH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_FsffiyJT_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qTR0tZ48_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_BTOdCF3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_odPXO5xX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_akOeeURA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Cfx4mWu8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Vhy9uXVl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_odPXO5xX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_akOeeURA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Cfx4mWu8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_9NqxUCyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KAyw8LI3, 0, m, &cVar_KAyw8LI3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8xJyRWJI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_odPXO5xX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_akOeeURA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Cfx4mWu8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4Xqh5RZ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_odPXO5xX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_akOeeURA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Cfx4mWu8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yzQPEbXG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_odPXO5xX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_akOeeURA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Cfx4mWu8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HXcUbmJA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_oQKRtR1c, 0, m, &cVar_oQKRtR1c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0m8JEIur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_np0c0xQX, 0, m, &cVar_np0c0xQX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lYcpsNve, 0, m, &cVar_lYcpsNve_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vqRoXdF3, 0, m, &cVar_vqRoXdF3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FpVNiMpB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_9NqxUCyn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Gfnsg9g8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_odPXO5xX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_akOeeURA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Cfx4mWu8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_EjVHrUdy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_p1IzKpDN, 0, m, &cVar_p1IzKpDN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mlQ5IAqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_t29WPkeB_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Y2Up8rvZ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Zb1Xzwon_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zXux4eVp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_4dIxWo09, 0, m, &cVar_4dIxWo09_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KB419fxV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KPicc8nH_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_FsffiyJT_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qTR0tZ48_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_q0YO08FH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_F2jub07f, 0, m, &cVar_F2jub07f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mVE1JVpV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_odPXO5xX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_akOeeURA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Cfx4mWu8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cReceive_xhrxL7jx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Zzw7iewQ_sendMessage(_c, 0, m);
  cMsg_Cr1Fbptd_sendMessage(_c, 0, m);
  cMsg_qs8HKoWo_sendMessage(_c, 0, m);
  cMsg_UEYMecw2_sendMessage(_c, 0, m);
  cMsg_BtKHpq92_sendMessage(_c, 0, m);
  cMsg_cKvcZXPY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_aoWBsKC4, 0, m, &cVar_aoWBsKC4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7j6EFgvQ, 0, m, &cVar_7j6EFgvQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cf0irE00, 0, m, &cVar_cf0irE00_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2eYvfeT1, 0, m, &cVar_2eYvfeT1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vViOuSws, 0, m, &cVar_vViOuSws_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IFkzGaee, 0, m, &cVar_IFkzGaee_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CbuIeV5P, 0, m, &cVar_CbuIeV5P_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uiep2mdK, 0, m, &cVar_uiep2mdK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RFsjrol7, 0, m, &cVar_RFsjrol7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KWbrqTsv, 0, m, &cVar_KWbrqTsv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OGnTEunt, 0, m, &cVar_OGnTEunt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nBjOB8a2, 0, m, &cVar_nBjOB8a2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3tdKC5o6, 0, m, &cVar_3tdKC5o6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cNaiL7V1, 0, m, &cVar_cNaiL7V1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_olQPGbyn, 0, m, &cVar_olQPGbyn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fGCSvT8A, 0, m, &cVar_fGCSvT8A_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fPQRrE0s, 0, m, &cVar_fPQRrE0s_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZJeQA4mh, 0, m, &cVar_ZJeQA4mh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9aMUZ4LS, 0, m, &cVar_9aMUZ4LS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xyjqi6fw, 0, m, &cVar_xyjqi6fw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MXLzkZzs, 0, m, &cVar_MXLzkZzs_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SDVg9zrD, 0, m, &cVar_SDVg9zrD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JDkpE6oY, 0, m, &cVar_JDkpE6oY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IRcBMK7t, 0, m, &cVar_IRcBMK7t_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nK0U0mbg, 0, m, &cVar_nK0U0mbg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Kp1w2zBA, 0, m, &cVar_Kp1w2zBA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fMZiRdWS, 0, m, &cVar_fMZiRdWS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gPTj32a2, 0, m, &cVar_gPTj32a2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_N6nVAae4, 0, m, &cVar_N6nVAae4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2us1DNKp, 0, m, &cVar_2us1DNKp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jQKDssvQ, 0, m, &cVar_jQKDssvQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JBbVVxFv, 0, m, &cVar_JBbVVxFv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7Hm77VZB, 0, m, &cVar_7Hm77VZB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gZYRfL5T, 0, m, &cVar_gZYRfL5T_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9VWgHGMD, 0, m, &cVar_9VWgHGMD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qhcjrmBy, 0, m, &cVar_qhcjrmBy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YZUWV0hv, 0, m, &cVar_YZUWV0hv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XeQ9T5Wg, 0, m, &cVar_XeQ9T5Wg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hqDqKmQm, 0, m, &cVar_hqDqKmQm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YvGhDbvH, 0, m, &cVar_YvGhDbvH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Qj11yOFv, 0, m, &cVar_Qj11yOFv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jZY58dxA, 0, m, &cVar_jZY58dxA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_L4J08TWe, 0, m, &cVar_L4J08TWe_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jK8qyWDU, 0, m, &cVar_jK8qyWDU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_o2Du3tv6, 0, m, &cVar_o2Du3tv6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wJODObdJ, 0, m, &cVar_wJODObdJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6iPb83CS, 0, m, &cVar_6iPb83CS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AiwS0bSa, 0, m, &cVar_AiwS0bSa_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ifi40YJu, 0, m, &cVar_Ifi40YJu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YKjOtGOQ, 0, m, &cVar_YKjOtGOQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hf2w8GAX, 0, m, &cVar_hf2w8GAX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_D7mlBY4n, 0, m, &cVar_D7mlBY4n_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tGEJlMjS, 0, m, &cVar_tGEJlMjS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_h1FCjR5T, 0, m, &cVar_h1FCjR5T_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UwEseuhe, 0, m, &cVar_UwEseuhe_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PxjGTUWL, 0, m, &cVar_PxjGTUWL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9bTWvr0K, 0, m, &cVar_9bTWvr0K_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LUsX6vvk, 0, m, &cVar_LUsX6vvk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0x7J47mD, 0, m, &cVar_0x7J47mD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lFqd7G7a, 0, m, &cVar_lFqd7G7a_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jUi3BycM, 0, m, &cVar_jUi3BycM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X8iHme26_sendMessage);
  cMsg_Wx9Rtc3y_sendMessage(_c, 0, m);
  cMsg_u0Hq7vYg_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n5SwLQIz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VOOru5xs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_5847RBWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rpqtljlv, 0, m, &cVar_rpqtljlv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_GKJBFzNX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GYD81vSg, 0, m, &cVar_GYD81vSg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_UfsuGQCW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5kaiuu8J, 0, m, &cVar_5kaiuu8J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_lawmpvUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7j6EFgvQ, 0, m, &cVar_7j6EFgvQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_UwLIShtH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dAJQuYbj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uRTZ7HvP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_TSibBAEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MASlewrO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a50D5rhE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tvztPqZ1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Rex6lipK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_QlgPs0Pn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dv6w5WUp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_S1txKMzg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TseyEptK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ik8IFCfk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_yCLL88G0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_o2o3FR9c_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qBvcTdUH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FLF1MO9f_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pSDXz4dP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_2HxPtPC7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KdyltgR0, HV_BINOP_MULTIPLY, 0, m, &cBinop_KdyltgR0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_PYXVUWc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_sRHJXbL6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_fiGlxxr7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_mgzbWJJs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_5nwnxuCr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_T8AOSnTh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ewKYvSkB_sendMessage);
  cMsg_33OPi7DH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_75R5CVgs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5VuBizdq, HV_BINOP_MULTIPLY, 0, m, &cBinop_5VuBizdq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_I8Jbvq9G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_g0JdSOcE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_rJVRUZJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eEnNoL6u, HV_BINOP_MULTIPLY, 1, m, &cBinop_eEnNoL6u_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_cUQ6p99y_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_0iHzikMg_sendMessage);
  cMsg_rGPdlWlS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_553Iso7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ECHVyQqx, HV_BINOP_MULTIPLY, 0, m, &cBinop_ECHVyQqx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_14W1NNmd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7Ruakr6b_sendMessage(_c, 0, m);
  cMsg_ifWY9jHa_sendMessage(_c, 0, m);
  cMsg_9T0fgkk2_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_vMXk0Ueo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_rcaGEspo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_T6Eu7pQJ_sendMessage);
  cMsg_jYOlMOWN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_fafaDxZn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vViOuSws, 0, m, &cVar_vViOuSws_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_1dSNCbAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TafYfLDm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j6vJHS8B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_9w9DgtJK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RtgPadxW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5wbfdt5H_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_p9ql59ku_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d0bQcL2i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_hgK6cwIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Vy7Yk4f8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TK2p5fmd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3xrLN2po_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qpkHFIzg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ZUdG1JSt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u65geins_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jm80aMk8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HZgdvX4y_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uhYKSJiN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_vCySTAWn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qfl4goeV, HV_BINOP_MULTIPLY, 0, m, &cBinop_Qfl4goeV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_5pl9RoFh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_uxIDl6gS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_EGB39VHz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_VynF1Ooz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_ZZmK87fo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_HOVjzIAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_K63XJRJH_sendMessage);
  cMsg_NN6SIK3m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_8R13FmlE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b8WCUmAD, HV_BINOP_MULTIPLY, 0, m, &cBinop_b8WCUmAD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_fTJ8jQhJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_U8EG0f4b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_7CUWnQnI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JflyvtUp, HV_BINOP_MULTIPLY, 1, m, &cBinop_JflyvtUp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_dL7ABZsS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_5SRwg7wl_sendMessage);
  cMsg_dZJPCc4h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_xZ9FaN6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7ALrXqSG, HV_BINOP_MULTIPLY, 0, m, &cBinop_7ALrXqSG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_cnKnw0gR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zO1QrZTI_sendMessage(_c, 0, m);
  cMsg_wxk2zNFj_sendMessage(_c, 0, m);
  cMsg_UpOMlOlc_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_J7jvZiAV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ul7mgnHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_W9AC9kNa_sendMessage);
  cMsg_huTxSDsK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_inFmYPzF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cSacIwHE, 0, m, &cVar_cSacIwHE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_msPtdApp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1rtcpRBW, 0, m, &cVar_1rtcpRBW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_QQusSzLe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TD2GC48h, 0, m, &cVar_TD2GC48h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_96rjqZ93_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Y3zEhTQN, 0, m, &cVar_Y3zEhTQN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_sRAeSG3v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tapR9NCA, 0, m, &cVar_tapR9NCA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_NQ2Akip6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OOav8DVl, 0, m, &cVar_OOav8DVl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_bucS69DY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_hnkhV7dx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_sDMRjJdm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_iWIkr1kZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_fII2LWuP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IBcdgxWQ, 0, m, &cVar_IBcdgxWQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_iOylIHin_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_25Sz3RI5, 0, m, &cVar_25Sz3RI5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_zY3h3ABA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_NToPBbeu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_CK9IXeBC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_jczo023Q_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bmtsu8If_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VizWKMtd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_QB1zvJpk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fMGvGAMY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3H62RqEF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_YX0SDn3T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_U5lqehuQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_OWNASTZ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DEFMfnuu, 0, m, &cVar_DEFMfnuu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_JAHT2qDU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7QzWHacc, 0, m, &cVar_7QzWHacc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_if0Uz0pL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_5nKml6kW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_eJq5xGfp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_1UKLv2Mj_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7HdVdeNl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DOVhqnNW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_HZxBjXjZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NEwb12M5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QAxjuBfJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_3ANAxUma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6rDepEPI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_aIQqFWDI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_xQAq4GB7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ObEk1ixs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jU53TK8N, 0, m, &cVar_jU53TK8N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_sN5VzAK0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_f7NPBKnN, 0, m, &cVar_f7NPBKnN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_PR82eDCm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_FR2fQ6dz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_uC1OmnhV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3hZODIBW_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uQ5Eq88U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cfSb4A0b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_nZUl1MxT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sZq5HPPd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ksI84ipw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_MI2TqDNN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fkSYBsH4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_9jom1PUg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_th0exKwl, 0, m, &cVar_th0exKwl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_dl3aLlne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TU32IZjr, 0, m, &cVar_TU32IZjr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_dRx3HTzB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_R5db3yHU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_JzQj7yWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_dZjZuMsz_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_B97YQO42_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5KaJNu9n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_OcsAmQRr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GhzKuOoK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xzS0O702_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_9enWemSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uYZ2ErTv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_5GtL5g4p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dfiMQfTV, 0, m, &cVar_dfiMQfTV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Jdnj97h5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9toWFASb, 0, m, &cVar_9toWFASb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_JlelTBC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hb37dN8I, 0, m, &cVar_hb37dN8I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_yi0hhW6r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_26fwkrrn, 0, m, &cVar_26fwkrrn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_88IudA8X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cxvdBAaq, 0, m, &cVar_cxvdBAaq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_70DWelDu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_m1by7wTn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_pQNOJMat_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_vsnWIXsy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_aG8VYCE0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EnFXUabm, 0, m, &cVar_EnFXUabm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_yi5F4Zzf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9xYvZgsu, 0, m, &cVar_9xYvZgsu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_afLXrcJ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_H846D9pl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_CUIvw89q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_j17i3mTU_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GviFBsdF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qwze7OkD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_WVZeA7tg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PGCgJkyl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tB8QG58s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_1txFQGsz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NHS2y8DX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_TZ0gvdYN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NGMJuspW, 0, m, &cVar_NGMJuspW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_CrstBReX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nn23TImq, 0, m, &cVar_nn23TImq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_bcRmYSrI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_HWbhZlq5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_sRosxn5n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_7xrHeX2C_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pW7Lj5J6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MGAz0Bxr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_WpO7MRbC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_j3BY9K7a_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kGhZVOVF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_g6OG94uD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n1daqDu7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_TP8W4Qdk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EE0A2WvJ, 0, m, &cVar_EE0A2WvJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_scxxDwgb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oQKRtR1c, 0, m, &cVar_oQKRtR1c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_K09SX2AQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_np0c0xQX, 0, m, &cVar_np0c0xQX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_vJowEYXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lYcpsNve, 0, m, &cVar_lYcpsNve_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_QyGGfnjG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vqRoXdF3, 0, m, &cVar_vqRoXdF3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_aYE3Vb39_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_9NqxUCyn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_9knGDMcO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_p1IzKpDN, 0, m, &cVar_p1IzKpDN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_fPm9mOV9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4dIxWo09, 0, m, &cVar_4dIxWo09_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_6Xh3ae9P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_F2jub07f, 0, m, &cVar_F2jub07f_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_M3NGLR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14, Bf15, Bf16, Bf17, Bf18, Bf19, Bf20;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_xzE6dU5K, VOf(Bf0));
    __hv_line_f(&sLine_QNmgPlwp, VOf(Bf1));
    __hv_line_f(&sLine_wM5aKWYy, VOf(Bf2));
    __hv_line_f(&sLine_dkMLcHqE, VOf(Bf3));
    __hv_line_f(&sLine_EkIBwZmn, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_fxMBqzVz, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_mawsVzU3, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_NVxjQnl8, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_SDGkcoaF, VOf(Bf1));
    __hv_line_f(&sLine_ALKocCTi, VOf(Bf0));
    __hv_line_f(&sLine_XPo78D2W, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_V7PZlozW, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_OwL1sSW8, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_yexUL0vG, VOf(Bf5));
    __hv_line_f(&sLine_FVCZeWQg, VOf(Bf1));
    __hv_line_f(&sLine_tLlV6mpz, VOf(Bf2));
    __hv_line_f(&sLine_TBAKZDFl, VOf(Bf4));
    __hv_line_f(&sLine_eXBMm8go, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_rs9E4TT7, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_wa75jf5a, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_UxYunt9Z, VOf(Bf6));
    __hv_line_f(&sLine_WxGO5sky, VOf(Bf2));
    __hv_line_f(&sLine_2cyd2HI4, VOf(Bf1));
    __hv_line_f(&sLine_NGkbo151, VOf(Bf5));
    __hv_line_f(&sLine_KmrYJsfz, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_9j8aNkGk, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_SToXVaC3, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_q0M14IhK, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_Ep96rZYL, VOf(Bf2));
    __hv_line_f(&sLine_slHWrL6L, VOf(Bf6));
    __hv_line_f(&sLine_8m9lBJHp, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_wjVxPtDR, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_NVP5gANv, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_FA8cnVyE, VOf(Bf8));
    __hv_line_f(&sLine_KdNFiuFT, VOf(Bf2));
    __hv_line_f(&sLine_jwfWwdB7, VOf(Bf1));
    __hv_line_f(&sLine_luAPr5kk, VOf(Bf7));
    __hv_line_f(&sLine_EIWIIEoV, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_SxDnELtD, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_ytDMHiuZ, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_ROk7WGZC, VIf(Bf0));
    __hv_varwrite_f(&sVarf_1dvUqAI2, VIf(Bf6));
    __hv_varwrite_f(&sVarf_VYUhJHSW, VIf(Bf4));
    __hv_varwrite_f(&sVarf_eOe5XbOk, VIf(Bf7));
    __hv_varread_f(&sVarf_WRJwFO7C, VOf(Bf7));
    __hv_varread_f(&sVarf_fexw9QZ3, VOf(Bf4));
    __hv_varread_f(&sVarf_jSB595L7, VOf(Bf6));
    __hv_varread_f(&sVarf_eF0IUtLc, VOf(Bf0));
    __hv_varread_f(&sVarf_EJVJGCRJ, VOf(Bf9));
    __hv_varread_f(&sVarf_dKmh1QMQ, VOf(Bf1));
    __hv_line_f(&sLine_KCVjVWAO, VOf(Bf2));
    __hv_line_f(&sLine_RFeTYkdi, VOf(Bf8));
    __hv_mul_f(VIf(Bf0), VIf(Bf8), VOf(Bf0));
    __hv_fma_f(VIf(Bf6), VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varwrite_f(&sVarf_jSB595L7, VIf(Bf7));
    __hv_varwrite_f(&sVarf_EJVJGCRJ, VIf(Bf4));
    __hv_varread_f(&sVarf_9KKacHes, VOf(Bf2));
    __hv_varread_f(&sVarf_ofaqyxcc, VOf(Bf9));
    __hv_varread_f(&sVarf_mIa4NwQH, VOf(Bf1));
    __hv_varread_f(&sVarf_7VIpL6fX, VOf(Bf6));
    __hv_varread_f(&sVarf_atHXUUe1, VOf(Bf10));
    __hv_varread_f(&sVarf_SjFUDRSj, VOf(Bf11));
    __hv_varread_f(&sVarf_PHlImIjo, VOf(Bf12));
    __hv_varwrite_f(&sVarf_slvEwhv4, VIf(Bf7));
    __hv_varread_f(&sVarf_G7gf7Wyu, VOf(Bf13));
    __hv_line_f(&sLine_8a6MMoqJ, VOf(Bf14));
    __hv_mul_f(VIf(Bf13), VIf(Bf14), VOf(Bf14));
    __hv_varread_f(&sVarf_01j254MX, VOf(Bf15));
    __hv_line_f(&sLine_RIykccS3, VOf(Bf16));
    __hv_mul_f(VIf(Bf15), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_hzcpSn2d, VOf(Bf14));
    __hv_line_f(&sLine_7aXjVofq, VOf(Bf17));
    __hv_mul_f(VIf(Bf14), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_varwrite_f(&sVarf_7VIpL6fX, VIf(Bf17));
    __hv_varread_f(&sVarf_slvEwhv4, VOf(Bf17));
    __hv_line_f(&sLine_Y8nZLxwb, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_HQ6Xu0B9, VOf(Bf18));
    __hv_mul_f(VIf(Bf14), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_clx4w716, VOf(Bf16));
    __hv_mul_f(VIf(Bf15), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_atHXUUe1, VIf(Bf16));
    __hv_line_f(&sLine_1cgHQtsR, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_NsFpXWm1, VOf(Bf18));
    __hv_mul_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_IADvtpRx, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_SjFUDRSj, VIf(Bf16));
    __hv_line_f(&sLine_n294RCd6, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_gJc8PNeP, VOf(Bf17));
    __hv_mul_f(VIf(Bf15), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_line_f(&sLine_EFn9NHaU, VOf(Bf16));
    __hv_mul_f(VIf(Bf13), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_PHlImIjo, VIf(Bf16));
    __hv_varwrite_f(&sVarf_G7gf7Wyu, VIf(Bf2));
    __hv_varwrite_f(&sVarf_01j254MX, VIf(Bf9));
    __hv_varwrite_f(&sVarf_hzcpSn2d, VIf(Bf1));
    sEnv_process(this, &sEnv_0vLXw4DE, VIf(Bf6), &sEnv_0vLXw4DE_sendMessage);
    sEnv_process(this, &sEnv_X6VhQUUt, VIf(Bf7), &sEnv_X6VhQUUt_sendMessage);
    __hv_line_f(&sLine_LJyZoAzY, VOf(Bf7));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf7), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf7), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf7), VOf(Bf7));
    __hv_exp_f(VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_wCiqSjlu, VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_Ze0mF9sT, VOf(Bf7));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf7), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf7), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf7), VOf(Bf7));
    __hv_exp_f(VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_1CQ7aROH, VOf(Bf6));
    __hv_line_f(&sLine_8dzZnWs7, VOf(Bf1));
    __hv_var_k_f(VOf(Bf9), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf6));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_9KKacHes, VIf(Bf9));
    __hv_varwrite_f(&sVarf_1CQ7aROH, VIf(Bf10));
    __hv_varwrite_f(&sVarf_yDlutCQ4, VIf(Bf11));
    __hv_varwrite_f(&sVarf_EP5RRXSZ, VIf(Bf12));
    __hv_varread_f(&sVarf_EP5RRXSZ, VOf(Bf12));
    __hv_line_f(&sLine_TcKZZxAD, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf11), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf11), VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf9));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf12), VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_div_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_mIa4NwQH, VIf(Bf10));
    __hv_varread_f(&sVarf_yDlutCQ4, VOf(Bf10));
    __hv_line_f(&sLine_GuuVTCeA, VOf(Bf11));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_floor_f(VIf(Bf11), VOf(Bf9));
    __hv_sub_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf9), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_neg_f(VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_ofaqyxcc, VIf(Bf10));
    __hv_varwrite_f(&sVarf_eF0IUtLc, VIf(Bf7));
    __hv_varread_f(&sVarf_EmVzxbGG, VOf(Bf7));
    __hv_varread_f(&sVarf_4EJIT8hm, VOf(Bf10));
    __hv_varread_f(&sVarf_cikgi5eF, VOf(Bf9));
    __hv_varread_f(&sVarf_kkAFQqqv, VOf(Bf11));
    __hv_varread_f(&sVarf_e3TMYEtE, VOf(Bf6));
    __hv_varread_f(&sVarf_uvmL77g5, VOf(Bf12));
    __hv_varread_f(&sVarf_4oQd7mB3, VOf(Bf1));
    __hv_varwrite_f(&sVarf_jXoGPIG6, VIf(Bf4));
    __hv_varread_f(&sVarf_DORhvzVY, VOf(Bf2));
    __hv_line_f(&sLine_ebeZcP8o, VOf(Bf16));
    __hv_mul_f(VIf(Bf2), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_f8keSKbS, VOf(Bf17));
    __hv_line_f(&sLine_tI4Q5Y6d, VOf(Bf13));
    __hv_mul_f(VIf(Bf17), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf16), VIf(Bf13), VOf(Bf13));
    __hv_varread_f(&sVarf_ttFZguO7, VOf(Bf16));
    __hv_line_f(&sLine_3sJV3a89, VOf(Bf15));
    __hv_mul_f(VIf(Bf16), VIf(Bf15), VOf(Bf15));
    __hv_add_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_varwrite_f(&sVarf_kkAFQqqv, VIf(Bf15));
    __hv_varread_f(&sVarf_jXoGPIG6, VOf(Bf15));
    __hv_line_f(&sLine_iYkY0hHB, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_wg2wgXps, VOf(Bf18));
    __hv_mul_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_rJYNLifm, VOf(Bf13));
    __hv_mul_f(VIf(Bf17), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_e3TMYEtE, VIf(Bf13));
    __hv_line_f(&sLine_R9Dmo8Lf, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_S3kLqp0Y, VOf(Bf18));
    __hv_mul_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_APcNkI4j, VOf(Bf13));
    __hv_mul_f(VIf(Bf16), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_uvmL77g5, VIf(Bf13));
    __hv_line_f(&sLine_91mblq9h, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_nMqFbXeQ, VOf(Bf15));
    __hv_mul_f(VIf(Bf17), VIf(Bf15), VOf(Bf15));
    __hv_add_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_line_f(&sLine_IdA1qZPZ, VOf(Bf13));
    __hv_mul_f(VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_4oQd7mB3, VIf(Bf13));
    __hv_varwrite_f(&sVarf_DORhvzVY, VIf(Bf7));
    __hv_varwrite_f(&sVarf_f8keSKbS, VIf(Bf10));
    __hv_varwrite_f(&sVarf_ttFZguO7, VIf(Bf9));
    sEnv_process(this, &sEnv_lXJoZoFl, VIf(Bf11), &sEnv_lXJoZoFl_sendMessage);
    sEnv_process(this, &sEnv_bvphXsZx, VIf(Bf4), &sEnv_bvphXsZx_sendMessage);
    __hv_line_f(&sLine_t3bi42mH, VOf(Bf4));
    __hv_var_k_f(VOf(Bf9), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf9), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf11), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_JYfbQUby, VOf(Bf11));
    __hv_mul_f(VIf(Bf4), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_l4FU55Kl, VOf(Bf4));
    __hv_var_k_f(VOf(Bf9), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf9), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf11), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_mTdxbi2K, VOf(Bf11));
    __hv_line_f(&sLine_LVqPhta4, VOf(Bf9));
    __hv_var_k_f(VOf(Bf10), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_floor_f(VIf(Bf9), VOf(Bf11));
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_div_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_EmVzxbGG, VIf(Bf10));
    __hv_varwrite_f(&sVarf_mTdxbi2K, VIf(Bf6));
    __hv_varwrite_f(&sVarf_LDV3oreP, VIf(Bf12));
    __hv_varwrite_f(&sVarf_VdogrI20, VIf(Bf1));
    __hv_varread_f(&sVarf_VdogrI20, VOf(Bf1));
    __hv_line_f(&sLine_Arn3lTzT, VOf(Bf12));
    __hv_mul_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf1), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf12), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf12), VOf(Bf1));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf6), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf1), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf12), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_cikgi5eF, VIf(Bf6));
    __hv_varread_f(&sVarf_LDV3oreP, VOf(Bf6));
    __hv_line_f(&sLine_SClschGm, VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf12), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_floor_f(VIf(Bf12), VOf(Bf10));
    __hv_sub_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf12), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_abs_f(VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf12), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_4EJIT8hm, VIf(Bf6));
    __hv_varwrite_f(&sVarf_dKmh1QMQ, VIf(Bf4));
    __hv_varwrite_f(&sVarf_G0Ud2ayX, VIf(Bf0));
    __hv_varread_f(&sVarf_ROk7WGZC, VOf(Bf0));
    __hv_varread_f(&sVarf_1dvUqAI2, VOf(Bf4));
    __hv_varread_f(&sVarf_OdTrvi1h, VOf(Bf6));
    __hv_varread_f(&sVarf_J5PLq9hm, VOf(Bf10));
    __hv_varread_f(&sVarf_OJIWjBm0, VOf(Bf12));
    __hv_varread_f(&sVarf_mbjq7YNJ, VOf(Bf11));
    __hv_line_f(&sLine_elVf9Vnz, VOf(Bf1));
    __hv_line_f(&sLine_Ewj5byRN, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf10));
    __hv_fma_f(VIf(Bf6), VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_OdTrvi1h, VIf(Bf0));
    __hv_varwrite_f(&sVarf_OJIWjBm0, VIf(Bf4));
    __hv_varread_f(&sVarf_aN4Ff5uW, VOf(Bf1));
    __hv_varread_f(&sVarf_Rmkgfx91, VOf(Bf12));
    __hv_varread_f(&sVarf_RlqNPGZL, VOf(Bf11));
    __hv_varread_f(&sVarf_9ZZaYkSw, VOf(Bf6));
    __hv_varread_f(&sVarf_rDyQb5CD, VOf(Bf7));
    __hv_varread_f(&sVarf_eRzs33w6, VOf(Bf13));
    __hv_varread_f(&sVarf_dkiKWwRw, VOf(Bf15));
    __hv_varwrite_f(&sVarf_CKWvYOMy, VIf(Bf0));
    __hv_varread_f(&sVarf_rQXuCUwb, VOf(Bf2));
    __hv_line_f(&sLine_mAK40YQY, VOf(Bf17));
    __hv_mul_f(VIf(Bf2), VIf(Bf17), VOf(Bf17));
    __hv_varread_f(&sVarf_qhKxAhAT, VOf(Bf18));
    __hv_line_f(&sLine_YfoEZAEN, VOf(Bf16));
    __hv_mul_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_eNKp5g8C, VOf(Bf17));
    __hv_line_f(&sLine_lAR1Xg2G, VOf(Bf14));
    __hv_mul_f(VIf(Bf17), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf16), VIf(Bf14), VOf(Bf14));
    __hv_varwrite_f(&sVarf_9ZZaYkSw, VIf(Bf14));
    __hv_varread_f(&sVarf_CKWvYOMy, VOf(Bf14));
    __hv_line_f(&sLine_XKdUOyXt, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_j5oT2Mgm, VOf(Bf19));
    __hv_mul_f(VIf(Bf17), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_72MT8g6v, VOf(Bf16));
    __hv_mul_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_rDyQb5CD, VIf(Bf16));
    __hv_line_f(&sLine_JOpHP5TD, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_x8SUfxUU, VOf(Bf19));
    __hv_mul_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_ZDX8w7Jk, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_eRzs33w6, VIf(Bf16));
    __hv_line_f(&sLine_i4Gtz4ZS, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_EW4g4xpW, VOf(Bf14));
    __hv_mul_f(VIf(Bf18), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf16), VIf(Bf14), VOf(Bf14));
    __hv_line_f(&sLine_mjr4eL4w, VOf(Bf16));
    __hv_mul_f(VIf(Bf2), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_dkiKWwRw, VIf(Bf16));
    __hv_varwrite_f(&sVarf_rQXuCUwb, VIf(Bf1));
    __hv_varwrite_f(&sVarf_qhKxAhAT, VIf(Bf12));
    __hv_varwrite_f(&sVarf_eNKp5g8C, VIf(Bf11));
    sEnv_process(this, &sEnv_Vab8C2Nk, VIf(Bf6), &sEnv_Vab8C2Nk_sendMessage);
    sEnv_process(this, &sEnv_7LSo0ycF, VIf(Bf0), &sEnv_7LSo0ycF_sendMessage);
    __hv_line_f(&sLine_Yag7Sdav, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_1zitPqRt, VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_DGWtYZyf, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_LVkKPiFV, VOf(Bf6));
    __hv_line_f(&sLine_5tIOs5Qy, VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_floor_f(VIf(Bf11), VOf(Bf6));
    __hv_sub_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_aN4Ff5uW, VIf(Bf12));
    __hv_varwrite_f(&sVarf_LVkKPiFV, VIf(Bf7));
    __hv_varwrite_f(&sVarf_KeaflkBF, VIf(Bf13));
    __hv_varwrite_f(&sVarf_f74U6UoW, VIf(Bf15));
    __hv_varread_f(&sVarf_f74U6UoW, VOf(Bf15));
    __hv_line_f(&sLine_8qUFWHDl, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf15), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf13), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf13), VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf15), VIf(Bf7), VOf(Bf12));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf15), VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_div_f(VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf13), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_RlqNPGZL, VIf(Bf7));
    __hv_varread_f(&sVarf_KeaflkBF, VOf(Bf7));
    __hv_line_f(&sLine_gLlNlnA8, VOf(Bf13));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf7), VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_floor_f(VIf(Bf13), VOf(Bf12));
    __hv_sub_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_abs_f(VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf12), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf7), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf13), VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_neg_f(VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_Rmkgfx91, VIf(Bf7));
    __hv_varwrite_f(&sVarf_J5PLq9hm, VIf(Bf0));
    __hv_varread_f(&sVarf_Ty4fTfwE, VOf(Bf0));
    __hv_varread_f(&sVarf_gL4FmsV0, VOf(Bf7));
    __hv_varread_f(&sVarf_iD5L6E3O, VOf(Bf12));
    __hv_varread_f(&sVarf_X9Ox9MuR, VOf(Bf13));
    __hv_varread_f(&sVarf_EjGaUOJc, VOf(Bf6));
    __hv_varread_f(&sVarf_E06bcTW9, VOf(Bf15));
    __hv_varread_f(&sVarf_eGo6mWCB, VOf(Bf11));
    __hv_varwrite_f(&sVarf_xr6JOdum, VIf(Bf4));
    __hv_varread_f(&sVarf_Dl2Ren66, VOf(Bf1));
    __hv_line_f(&sLine_ECvhcurD, VOf(Bf16));
    __hv_mul_f(VIf(Bf1), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_JVwDpWW2, VOf(Bf14));
    __hv_line_f(&sLine_lawUtHkC, VOf(Bf2));
    __hv_mul_f(VIf(Bf14), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf16), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_B885LOj5, VOf(Bf16));
    __hv_line_f(&sLine_0Y5Sf33o, VOf(Bf18));
    __hv_mul_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_varwrite_f(&sVarf_X9Ox9MuR, VIf(Bf18));
    __hv_varread_f(&sVarf_xr6JOdum, VOf(Bf18));
    __hv_line_f(&sLine_VDwP6j68, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_f6BOh6kk, VOf(Bf19));
    __hv_mul_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_C6tFtCZA, VOf(Bf2));
    __hv_mul_f(VIf(Bf14), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf19), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_EjGaUOJc, VIf(Bf2));
    __hv_line_f(&sLine_XX44TUy7, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_n3yD6RiJ, VOf(Bf19));
    __hv_mul_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_1v52Lauc, VOf(Bf2));
    __hv_mul_f(VIf(Bf16), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf19), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_E06bcTW9, VIf(Bf2));
    __hv_line_f(&sLine_w6aXpICg, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_plRZ9nUu, VOf(Bf18));
    __hv_mul_f(VIf(Bf14), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_dojQ6Ax2, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_eGo6mWCB, VIf(Bf2));
    __hv_varwrite_f(&sVarf_Dl2Ren66, VIf(Bf0));
    __hv_varwrite_f(&sVarf_JVwDpWW2, VIf(Bf7));
    __hv_varwrite_f(&sVarf_B885LOj5, VIf(Bf12));
    sEnv_process(this, &sEnv_SebcApkC, VIf(Bf13), &sEnv_SebcApkC_sendMessage);
    sEnv_process(this, &sEnv_NVpinrgk, VIf(Bf4), &sEnv_NVpinrgk_sendMessage);
    __hv_line_f(&sLine_bI2EUWQ6, VOf(Bf4));
    __hv_var_k_f(VOf(Bf12), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf12), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf13), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_hCh9b5xs, VOf(Bf13));
    __hv_mul_f(VIf(Bf4), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_jp0p0uDd, VOf(Bf4));
    __hv_var_k_f(VOf(Bf12), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf12), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf13), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_TK4TYESy, VOf(Bf13));
    __hv_line_f(&sLine_tsPkPeLQ, VOf(Bf12));
    __hv_var_k_f(VOf(Bf7), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf12), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf13), VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_floor_f(VIf(Bf12), VOf(Bf13));
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_div_f(VIf(Bf13), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_Ty4fTfwE, VIf(Bf7));
    __hv_varwrite_f(&sVarf_TK4TYESy, VIf(Bf6));
    __hv_varwrite_f(&sVarf_IJ22BkAO, VIf(Bf15));
    __hv_varwrite_f(&sVarf_rocW0gck, VIf(Bf11));
    __hv_varread_f(&sVarf_rocW0gck, VOf(Bf11));
    __hv_line_f(&sLine_g6gD2mH3, VOf(Bf15));
    __hv_mul_f(VIf(Bf11), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf11), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf15), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf15), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf15), VOf(Bf15));
    __hv_mul_f(VIf(Bf15), VIf(Bf15), VOf(Bf11));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf11), VIf(Bf6), VOf(Bf7));
    __hv_var_k_f(VOf(Bf13), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf11), VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf15), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_iD5L6E3O, VIf(Bf6));
    __hv_varread_f(&sVarf_IJ22BkAO, VOf(Bf6));
    __hv_line_f(&sLine_7eWR2twk, VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf15), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf15), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf7), VIf(Bf15), VOf(Bf15));
    __hv_floor_f(VIf(Bf15), VOf(Bf7));
    __hv_sub_f(VIf(Bf15), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf15), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf7), VIf(Bf15), VOf(Bf15));
    __hv_abs_f(VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf15), VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_gL4FmsV0, VIf(Bf6));
    __hv_varwrite_f(&sVarf_mbjq7YNJ, VIf(Bf4));
    __hv_varwrite_f(&sVarf_Ek9mkeHO, VIf(Bf10));
    __hv_varread_f(&sVarf_VYUhJHSW, VOf(Bf10));
    __hv_varread_f(&sVarf_eOe5XbOk, VOf(Bf4));
    __hv_varread_f(&sVarf_vWN3FD41, VOf(Bf6));
    __hv_varread_f(&sVarf_GIsMgmBC, VOf(Bf7));
    __hv_varread_f(&sVarf_9VVJSSb0, VOf(Bf15));
    __hv_varread_f(&sVarf_qKPhfqwc, VOf(Bf13));
    __hv_line_f(&sLine_wt4CEhaf, VOf(Bf11));
    __hv_line_f(&sLine_zskjx6sR, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf11), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf15), VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_vWN3FD41, VIf(Bf10));
    __hv_varwrite_f(&sVarf_9VVJSSb0, VIf(Bf4));
    __hv_varread_f(&sVarf_ZdmopDW5, VOf(Bf11));
    __hv_varread_f(&sVarf_DZIPtg72, VOf(Bf15));
    __hv_varread_f(&sVarf_TUHsI1O3, VOf(Bf13));
    __hv_varread_f(&sVarf_w20YXUEA, VOf(Bf6));
    __hv_varread_f(&sVarf_FUHaXlpV, VOf(Bf0));
    __hv_varread_f(&sVarf_DZSBaz24, VOf(Bf2));
    __hv_varread_f(&sVarf_3cw3hUVR, VOf(Bf18));
    __hv_varwrite_f(&sVarf_bHTllCpE, VIf(Bf10));
    __hv_varread_f(&sVarf_5GRNsmGi, VOf(Bf1));
    __hv_line_f(&sLine_FAGprRyj, VOf(Bf14));
    __hv_mul_f(VIf(Bf1), VIf(Bf14), VOf(Bf14));
    __hv_varread_f(&sVarf_y1K2B105, VOf(Bf19));
    __hv_line_f(&sLine_dObJ04sd, VOf(Bf16));
    __hv_mul_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_18tAKPat, VOf(Bf14));
    __hv_line_f(&sLine_V0EU16uj, VOf(Bf17));
    __hv_mul_f(VIf(Bf14), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_varwrite_f(&sVarf_w20YXUEA, VIf(Bf17));
    __hv_varread_f(&sVarf_bHTllCpE, VOf(Bf17));
    __hv_line_f(&sLine_4evbcxnu, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_nupK7uV8, VOf(Bf20));
    __hv_mul_f(VIf(Bf14), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_yCcYTrOX, VOf(Bf16));
    __hv_mul_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf20), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_FUHaXlpV, VIf(Bf16));
    __hv_line_f(&sLine_IRwnmGeo, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_HWilLpMo, VOf(Bf20));
    __hv_mul_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_PanNwXSZ, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf20), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_DZSBaz24, VIf(Bf16));
    __hv_line_f(&sLine_tJmxRwCr, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_WbCaSSpp, VOf(Bf17));
    __hv_mul_f(VIf(Bf19), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_line_f(&sLine_hDomaCGc, VOf(Bf16));
    __hv_mul_f(VIf(Bf1), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_3cw3hUVR, VIf(Bf16));
    __hv_varwrite_f(&sVarf_5GRNsmGi, VIf(Bf11));
    __hv_varwrite_f(&sVarf_y1K2B105, VIf(Bf15));
    __hv_varwrite_f(&sVarf_18tAKPat, VIf(Bf13));
    sEnv_process(this, &sEnv_SXUIox5T, VIf(Bf6), &sEnv_SXUIox5T_sendMessage);
    sEnv_process(this, &sEnv_bgmQ18zr, VIf(Bf10), &sEnv_bgmQ18zr_sendMessage);
    __hv_line_f(&sLine_Jh39WsDN, VOf(Bf10));
    __hv_var_k_f(VOf(Bf13), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf10), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf13), VIf(Bf10), VOf(Bf10));
    __hv_exp_f(VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_4COV11Cx, VOf(Bf6));
    __hv_mul_f(VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_5JoV6qyc, VOf(Bf10));
    __hv_var_k_f(VOf(Bf13), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf10), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf13), VIf(Bf10), VOf(Bf10));
    __hv_exp_f(VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_K48ilF92, VOf(Bf6));
    __hv_line_f(&sLine_6xI3KZ7e, VOf(Bf13));
    __hv_var_k_f(VOf(Bf15), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf13), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_floor_f(VIf(Bf13), VOf(Bf6));
    __hv_sub_f(VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf15), VOf(Bf15));
    __hv_varwrite_f(&sVarf_ZdmopDW5, VIf(Bf15));
    __hv_varwrite_f(&sVarf_K48ilF92, VIf(Bf0));
    __hv_varwrite_f(&sVarf_AHpmQabp, VIf(Bf2));
    __hv_varwrite_f(&sVarf_VeNFz0yL, VIf(Bf18));
    __hv_varread_f(&sVarf_VeNFz0yL, VOf(Bf18));
    __hv_line_f(&sLine_rg70aCQ4, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf18), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf2), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf18), VIf(Bf0), VOf(Bf15));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf18), VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_div_f(VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_TUHsI1O3, VIf(Bf0));
    __hv_varread_f(&sVarf_AHpmQabp, VOf(Bf0));
    __hv_line_f(&sLine_Jq7zY0aX, VOf(Bf2));
    __hv_var_k_f(VOf(Bf15), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf0), VIf(Bf2), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf2), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf15));
    __hv_sub_f(VIf(Bf2), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf15), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_DZIPtg72, VIf(Bf0));
    __hv_varwrite_f(&sVarf_GIsMgmBC, VIf(Bf10));
    __hv_varread_f(&sVarf_V34kDXjc, VOf(Bf10));
    __hv_varread_f(&sVarf_vuXuffCV, VOf(Bf0));
    __hv_varread_f(&sVarf_lCsD17he, VOf(Bf15));
    __hv_varread_f(&sVarf_sXKCcAMk, VOf(Bf2));
    __hv_varread_f(&sVarf_9yqDVKeT, VOf(Bf6));
    __hv_varread_f(&sVarf_eQoPPMJC, VOf(Bf18));
    __hv_varread_f(&sVarf_r0bWoJem, VOf(Bf13));
    __hv_varwrite_f(&sVarf_n4ydhRnt, VIf(Bf4));
    __hv_varread_f(&sVarf_ZGCY2BTb, VOf(Bf11));
    __hv_line_f(&sLine_QnjqZWyq, VOf(Bf16));
    __hv_mul_f(VIf(Bf11), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_MM070WZK, VOf(Bf17));
    __hv_line_f(&sLine_kOSS03Ry, VOf(Bf1));
    __hv_mul_f(VIf(Bf17), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf16), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_Os3fD1ui, VOf(Bf16));
    __hv_line_f(&sLine_jLuLpq0c, VOf(Bf19));
    __hv_mul_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_varwrite_f(&sVarf_sXKCcAMk, VIf(Bf19));
    __hv_varread_f(&sVarf_n4ydhRnt, VOf(Bf19));
    __hv_line_f(&sLine_SDxmP6OQ, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_bU5ybW5d, VOf(Bf20));
    __hv_mul_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_3f7SoeF2, VOf(Bf1));
    __hv_mul_f(VIf(Bf17), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf20), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_9yqDVKeT, VIf(Bf1));
    __hv_line_f(&sLine_00Le1ti8, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_k05MI0kE, VOf(Bf20));
    __hv_mul_f(VIf(Bf11), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_b0oYX8rM, VOf(Bf1));
    __hv_mul_f(VIf(Bf16), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf20), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_eQoPPMJC, VIf(Bf1));
    __hv_line_f(&sLine_u3olOA84, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_s4XeWf9J, VOf(Bf19));
    __hv_mul_f(VIf(Bf17), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_TQ0BTggM, VOf(Bf1));
    __hv_mul_f(VIf(Bf11), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_r0bWoJem, VIf(Bf1));
    __hv_varwrite_f(&sVarf_ZGCY2BTb, VIf(Bf10));
    __hv_varwrite_f(&sVarf_MM070WZK, VIf(Bf0));
    __hv_varwrite_f(&sVarf_Os3fD1ui, VIf(Bf15));
    sEnv_process(this, &sEnv_eTwj183W, VIf(Bf2), &sEnv_eTwj183W_sendMessage);
    sEnv_process(this, &sEnv_QADo3dvR, VIf(Bf4), &sEnv_QADo3dvR_sendMessage);
    __hv_line_f(&sLine_cKRaaX4s, VOf(Bf4));
    __hv_var_k_f(VOf(Bf15), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf15), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_9hihgmkH, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_Avrt8f19, VOf(Bf4));
    __hv_var_k_f(VOf(Bf15), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf15), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_Kqd2OWvr, VOf(Bf2));
    __hv_line_f(&sLine_YqdGmMqn, VOf(Bf15));
    __hv_var_k_f(VOf(Bf0), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf15), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf2), VIf(Bf0), VIf(Bf15), VOf(Bf15));
    __hv_floor_f(VIf(Bf15), VOf(Bf2));
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_div_f(VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_V34kDXjc, VIf(Bf0));
    __hv_varwrite_f(&sVarf_Kqd2OWvr, VIf(Bf6));
    __hv_varwrite_f(&sVarf_8nb9sm9G, VIf(Bf18));
    __hv_varwrite_f(&sVarf_GrvutEiq, VIf(Bf13));
    __hv_varread_f(&sVarf_GrvutEiq, VOf(Bf13));
    __hv_line_f(&sLine_cILf1MKD, VOf(Bf18));
    __hv_mul_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf13), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf18), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_mul_f(VIf(Bf18), VIf(Bf18), VOf(Bf13));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf13), VIf(Bf6), VOf(Bf0));
    __hv_var_k_f(VOf(Bf2), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf13), VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf18), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_lCsD17he, VIf(Bf6));
    __hv_varread_f(&sVarf_8nb9sm9G, VOf(Bf6));
    __hv_line_f(&sLine_6uApRBZ9, VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf18), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf18), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf0), VIf(Bf18), VOf(Bf18));
    __hv_floor_f(VIf(Bf18), VOf(Bf0));
    __hv_sub_f(VIf(Bf18), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf18), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf18), VOf(Bf18));
    __hv_abs_f(VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf18), VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_vuXuffCV, VIf(Bf6));
    __hv_varwrite_f(&sVarf_qKPhfqwc, VIf(Bf4));
    __hv_varwrite_f(&sVarf_NCKczyfp, VIf(Bf7));
    __hv_varwrite_f(&sVarf_97oBvnPd, VIf(Bf8));
    __hv_varwrite_f(&sVarf_9dA9dDxu, VIf(Bf9));
    __hv_varwrite_f(&sVarf_kXFktIX5, VIf(Bf12));
    __hv_varwrite_f(&sVarf_WRJwFO7C, VIf(Bf3));
    __hv_varwrite_f(&sVarf_fexw9QZ3, VIf(Bf5));
    __hv_varread_f(&sVarf_97oBvnPd, VOf(Bf5));
    __hv_varread_f(&sVarf_9dA9dDxu, VOf(Bf3));
    __hv_varread_f(&sVarf_kXFktIX5, VOf(Bf12));
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf5), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf12), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_G0Ud2ayX, VOf(Bf12));
    __hv_varread_f(&sVarf_Ek9mkeHO, VOf(Bf5));
    __hv_varread_f(&sVarf_NCKczyfp, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_M3NGLR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_M3NGLR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
